/* Generated by re2c 3.1 on Sun Sep  3 21:16:31 2023 */
#line 1 "tokenizer.re"
#include <limits>

#include <lfortran/parser/parser_exception.h>
#include <lfortran/parser/tokenizer.h>
#include <lfortran/parser/parser.tab.hh>
#include <libasr/bigint.h>

namespace LCompilers::LFortran {

void Tokenizer::set_string(const std::string &str)
{
    // The input string must be NULL terminated, otherwise the tokenizer will
    // not detect the end of string. After C++11, the std::string is guaranteed
    // to end with \0, but we check this here just in case.
    LCOMPILERS_ASSERT(str[str.size()] == '\0');
    cur = (unsigned char *)(&str[0]);
    string_start = cur;
    cur_line = cur;
    line_num = 1;
}

template<int base>
bool adddgt(uint64_t &u, uint64_t d)
{
    if (u > (std::numeric_limits<uint64_t>::max() - d) / base) {
        return false;
    }
    u = u * base + d;
    return true;
}

bool lex_dec(const unsigned char *s, const unsigned char *e, uint64_t &u)
{
    for (u = 0; s < e; ++s) {
        if (!adddgt<10>(u, *s - 0x30u)) {
            return false;
        }
    }
    return true;
}

// Tokenizes integer of the kind 1234_ikind into `u` and `suffix`
// s ... the start of the integer
// e ... the character after the end
bool lex_int(const unsigned char *s, const unsigned char *e, uint64_t &u,
    Str &suffix)
{
    for (u = 0; s < e; ++s) {
        if (*s == '_') {
            s++;
            suffix.p = (char*) s;
            suffix.n = e-s;
            return true;
        } else if (!adddgt<10>(u, *s - 0x30u)) {
            return false;
        }
    }
    suffix.p = nullptr;
    suffix.n = 0;
    return true;
}

void lex_int_large(Allocator &al, const unsigned char *s,
    const unsigned char *e, BigInt::BigInt &u, Str &suffix)
{
    uint64_t ui;
    if (lex_int(s, e, ui, suffix)) {
        if (ui <= BigInt::MAX_SMALL_INT) {
            u.from_smallint(ui);
            return;
        }
    }
    const unsigned char *start = s;
    for (; s < e; ++s) {
        if (*s == '_') {
            s++;
            suffix.p = (char*) s;
            suffix.n = e-s;

            Str num;
            num.p = (char*)start;
            num.n = s-start-1;
            u.from_largeint(al, num);
            return;
        }
    }
    suffix.p = nullptr;
    suffix.n = 0;
    Str num;
    num.p = (char*)start;
    num.n = e-start;
    u.from_largeint(al, num);
}

uint64_t parse_int(const unsigned char *s)
{
    while (*s == ' ') s++;
    uint64_t u;
    for (u = 0; ; ++s) {
        if (*s >= '0' && *s <= '9') {
            if (!adddgt<10>(u, *s - 0x30u)) {
                return false;
            }
        } else {
            return u;
        }
    }
}

#define KW(x) token(yylval.string); RET(KW_##x);
#define RET(x) token_loc(loc); last_token=yytokentype::x; return yytokentype::x;
#define WARN_REL(x) add_rel_warning(diagnostics, fixed_form, yytokentype::TK_##x);

void Tokenizer::add_rel_warning(diag::Diagnostics &diagnostics, bool fixed_form, int rel_token) const {
    if (!fixed_form) {
        static const std::map<int, std::pair<std::string, std::string>> m = {
            {yytokentype::TK_EQ, {"==", ".eq."}},
            {yytokentype::TK_NE, {"/=", ".ne."}},
            {yytokentype::TK_LT, {"<",  ".lt."}},
            {yytokentype::TK_GT, {">",  ".gt."}},
            {yytokentype::TK_LE, {"<=", ".le."}},
            {yytokentype::TK_GE, {">=", ".ge."}},
        };
        const std::string rel_new = m.at(rel_token).first;
        const std::string rel_old = m.at(rel_token).second;
        Location loc;
        token_loc(loc);
        diagnostics.tokenizer_style_label(
            "Use '" + rel_new + "' instead of '" + rel_old + "'",
            {loc},
            "help: write this as '" + rel_new + "'");
    }
}

int Tokenizer::lex(Allocator &al, YYSTYPE &yylval, Location &loc, diag::Diagnostics &diagnostics)
{
    if (enddo_state == 1) {
        enddo_state = 2;
        KW(END_DO)
    } else if (enddo_state == 2) {
        enddo_insert_count--;
        if (enddo_insert_count > 0) {
            enddo_state = 1;
        } else {
            enddo_state = 0;
            token_loc(loc); line_num++; cur_line=cur;
            last_token = yytokentype::TK_NEWLINE;
        }
        return yytokentype::TK_NEWLINE;
    }
    for (;;) {
        tok = cur;

        /*
        Re2c has excellent documentation at:

        https://re2c.org/manual/manual_c.html

        The first paragraph there explains the basics:

        * If multiple rules match, the longest match takes precedence
        * If multiple rules match the same string, the earlier rule takes
          precedence
        * Default rule `*` should always be defined, it has the lowest priority
          regardless of its place and matches any code unit
        * We use the "Sentinel character" method for end of input:
            * The end of the input text is denoted with a null character \x00
            * Thus the null character cannot be part of the input otherwise
            * There is one rule to match \x00 to end the parser
            * No other rule is allowed to match \x00, otherwise the re2c block
              would parse past the end of the string and segfaults
            * A special case of the previous point are negated character
              ranges, such as [^"\x00], where one must include \x00 in it to
              ensure this rule does not match \x00 (all other rules simply do
              not mention \x00)
            * See the "Handling the end of input" section in the re2c
              documentation for more info

        The re2c block interacts with the rest of the code via just one pointer
        variable `cur`. On entering the re2c block, the `cur` variable must
        point to the first character of the token to be tokenized by the block.
        The re2c block below then executes on its own until a rule is matched:
        the action in {} is then executed. In that action `cur` points to the
        first character of the next token.

        Before the re2c block we save the current `cur` into `tok`, so that we
        can use `tok` and `cur` in the action in {} to extract the token that
        corresponds to the rule that got matched:

        * `tok` points to the first character of the token
        * `cur-1` points to the last character of the token
        * `cur` points to the first character of the next token
        * `cur-tok` is the length of the token

        In the action, we do one of:

        * call `continue` which executes another cycle in the for loop (which
          will parse the next token); we use this to skip a token
        * call `return` which returns from this function; we return a token
        * throw an exception (terminates the tokenizer)

        In the first two cases, `cur` points to first character of the next
        token, which becomes `tok` at the next iteration of the loop (either
        right away after `continue` or after the `lex` function is called again
        after `return`).

        See the manual for more details.
        */


        // These two variables are needed by the re2c block below internally,
        // initialization is not needed. One can think of them as local
        // variables of the re2c block.
        unsigned char *mar, *ctxmar;
        
#line 219 "tokenizer.cpp"
{
	unsigned char yych;
	unsigned int yyaccept = 0;
	static const unsigned char yybm[] = {
		/* table 1 .. 8: 0 */
		  0,   2,   2,   2,   2,   2,   2,   2, 
		  2,   3,   3,   3,   2,   3,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  3,   2,   2,   2,   2,   2,   2,   0, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		242, 242, 210, 210, 210, 210, 210, 210, 
		146, 146,   2,   2,   2,   2,   2,   2, 
		  2, 150, 150, 150, 150, 150, 150,  22, 
		 22,  22,  22,  22,  22,  22,  22,  22, 
		 22,  22,  22,  22,  22,  22,  22,  22, 
		 22,  22,  22,   2,   2,   2,   2,  26, 
		  2, 150, 150, 150, 150, 150, 150,  22, 
		 22,  22,  22,  22,  22,  22,  22,  22, 
		 22,  22,  22,  22,  22,  22,  22,  22, 
		 22,  22,  22,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		  2,   2,   2,   2,   2,   2,   2,   2, 
		/* table 9 .. 13: 256 */
		  0, 192, 192, 192, 192, 192, 192, 192, 
		192, 200, 128, 200, 192, 200, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		200, 192,  64, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		240, 240, 240, 240, 240, 240, 240, 240, 
		240, 240, 192, 192, 192, 192, 192, 192, 
		192, 224, 224, 224, 224, 224, 224, 224, 
		224, 224, 224, 224, 224, 224, 224, 224, 
		224, 224, 224, 224, 224, 224, 224, 224, 
		224, 224, 224, 192, 192, 192, 192, 192, 
		192, 224, 224, 224, 224, 224, 224, 224, 
		224, 224, 224, 224, 224, 224, 224, 224, 
		224, 224, 224, 224, 224, 224, 224, 224, 
		224, 224, 224, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
		192, 192, 192, 192, 192, 192, 192, 192, 
	};
	yych = *cur;
	if (yybm[256+yych] & 8) {
		goto yy4;
	}
	switch (yych) {
		case 0x00: goto yy1;
		case '\t':
		case '\n': goto yy5;
		case ' ':
		case '!': goto yy6;
		case '"': goto yy7;
		case '#': goto yy8;
		case '%': goto yy9;
		case '&': goto yy10;
		case '\'': goto yy11;
		case '(': goto yy12;
		case ')': goto yy13;
		case '*': goto yy14;
		case '+': goto yy15;
		case ',': goto yy16;
		case '-': goto yy17;
		case '.': goto yy18;
		case '/': goto yy19;
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
		case '5':
		case '6':
		case '7':
		case '8':
		case '9': goto yy20;
		case ':': goto yy22;
		case ';': goto yy23;
		case '<': goto yy24;
		case '=': goto yy25;
		case '>': goto yy27;
		case 'A':
		case 'a': goto yy28;
		case 'B':
		case 'b': goto yy30;
		case 'C':
		case 'c': goto yy31;
		case 'D':
		case 'd': goto yy32;
		case 'E':
		case 'e': goto yy33;
		case 'F':
		case 'f': goto yy34;
		case 'G':
		case 'g': goto yy35;
		case 'H':
		case 'J':
		case 'X':
		case 'Y':
		case '_':
		case 'h':
		case 'j':
		case 'x':
		case 'y': goto yy36;
		case 'I':
		case 'i': goto yy38;
		case 'K':
		case 'k': goto yy39;
		case 'L':
		case 'l': goto yy40;
		case 'M':
		case 'm': goto yy41;
		case 'N':
		case 'n': goto yy42;
		case 'O':
		case 'o': goto yy43;
		case 'P':
		case 'p': goto yy44;
		case 'Q':
		case 'q': goto yy45;
		case 'R':
		case 'r': goto yy46;
		case 'S':
		case 's': goto yy47;
		case 'T':
		case 't': goto yy48;
		case 'U':
		case 'u': goto yy49;
		case 'V':
		case 'v': goto yy50;
		case 'W':
		case 'w': goto yy51;
		case 'Z':
		case 'z': goto yy52;
		case '[': goto yy53;
		case ']': goto yy55;
		case '|': goto yy56;
		default: goto yy2;
	}
yy1:
	++cur;
#line 248 "tokenizer.re"
	{ RET(END_OF_FILE); }
#line 391 "tokenizer.cpp"
yy2:
	++cur;
yy3:
#line 239 "tokenizer.re"
	{ token_loc(loc);
                std::string t = token();
                throw parser_local::TokenizerError(diag::Diagnostic(
                    "Token '" + t + "' is not recognized",
                    diag::Level::Error, diag::Stage::Tokenizer, {
                        diag::Label("token not recognized", {loc})
                    })
                );
            }
#line 405 "tokenizer.cpp"
yy4:
	yych = *++cur;
	if (yybm[256+yych] & 8) {
		goto yy4;
	}
#line 249 "tokenizer.re"
	{ continue; }
#line 413 "tokenizer.cpp"
yy5:
	++cur;
#line 505 "tokenizer.re"
	{
                if (enddo_newline_process) {
                    enddo_newline_process = false;
                    enddo_state = 1;
                    return yytokentype::TK_NEWLINE;
                } else {
                    enddo_newline_process = false;
                    enddo_insert_count = 0;
                    token_loc(loc); line_num++; cur_line=cur;
                    last_token = yytokentype::TK_NEWLINE;
                    return yytokentype::TK_NEWLINE;
                }
            }
#line 430 "tokenizer.cpp"
yy6:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 0x00) goto yy3;
	goto yy58;
yy7:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 0x00) goto yy3;
	goto yy62;
yy8:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 0x00) goto yy3;
	goto yy65;
yy9:
	++cur;
#line 538 "tokenizer.re"
	{ RET(TK_PERCENT) }
#line 450 "tokenizer.cpp"
yy10:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= '\f') {
		if (yych <= 0x08) goto yy3;
		if (yych <= '\v') goto yy67;
		goto yy3;
	} else {
		if (yych <= '\r') goto yy67;
		if (yych <= 0x1F) goto yy3;
		if (yych <= '!') goto yy67;
		goto yy3;
	}
yy11:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 0x00) goto yy3;
	goto yy72;
yy12:
	yych = *++cur;
	if (yych == '/') {
		ctxmar = cur;
		goto yy74;
	}
#line 520 "tokenizer.re"
	{ RET(TK_LPAREN) }
#line 477 "tokenizer.cpp"
yy13:
	++cur;
#line 528 "tokenizer.re"
	{ RET(TK_RPAREN) }
#line 482 "tokenizer.cpp"
yy14:
	yych = *++cur;
	if (yych == '*') goto yy75;
#line 540 "tokenizer.re"
	{ RET(TK_STAR) }
#line 488 "tokenizer.cpp"
yy15:
	++cur;
#line 532 "tokenizer.re"
	{ RET(TK_PLUS) }
#line 493 "tokenizer.cpp"
yy16:
	++cur;
#line 539 "tokenizer.re"
	{ RET(TK_COMMA) }
#line 498 "tokenizer.cpp"
yy17:
	++cur;
#line 533 "tokenizer.re"
	{ RET(TK_MINUS) }
#line 503 "tokenizer.cpp"
yy18:
	yyaccept = 0;
	yych = *(mar = ++cur);
	switch (yych) {
		case '.': goto yy76;
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
		case '5':
		case '6':
		case '7':
		case '8':
		case '9': goto yy77;
		case 'A':
		case 'a': goto yy80;
		case 'B':
		case 'C':
		case 'D':
		case 'H':
		case 'I':
		case 'J':
		case 'K':
		case 'M':
		case 'P':
		case 'Q':
		case 'R':
		case 'S':
		case 'U':
		case 'V':
		case 'W':
		case 'Y':
		case 'Z':
		case 'b':
		case 'c':
		case 'd':
		case 'h':
		case 'i':
		case 'j':
		case 'k':
		case 'm':
		case 'p':
		case 'q':
		case 'r':
		case 's':
		case 'u':
		case 'v':
		case 'w':
		case 'y':
		case 'z': goto yy81;
		case 'E':
		case 'e': goto yy83;
		case 'F':
		case 'f': goto yy84;
		case 'G':
		case 'g': goto yy85;
		case 'L':
		case 'l': goto yy86;
		case 'N':
		case 'n': goto yy87;
		case 'O':
		case 'o': goto yy88;
		case 'T':
		case 't': goto yy89;
		case 'X':
		case 'x': goto yy90;
		default: goto yy3;
	}
yy19:
	yych = *++cur;
	if (yych <= '.') {
		if (yych == ')') goto yy91;
	} else {
		if (yych <= '/') goto yy92;
		if (yych == '=') goto yy93;
	}
#line 537 "tokenizer.re"
	{ RET(TK_SLASH) }
#line 583 "tokenizer.cpp"
yy20:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yybm[256+yych] & 16) {
		goto yy20;
	}
	if (yych <= ' ') {
		if (yych <= '\v') {
			if (yych == '\t') {
				ctxmar = cur;
				goto yy94;
			}
			if (yych >= '\v') {
				ctxmar = cur;
				goto yy94;
			}
		} else {
			if (yych == '\r') {
				ctxmar = cur;
				goto yy94;
			}
			if (yych >= ' ') {
				ctxmar = cur;
				goto yy94;
			}
		}
	} else {
		if (yych <= 'E') {
			if (yych == '.') {
				ctxmar = cur;
				goto yy95;
			}
			if (yych >= 'D') goto yy96;
		} else {
			if (yych <= '_') {
				if (yych >= '_') goto yy97;
			} else {
				if (yych <= 'c') goto yy21;
				if (yych <= 'e') goto yy96;
			}
		}
	}
yy21:
#line 625 "tokenizer.re"
	{
                lex_int_large(al, tok, cur,
                    yylval.int_suffix.int_n,
                    yylval.int_suffix.int_kind);
                RET(TK_INTEGER)
            }
#line 634 "tokenizer.cpp"
yy22:
	yych = *++cur;
	if (yych == ':') goto yy98;
#line 535 "tokenizer.re"
	{ RET(TK_COLON) }
#line 640 "tokenizer.cpp"
yy23:
	++cur;
#line 536 "tokenizer.re"
	{ RET(TK_SEMICOLON) }
#line 645 "tokenizer.cpp"
yy24:
	yych = *++cur;
	if (yych == '=') goto yy99;
#line 557 "tokenizer.re"
	{ RET(TK_LT) }
#line 651 "tokenizer.cpp"
yy25:
	yych = *++cur;
	if (yych <= '<') goto yy26;
	if (yych <= '=') goto yy100;
	if (yych <= '>') goto yy101;
yy26:
#line 534 "tokenizer.re"
	{ RET(TK_EQUAL) }
#line 660 "tokenizer.cpp"
yy27:
	yych = *++cur;
	if (yych == '=') goto yy102;
#line 563 "tokenizer.re"
	{ RET(TK_GT) }
#line 666 "tokenizer.cpp"
yy28:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych <= 'K') {
			if (yych == 'B') goto yy103;
			goto yy37;
		} else {
			if (yych <= 'L') goto yy104;
			if (yych <= 'R') goto yy37;
			goto yy105;
		}
	} else {
		if (yych <= 'k') {
			if (yych == 'b') goto yy103;
			goto yy37;
		} else {
			if (yych <= 'l') goto yy104;
			if (yych == 's') goto yy105;
			goto yy37;
		}
	}
yy29:
#line 663 "tokenizer.re"
	{ token(yylval.string); RET(TK_NAME) }
#line 691 "tokenizer.cpp"
yy30:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych <= 'I') {
		if (yych <= '\'') {
			if (yych == '"') goto yy107;
			if (yych <= '&') goto yy37;
			goto yy108;
		} else {
			if (yych == 'A') goto yy109;
			if (yych <= 'H') goto yy37;
			goto yy110;
		}
	} else {
		if (yych <= 'a') {
			if (yych == 'L') goto yy111;
			if (yych <= '`') goto yy37;
			goto yy109;
		} else {
			if (yych <= 'i') {
				if (yych <= 'h') goto yy37;
				goto yy110;
			} else {
				if (yych == 'l') goto yy111;
				goto yy37;
			}
		}
	}
yy31:
	yych = *++cur;
	switch (yych) {
		case 'A':
		case 'a': goto yy112;
		case 'H':
		case 'h': goto yy113;
		case 'L':
		case 'l': goto yy114;
		case 'O':
		case 'o': goto yy115;
		case 'R':
		case 'r': goto yy116;
		case 'Y':
		case 'y': goto yy117;
		default: goto yy37;
	}
yy32:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych <= 'E') {
			if (yych == 'A') goto yy118;
			if (yych <= 'D') goto yy37;
			goto yy119;
		} else {
			if (yych == 'I') goto yy120;
			if (yych <= 'N') goto yy37;
			goto yy121;
		}
	} else {
		if (yych <= 'e') {
			if (yych == 'a') goto yy118;
			if (yych <= 'd') goto yy37;
			goto yy119;
		} else {
			if (yych <= 'i') {
				if (yych <= 'h') goto yy37;
				goto yy120;
			} else {
				if (yych == 'o') goto yy121;
				goto yy37;
			}
		}
	}
yy33:
	yych = *++cur;
	switch (yych) {
		case 'L':
		case 'l': goto yy123;
		case 'N':
		case 'n': goto yy124;
		case 'Q':
		case 'q': goto yy125;
		case 'R':
		case 'r': goto yy126;
		case 'V':
		case 'v': goto yy127;
		case 'X':
		case 'x': goto yy128;
		default: goto yy37;
	}
yy34:
	yych = *++cur;
	switch (yych) {
		case 'I':
		case 'i': goto yy129;
		case 'L':
		case 'l': goto yy130;
		case 'O':
		case 'o': goto yy131;
		case 'U':
		case 'u': goto yy132;
		default: goto yy37;
	}
yy35:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'E') goto yy133;
		if (yych <= 'N') goto yy37;
		goto yy134;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy133;
		} else {
			if (yych == 'o') goto yy134;
			goto yy37;
		}
	}
yy36:
	yych = *++cur;
yy37:
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
	goto yy29;
yy38:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych <= 'L') {
			if (yych == 'F') goto yy136;
			goto yy37;
		} else {
			if (yych <= 'M') goto yy137;
			if (yych <= 'N') goto yy138;
			if (yych <= 'R') goto yy37;
			goto yy140;
		}
	} else {
		if (yych <= 'm') {
			if (yych == 'f') goto yy136;
			if (yych <= 'l') goto yy37;
			goto yy137;
		} else {
			if (yych <= 'n') goto yy138;
			if (yych == 's') goto yy140;
			goto yy37;
		}
	}
yy39:
	yych = *++cur;
	if (yych == 'I') goto yy141;
	if (yych == 'i') goto yy141;
	goto yy37;
yy40:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'E') goto yy142;
		if (yych <= 'N') goto yy37;
		goto yy143;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy142;
		} else {
			if (yych == 'o') goto yy143;
			goto yy37;
		}
	}
yy41:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'E') goto yy144;
		if (yych <= 'N') goto yy37;
		goto yy145;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy144;
		} else {
			if (yych == 'o') goto yy145;
			goto yy37;
		}
	}
yy42:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych <= 'E') {
			if (yych == 'A') goto yy146;
			if (yych <= 'D') goto yy37;
			goto yy147;
		} else {
			if (yych == 'O') goto yy148;
			if (yych <= 'T') goto yy37;
			goto yy149;
		}
	} else {
		if (yych <= 'e') {
			if (yych == 'a') goto yy146;
			if (yych <= 'd') goto yy37;
			goto yy147;
		} else {
			if (yych <= 'o') {
				if (yych <= 'n') goto yy37;
				goto yy148;
			} else {
				if (yych == 'u') goto yy149;
				goto yy37;
			}
		}
	}
yy43:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych <= 'P') {
		if (yych <= '\'') {
			if (yych == '"') goto yy150;
			if (yych <= '&') goto yy37;
			goto yy151;
		} else {
			if (yych == 'N') goto yy152;
			if (yych <= 'O') goto yy37;
			goto yy153;
		}
	} else {
		if (yych <= 'n') {
			if (yych == 'U') goto yy154;
			if (yych <= 'm') goto yy37;
			goto yy152;
		} else {
			if (yych <= 'p') {
				if (yych <= 'o') goto yy37;
				goto yy153;
			} else {
				if (yych == 'u') goto yy154;
				goto yy37;
			}
		}
	}
yy44:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych <= 'O') {
			if (yych == 'A') goto yy155;
			if (yych <= 'N') goto yy37;
			goto yy156;
		} else {
			if (yych == 'R') goto yy157;
			if (yych <= 'T') goto yy37;
			goto yy158;
		}
	} else {
		if (yych <= 'o') {
			if (yych == 'a') goto yy155;
			if (yych <= 'n') goto yy37;
			goto yy156;
		} else {
			if (yych <= 'r') {
				if (yych <= 'q') goto yy37;
				goto yy157;
			} else {
				if (yych == 'u') goto yy158;
				goto yy37;
			}
		}
	}
yy45:
	yych = *++cur;
	if (yych == 'U') goto yy159;
	if (yych == 'u') goto yy159;
	goto yy37;
yy46:
	yych = *++cur;
	if (yych <= 'E') {
		if (yych == 'A') goto yy160;
		if (yych <= 'D') goto yy37;
		goto yy161;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy160;
		} else {
			if (yych == 'e') goto yy161;
			goto yy37;
		}
	}
yy47:
	yych = *++cur;
	switch (yych) {
		case 'A':
		case 'a': goto yy162;
		case 'E':
		case 'e': goto yy163;
		case 'H':
		case 'h': goto yy164;
		case 'O':
		case 'o': goto yy165;
		case 'T':
		case 't': goto yy166;
		case 'U':
		case 'u': goto yy167;
		case 'Y':
		case 'y': goto yy168;
		default: goto yy37;
	}
yy48:
	yych = *++cur;
	switch (yych) {
		case 'A':
		case 'a': goto yy169;
		case 'E':
		case 'e': goto yy170;
		case 'H':
		case 'h': goto yy171;
		case 'O':
		case 'o': goto yy172;
		case 'Y':
		case 'y': goto yy173;
		default: goto yy37;
	}
yy49:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych == 'N') goto yy174;
		if (yych <= 'R') goto yy37;
		goto yy175;
	} else {
		if (yych <= 'n') {
			if (yych <= 'm') goto yy37;
			goto yy174;
		} else {
			if (yych == 's') goto yy175;
			goto yy37;
		}
	}
yy50:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'A') goto yy176;
		if (yych <= 'N') goto yy37;
		goto yy177;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy176;
		} else {
			if (yych == 'o') goto yy177;
			goto yy37;
		}
	}
yy51:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych <= 'G') {
			if (yych == 'A') goto yy178;
			goto yy37;
		} else {
			if (yych <= 'H') goto yy179;
			if (yych <= 'Q') goto yy37;
			goto yy180;
		}
	} else {
		if (yych <= 'g') {
			if (yych == 'a') goto yy178;
			goto yy37;
		} else {
			if (yych <= 'h') goto yy179;
			if (yych == 'r') goto yy180;
			goto yy37;
		}
	}
yy52:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych == '"') goto yy181;
	if (yych == '\'') goto yy182;
	goto yy37;
yy53:
	++cur;
yy54:
#line 529 "tokenizer.re"
	{ RET(TK_LBRACKET) }
#line 1073 "tokenizer.cpp"
yy55:
	++cur;
#line 530 "tokenizer.re"
	{ RET(TK_RBRACKET) }
#line 1078 "tokenizer.cpp"
yy56:
	++cur;
#line 541 "tokenizer.re"
	{ RET(TK_VBAR) }
#line 1083 "tokenizer.cpp"
yy57:
	yych = *++cur;
yy58:
	if (yybm[256+yych] & 64) {
		goto yy57;
	}
	if (yych >= 0x01) goto yy60;
yy59:
	cur = mar;
	if (yyaccept <= 7) {
		if (yyaccept <= 3) {
			if (yyaccept <= 1) {
				if (yyaccept == 0) {
					goto yy3;
				} else {
					goto yy21;
				}
			} else {
				if (yyaccept == 2) {
					goto yy29;
				} else {
					goto yy63;
				}
			}
		} else {
			if (yyaccept <= 5) {
				if (yyaccept == 4) {
					goto yy69;
				} else {
					goto yy73;
				}
			} else {
				if (yyaccept == 6) {
					goto yy54;
				} else {
					goto yy79;
				}
			}
		}
	} else {
		if (yyaccept <= 11) {
			if (yyaccept <= 9) {
				if (yyaccept == 8) {
					goto yy122;
				} else {
					goto yy139;
				}
			} else {
				if (yyaccept == 10) {
					goto yy240;
				} else {
					goto yy637;
				}
			}
		} else {
			if (yyaccept <= 13) {
				if (yyaccept == 12) {
					goto yy765;
				} else {
					goto yy915;
				}
			} else {
				goto yy985;
			}
		}
	}
yy60:
	++cur;
#line 643 "tokenizer.re"
	{
                line_num++; cur_line=cur;
                token(yylval.string);
                yylval.string.n--;
                token_loc(loc);
                if (last_token == yytokentype::TK_NEWLINE) {
                    return yytokentype::TK_COMMENT;
                } else {
                    last_token=yytokentype::TK_NEWLINE;
                    return yytokentype::TK_EOLCOMMENT;
                }
            }
#line 1165 "tokenizer.cpp"
yy61:
	yych = *++cur;
yy62:
	if (yybm[256+yych] & 128) {
		goto yy61;
	}
	if (yych <= 0x00) goto yy59;
	yyaccept = 3;
	yych = *(mar = ++cur);
	if (yych == '"') goto yy61;
yy63:
#line 659 "tokenizer.re"
	{ token_str(al, yylval.string, '"'); RET(TK_STRING) }
#line 1179 "tokenizer.cpp"
yy64:
	yych = *++cur;
yy65:
	if (yych <= 0x00) goto yy59;
	if (yych != '\n') goto yy64;
	++cur;
#line 657 "tokenizer.re"
	{ line_num++; cur_line=cur; continue; }
#line 1188 "tokenizer.cpp"
yy66:
	yych = *++cur;
yy67:
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy59;
			goto yy66;
		} else {
			if (yych <= '\n') goto yy68;
			if (yych <= '\v') goto yy66;
			goto yy59;
		}
	} else {
		if (yych <= 0x1F) {
			if (yych <= '\r') goto yy66;
			goto yy59;
		} else {
			if (yych <= ' ') goto yy66;
			if (yych <= '!') goto yy70;
			goto yy59;
		}
	}
yy68:
	yyaccept = 4;
	yych = *(mar = ++cur);
	if (yybm[0+yych] & 1) {
		goto yy68;
	}
	if (yych <= 0x1F) goto yy69;
	if (yych <= '!') goto yy70;
	if (yych == '&') goto yy183;
yy69:
#line 639 "tokenizer.re"
	{
                line_num++; cur_line=cur; continue;
            }
#line 1225 "tokenizer.cpp"
yy70:
	yych = *++cur;
	if (yych <= 0x00) goto yy59;
	if (yych == '\n') goto yy68;
	goto yy70;
yy71:
	yych = *++cur;
yy72:
	if (yybm[0+yych] & 2) {
		goto yy71;
	}
	if (yych <= 0x00) goto yy59;
	yyaccept = 5;
	yych = *(mar = ++cur);
	if (yych == '\'') goto yy71;
yy73:
#line 660 "tokenizer.re"
	{ token_str(al, yylval.string, '\''); RET(TK_STRING) }
#line 1244 "tokenizer.cpp"
yy74:
	yyaccept = 6;
	yych = *(mar = ++cur);
	if (yych <= 0x1F) {
		if (yych <= '\n') {
			if (yych == '\t') goto yy184;
			goto yy54;
		} else {
			if (yych == '\f') goto yy54;
			if (yych <= '\r') goto yy184;
			goto yy54;
		}
	} else {
		if (yych <= '.') {
			if (yych <= ' ') goto yy184;
			if (yych == ')') goto yy185;
			goto yy54;
		} else {
			if (yych <= '/') goto yy186;
			if (yych == '=') goto yy187;
			goto yy54;
		}
	}
yy75:
	++cur;
#line 546 "tokenizer.re"
	{ RET(TK_POW) }
#line 1272 "tokenizer.cpp"
yy76:
	++cur;
#line 544 "tokenizer.re"
	{ RET(TK_DBL_DOT) }
#line 1277 "tokenizer.cpp"
yy77:
	yyaccept = 7;
	yych = *(mar = ++cur);
yy78:
	if (yych <= 'E') {
		if (yych <= '/') goto yy79;
		if (yych <= '9') goto yy77;
		if (yych >= 'D') goto yy96;
	} else {
		if (yych <= '_') {
			if (yych >= '_') goto yy188;
		} else {
			if (yych <= 'c') goto yy79;
			if (yych <= 'e') goto yy96;
		}
	}
yy79:
#line 596 "tokenizer.re"
	{ token(yylval.string); RET(TK_REAL) }
#line 1297 "tokenizer.cpp"
yy80:
	yych = *++cur;
	if (yych == 'N') goto yy190;
	if (yych == 'n') goto yy190;
	goto yy82;
yy81:
	yych = *++cur;
yy82:
	if (yybm[0+yych] & 4) {
		goto yy81;
	}
	if (yych == '.') goto yy189;
	goto yy59;
yy83:
	yych = *++cur;
	if (yych == 'Q') goto yy191;
	if (yych == 'q') goto yy191;
	goto yy82;
yy84:
	yych = *++cur;
	if (yych == 'A') goto yy192;
	if (yych == 'a') goto yy192;
	goto yy82;
yy85:
	yych = *++cur;
	if (yych <= 'T') {
		if (yych == 'E') goto yy193;
		if (yych <= 'S') goto yy82;
		goto yy194;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy82;
			goto yy193;
		} else {
			if (yych == 't') goto yy194;
			goto yy82;
		}
	}
yy86:
	yych = *++cur;
	if (yych <= 'T') {
		if (yych == 'E') goto yy195;
		if (yych <= 'S') goto yy82;
		goto yy196;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy82;
			goto yy195;
		} else {
			if (yych == 't') goto yy196;
			goto yy82;
		}
	}
yy87:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'E') goto yy197;
		if (yych <= 'N') goto yy82;
		goto yy198;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy82;
			goto yy197;
		} else {
			if (yych == 'o') goto yy198;
			goto yy82;
		}
	}
yy88:
	yych = *++cur;
	if (yych == 'R') goto yy199;
	if (yych == 'r') goto yy199;
	goto yy82;
yy89:
	yych = *++cur;
	if (yych == 'R') goto yy200;
	if (yych == 'r') goto yy200;
	goto yy82;
yy90:
	yych = *++cur;
	if (yych == 'O') goto yy201;
	if (yych == 'o') goto yy201;
	goto yy82;
yy91:
	++cur;
#line 531 "tokenizer.re"
	{ RET(TK_RBRACKET_OLD) }
#line 1385 "tokenizer.cpp"
yy92:
	++cur;
#line 547 "tokenizer.re"
	{ RET(TK_CONCAT) }
#line 1390 "tokenizer.cpp"
yy93:
	++cur;
#line 554 "tokenizer.re"
	{ RET(TK_NE) }
#line 1395 "tokenizer.cpp"
yy94:
	yych = *++cur;
	if (yych <= 0x1F) {
		if (yych <= '\n') {
			if (yych == '\t') goto yy94;
			goto yy59;
		} else {
			if (yych == '\f') goto yy59;
			if (yych <= '\r') goto yy94;
			goto yy59;
		}
	} else {
		if (yych <= '^') {
			if (yych <= ' ') goto yy94;
			if (yych <= '@') goto yy59;
			if (yych <= 'Z') goto yy202;
			goto yy59;
		} else {
			if (yych == '`') goto yy59;
			if (yych <= 'z') goto yy202;
			goto yy59;
		}
	}
yy95:
	yyaccept = 7;
	yych = *(mar = ++cur);
	if (yych <= 'Z') {
		if (yych <= '@') goto yy78;
		if (yych <= 'C') goto yy203;
		if (yych <= 'E') goto yy205;
		goto yy203;
	} else {
		if (yych <= 'c') {
			if (yych <= '`') goto yy78;
			goto yy203;
		} else {
			if (yych <= 'e') goto yy205;
			if (yych <= 'z') goto yy203;
			goto yy78;
		}
	}
yy96:
	yych = *++cur;
	if (yych <= ',') {
		if (yych == '+') goto yy206;
		goto yy59;
	} else {
		if (yych <= '-') goto yy206;
		if (yych <= '/') goto yy59;
		if (yych <= '9') goto yy207;
		goto yy59;
	}
yy97:
	yych = *++cur;
	if (yych <= '9') {
		if (yych <= '&') {
			if (yych == '"') goto yy61;
			goto yy59;
		} else {
			if (yych <= '\'') goto yy71;
			if (yych <= '/') goto yy59;
			goto yy208;
		}
	} else {
		if (yych <= '^') {
			if (yych <= '@') goto yy59;
			if (yych <= 'Z') goto yy209;
			goto yy59;
		} else {
			if (yych == '`') goto yy59;
			if (yych <= 'z') goto yy209;
			goto yy59;
		}
	}
yy98:
	++cur;
#line 545 "tokenizer.re"
	{ RET(TK_DBL_COLON) }
#line 1474 "tokenizer.cpp"
yy99:
	++cur;
#line 560 "tokenizer.re"
	{ RET(TK_LE) }
#line 1479 "tokenizer.cpp"
yy100:
	++cur;
#line 551 "tokenizer.re"
	{ RET(TK_EQ) }
#line 1484 "tokenizer.cpp"
yy101:
	++cur;
#line 548 "tokenizer.re"
	{ RET(TK_ARROW) }
#line 1489 "tokenizer.cpp"
yy102:
	++cur;
#line 566 "tokenizer.re"
	{ RET(TK_GE) }
#line 1494 "tokenizer.cpp"
yy103:
	yych = *++cur;
	if (yych == 'S') goto yy210;
	if (yych == 's') goto yy210;
	goto yy37;
yy104:
	yych = *++cur;
	if (yych == 'L') goto yy211;
	if (yych == 'l') goto yy211;
	goto yy37;
yy105:
	yych = *++cur;
	if (yych <= 'Y') {
		if (yych == 'S') goto yy213;
		if (yych <= 'X') goto yy37;
		goto yy214;
	} else {
		if (yych <= 's') {
			if (yych <= 'r') goto yy37;
			goto yy213;
		} else {
			if (yych == 'y') goto yy214;
			goto yy37;
		}
	}
yy106:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych <= '&') {
		if (yych == '"') goto yy61;
		goto yy29;
	} else {
		if (yych <= '\'') goto yy71;
		if (yych == '_') goto yy106;
		goto yy29;
	}
yy107:
	yych = *++cur;
	if (yybm[0+yych] & 32) {
		goto yy215;
	}
	goto yy59;
yy108:
	yych = *++cur;
	if (yych <= '/') goto yy59;
	if (yych <= '1') goto yy216;
	goto yy59;
yy109:
	yych = *++cur;
	if (yych == 'C') goto yy217;
	if (yych == 'c') goto yy217;
	goto yy37;
yy110:
	yych = *++cur;
	if (yych == 'N') goto yy218;
	if (yych == 'n') goto yy218;
	goto yy37;
yy111:
	yych = *++cur;
	if (yych == 'O') goto yy219;
	if (yych == 'o') goto yy219;
	goto yy37;
yy112:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych == 'L') goto yy220;
		if (yych <= 'R') goto yy37;
		goto yy221;
	} else {
		if (yych <= 'l') {
			if (yych <= 'k') goto yy37;
			goto yy220;
		} else {
			if (yych == 's') goto yy221;
			goto yy37;
		}
	}
yy113:
	yych = *++cur;
	if (yych == 'A') goto yy222;
	if (yych == 'a') goto yy222;
	goto yy37;
yy114:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'A') goto yy223;
		if (yych <= 'N') goto yy37;
		goto yy224;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy223;
		} else {
			if (yych == 'o') goto yy224;
			goto yy37;
		}
	}
yy115:
	yych = *++cur;
	if (yych <= 'N') {
		if (yych <= 'D') {
			if (yych <= 'C') goto yy37;
			goto yy225;
		} else {
			if (yych <= 'L') goto yy37;
			if (yych <= 'M') goto yy226;
			goto yy227;
		}
	} else {
		if (yych <= 'l') {
			if (yych == 'd') goto yy225;
			goto yy37;
		} else {
			if (yych <= 'm') goto yy226;
			if (yych <= 'n') goto yy227;
			goto yy37;
		}
	}
yy116:
	yych = *++cur;
	if (yych == 'I') goto yy228;
	if (yych == 'i') goto yy228;
	goto yy37;
yy117:
	yych = *++cur;
	if (yych == 'C') goto yy229;
	if (yych == 'c') goto yy229;
	goto yy37;
yy118:
	yych = *++cur;
	if (yych == 'T') goto yy230;
	if (yych == 't') goto yy230;
	goto yy37;
yy119:
	yych = *++cur;
	if (yych <= 'F') {
		if (yych == 'A') goto yy231;
		if (yych <= 'E') goto yy37;
		goto yy232;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy231;
		} else {
			if (yych == 'f') goto yy232;
			goto yy37;
		}
	}
yy120:
	yych = *++cur;
	if (yych == 'M') goto yy233;
	if (yych == 'm') goto yy233;
	goto yy37;
yy121:
	yyaccept = 8;
	yych = *(mar = ++cur);
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= '@') {
		if (yych <= '\f') {
			if (yych <= '\t') {
				if (yych >= '\t') {
					ctxmar = cur;
					goto yy234;
				}
			} else {
				if (yych == '\v') {
					ctxmar = cur;
					goto yy234;
				}
			}
		} else {
			if (yych <= ' ') {
				if (yych <= '\r') {
					ctxmar = cur;
					goto yy234;
				}
				if (yych >= ' ') {
					ctxmar = cur;
					goto yy234;
				}
			} else {
				if (yych <= '/') goto yy122;
				if (yych <= '9') goto yy36;
			}
		}
	} else {
		if (yych <= '`') {
			if (yych <= 'V') {
				if (yych == 'U') goto yy235;
				goto yy36;
			} else {
				if (yych <= 'W') goto yy236;
				if (yych <= 'Z') goto yy36;
			}
		} else {
			if (yych <= 'v') {
				if (yych == 'u') goto yy235;
				goto yy36;
			} else {
				if (yych <= 'w') goto yy236;
				if (yych <= 'z') goto yy36;
			}
		}
	}
yy122:
#line 291 "tokenizer.re"
	{ KW(DO) }
#line 1707 "tokenizer.cpp"
yy123:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych == 'E') goto yy237;
		if (yych <= 'R') goto yy37;
		goto yy238;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy237;
		} else {
			if (yych == 's') goto yy238;
			goto yy37;
		}
	}
yy124:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych <= 'D') {
			if (yych <= 'C') goto yy37;
			goto yy239;
		} else {
			if (yych <= 'S') goto yy37;
			if (yych <= 'T') goto yy241;
			goto yy242;
		}
	} else {
		if (yych <= 's') {
			if (yych == 'd') goto yy239;
			goto yy37;
		} else {
			if (yych <= 't') goto yy241;
			if (yych <= 'u') goto yy242;
			goto yy37;
		}
	}
yy125:
	yych = *++cur;
	if (yych == 'U') goto yy243;
	if (yych == 'u') goto yy243;
	goto yy37;
yy126:
	yych = *++cur;
	if (yych == 'R') goto yy244;
	if (yych == 'r') goto yy244;
	goto yy37;
yy127:
	yych = *++cur;
	if (yych == 'E') goto yy245;
	if (yych == 'e') goto yy245;
	goto yy37;
yy128:
	yych = *++cur;
	if (yych <= 'T') {
		if (yych == 'I') goto yy246;
		if (yych <= 'S') goto yy37;
		goto yy247;
	} else {
		if (yych <= 'i') {
			if (yych <= 'h') goto yy37;
			goto yy246;
		} else {
			if (yych == 't') goto yy247;
			goto yy37;
		}
	}
yy129:
	yych = *++cur;
	if (yych <= 'N') {
		if (yych == 'L') goto yy248;
		if (yych <= 'M') goto yy37;
		goto yy249;
	} else {
		if (yych <= 'l') {
			if (yych <= 'k') goto yy37;
			goto yy248;
		} else {
			if (yych == 'n') goto yy249;
			goto yy37;
		}
	}
yy130:
	yych = *++cur;
	if (yych == 'U') goto yy250;
	if (yych == 'u') goto yy250;
	goto yy37;
yy131:
	yych = *++cur;
	if (yych == 'R') goto yy251;
	if (yych == 'r') goto yy251;
	goto yy37;
yy132:
	yych = *++cur;
	if (yych == 'N') goto yy252;
	if (yych == 'n') goto yy252;
	goto yy37;
yy133:
	yych = *++cur;
	if (yych == 'N') goto yy253;
	if (yych == 'n') goto yy253;
	goto yy37;
yy134:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'T') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy135;
			if (yych <= 'S') goto yy36;
			goto yy254;
		}
	} else {
		if (yych <= 's') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 't') goto yy254;
			if (yych <= 'z') goto yy36;
		}
	}
yy135:
#line 408 "tokenizer.re"
	{ KW(GO) }
#line 1834 "tokenizer.cpp"
yy136:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 410 "tokenizer.re"
	{ KW(IF) }
#line 1843 "tokenizer.cpp"
yy137:
	yych = *++cur;
	if (yych <= 'P') {
		if (yych == 'A') goto yy255;
		if (yych <= 'O') goto yy37;
		goto yy256;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy255;
		} else {
			if (yych == 'p') goto yy256;
			goto yy37;
		}
	}
yy138:
	yyaccept = 9;
	yych = *(mar = ++cur);
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'P') {
		if (yych <= ' ') {
			if (yych <= '\v') {
				if (yych == '\t') goto yy257;
				if (yych >= '\v') goto yy257;
			} else {
				if (yych == '\r') goto yy257;
				if (yych >= ' ') goto yy257;
			}
		} else {
			if (yych <= 'B') {
				if (yych <= '/') goto yy139;
				if (yych <= '9') goto yy36;
				if (yych >= 'A') goto yy36;
			} else {
				if (yych <= 'C') goto yy258;
				if (yych == 'O') goto yy259;
				goto yy36;
			}
		}
	} else {
		if (yych <= 'c') {
			if (yych <= 'T') {
				if (yych <= 'Q') goto yy260;
				if (yych <= 'R') goto yy36;
				if (yych <= 'S') goto yy261;
				goto yy262;
			} else {
				if (yych <= 'Z') goto yy36;
				if (yych <= '`') goto yy139;
				if (yych <= 'b') goto yy36;
				goto yy258;
			}
		} else {
			if (yych <= 'q') {
				if (yych == 'o') goto yy259;
				if (yych <= 'p') goto yy36;
				goto yy260;
			} else {
				if (yych <= 's') {
					if (yych <= 'r') goto yy36;
					goto yy261;
				} else {
					if (yych <= 't') goto yy262;
					if (yych <= 'z') goto yy36;
				}
			}
		}
	}
yy139:
#line 415 "tokenizer.re"
	{ KW(IN) }
#line 1917 "tokenizer.cpp"
yy140:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 425 "tokenizer.re"
	{ KW(IS) }
#line 1926 "tokenizer.cpp"
yy141:
	yych = *++cur;
	if (yych == 'N') goto yy263;
	if (yych == 'n') goto yy263;
	goto yy37;
yy142:
	yych = *++cur;
	if (yych == 'N') goto yy264;
	if (yych == 'n') goto yy264;
	goto yy37;
yy143:
	yych = *++cur;
	if (yych <= 'G') {
		if (yych == 'C') goto yy265;
		if (yych <= 'F') goto yy37;
		goto yy266;
	} else {
		if (yych <= 'c') {
			if (yych <= 'b') goto yy37;
			goto yy265;
		} else {
			if (yych == 'g') goto yy266;
			goto yy37;
		}
	}
yy144:
	yych = *++cur;
	if (yych == 'M') goto yy267;
	if (yych == 'm') goto yy267;
	goto yy37;
yy145:
	yych = *++cur;
	if (yych <= 'L') {
		if (yych == 'D') goto yy268;
		if (yych <= 'K') goto yy37;
		goto yy269;
	} else {
		if (yych <= 'd') {
			if (yych <= 'c') goto yy37;
			goto yy268;
		} else {
			if (yych == 'l') goto yy269;
			goto yy37;
		}
	}
yy146:
	yych = *++cur;
	if (yych == 'M') goto yy270;
	if (yych == 'm') goto yy270;
	goto yy37;
yy147:
	yych = *++cur;
	if (yych == 'W') goto yy271;
	if (yych == 'w') goto yy271;
	goto yy37;
yy148:
	yych = *++cur;
	if (yych <= 'P') {
		if (yych == 'N') goto yy272;
		if (yych <= 'O') goto yy37;
		goto yy273;
	} else {
		if (yych <= 'n') {
			if (yych <= 'm') goto yy37;
			goto yy272;
		} else {
			if (yych == 'p') goto yy273;
			goto yy37;
		}
	}
yy149:
	yych = *++cur;
	if (yych == 'L') goto yy274;
	if (yych == 'l') goto yy274;
	goto yy37;
yy150:
	yych = *++cur;
	if (yybm[0+yych] & 64) {
		goto yy275;
	}
	goto yy59;
yy151:
	yych = *++cur;
	if (yych <= '/') goto yy59;
	if (yych <= '7') goto yy276;
	goto yy59;
yy152:
	yych = *++cur;
	if (yych == 'L') goto yy277;
	if (yych == 'l') goto yy277;
	goto yy37;
yy153:
	yych = *++cur;
	if (yych <= 'T') {
		if (yych == 'E') goto yy278;
		if (yych <= 'S') goto yy37;
		goto yy279;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy278;
		} else {
			if (yych == 't') goto yy279;
			goto yy37;
		}
	}
yy154:
	yych = *++cur;
	if (yych == 'T') goto yy280;
	if (yych == 't') goto yy280;
	goto yy37;
yy155:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych <= 'Q') goto yy37;
		if (yych <= 'R') goto yy281;
		goto yy282;
	} else {
		if (yych <= 'q') goto yy37;
		if (yych <= 'r') goto yy281;
		if (yych <= 's') goto yy282;
		goto yy37;
	}
yy156:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych == 'I') goto yy283;
		if (yych <= 'R') goto yy37;
		goto yy284;
	} else {
		if (yych <= 'i') {
			if (yych <= 'h') goto yy37;
			goto yy283;
		} else {
			if (yych == 's') goto yy284;
			goto yy37;
		}
	}
yy157:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych <= 'H') {
			if (yych == 'E') goto yy285;
			goto yy37;
		} else {
			if (yych <= 'I') goto yy286;
			if (yych <= 'N') goto yy37;
			goto yy287;
		}
	} else {
		if (yych <= 'h') {
			if (yych == 'e') goto yy285;
			goto yy37;
		} else {
			if (yych <= 'i') goto yy286;
			if (yych == 'o') goto yy287;
			goto yy37;
		}
	}
yy158:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'B') goto yy288;
		if (yych <= 'Q') goto yy37;
		goto yy289;
	} else {
		if (yych <= 'b') {
			if (yych <= 'a') goto yy37;
			goto yy288;
		} else {
			if (yych == 'r') goto yy289;
			goto yy37;
		}
	}
yy159:
	yych = *++cur;
	if (yych == 'I') goto yy290;
	if (yych == 'i') goto yy290;
	goto yy37;
yy160:
	yych = *++cur;
	if (yych == 'N') goto yy291;
	if (yych == 'n') goto yy291;
	goto yy37;
yy161:
	yych = *++cur;
	switch (yych) {
		case 'A':
		case 'a': goto yy292;
		case 'C':
		case 'c': goto yy293;
		case 'D':
		case 'd': goto yy294;
		case 'Q':
		case 'q': goto yy295;
		case 'S':
		case 's': goto yy296;
		case 'T':
		case 't': goto yy297;
		case 'W':
		case 'w': goto yy298;
		default: goto yy37;
	}
yy162:
	yych = *++cur;
	if (yych == 'V') goto yy299;
	if (yych == 'v') goto yy299;
	goto yy37;
yy163:
	yych = *++cur;
	if (yych <= 'Q') {
		if (yych == 'L') goto yy300;
		if (yych <= 'P') goto yy37;
		goto yy301;
	} else {
		if (yych <= 'l') {
			if (yych <= 'k') goto yy37;
			goto yy300;
		} else {
			if (yych == 'q') goto yy301;
			goto yy37;
		}
	}
yy164:
	yych = *++cur;
	if (yych == 'A') goto yy302;
	if (yych == 'a') goto yy302;
	goto yy37;
yy165:
	yych = *++cur;
	if (yych == 'U') goto yy303;
	if (yych == 'u') goto yy303;
	goto yy37;
yy166:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'A') goto yy304;
		if (yych <= 'N') goto yy37;
		goto yy305;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy304;
		} else {
			if (yych == 'o') goto yy305;
			goto yy37;
		}
	}
yy167:
	yych = *++cur;
	if (yych == 'B') goto yy306;
	if (yych == 'b') goto yy306;
	goto yy37;
yy168:
	yych = *++cur;
	if (yych == 'N') goto yy307;
	if (yych == 'n') goto yy307;
	goto yy37;
yy169:
	yych = *++cur;
	if (yych == 'R') goto yy308;
	if (yych == 'r') goto yy308;
	goto yy37;
yy170:
	yych = *++cur;
	if (yych <= 'M') {
		if (yych == 'A') goto yy309;
		if (yych <= 'L') goto yy37;
		goto yy310;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy309;
		} else {
			if (yych == 'm') goto yy310;
			goto yy37;
		}
	}
yy171:
	yych = *++cur;
	if (yych == 'E') goto yy311;
	if (yych == 'e') goto yy311;
	goto yy37;
yy172:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 493 "tokenizer.re"
	{ KW(TO) }
#line 2218 "tokenizer.cpp"
yy173:
	yych = *++cur;
	if (yych == 'P') goto yy312;
	if (yych == 'p') goto yy312;
	goto yy37;
yy174:
	yych = *++cur;
	if (yych == 'F') goto yy313;
	if (yych == 'f') goto yy313;
	goto yy37;
yy175:
	yych = *++cur;
	if (yych == 'E') goto yy314;
	if (yych == 'e') goto yy314;
	goto yy37;
yy176:
	yych = *++cur;
	if (yych == 'L') goto yy315;
	if (yych == 'l') goto yy315;
	goto yy37;
yy177:
	yych = *++cur;
	if (yych == 'L') goto yy316;
	if (yych == 'l') goto yy316;
	goto yy37;
yy178:
	yych = *++cur;
	if (yych == 'I') goto yy317;
	if (yych == 'i') goto yy317;
	goto yy37;
yy179:
	yych = *++cur;
	if (yych <= 'I') {
		if (yych == 'E') goto yy318;
		if (yych <= 'H') goto yy37;
		goto yy319;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy318;
		} else {
			if (yych == 'i') goto yy319;
			goto yy37;
		}
	}
yy180:
	yych = *++cur;
	if (yych == 'I') goto yy320;
	if (yych == 'i') goto yy320;
	goto yy37;
yy181:
	yych = *++cur;
	if (yych == '"') goto yy59;
	goto yy322;
yy182:
	yych = *++cur;
	if (yych == '\'') goto yy59;
	goto yy324;
yy183:
	++cur;
	goto yy69;
yy184:
	yych = *++cur;
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy59;
			goto yy184;
		} else {
			if (yych == '\v') goto yy184;
			goto yy59;
		}
	} else {
		if (yych <= ' ') {
			if (yych <= '\r') goto yy184;
			if (yych <= 0x1F) goto yy59;
			goto yy184;
		} else {
			if (yych == ')') goto yy325;
			goto yy59;
		}
	}
yy185:
	++cur;
	cur -= 2;
#line 522 "tokenizer.re"
	{ RET(TK_LPAREN) }
#line 2305 "tokenizer.cpp"
yy186:
	yych = *++cur;
	if (yych == ')') goto yy328;
	goto yy327;
yy187:
	++cur;
	cur -= 2;
#line 521 "tokenizer.re"
	{ RET(TK_LPAREN) }
#line 2315 "tokenizer.cpp"
yy188:
	yych = *++cur;
	if (yych <= 'Z') {
		if (yych <= '/') goto yy59;
		if (yych <= '9') goto yy329;
		if (yych <= '@') goto yy59;
		goto yy330;
	} else {
		if (yych <= '_') {
			if (yych <= '^') goto yy59;
			goto yy330;
		} else {
			if (yych <= '`') goto yy59;
			if (yych <= 'z') goto yy330;
			goto yy59;
		}
	}
yy189:
	++cur;
#line 662 "tokenizer.re"
	{ token(yylval.string); RET(TK_DEF_OP) }
#line 2337 "tokenizer.cpp"
yy190:
	yych = *++cur;
	if (yych == 'D') goto yy331;
	if (yych == 'd') goto yy331;
	goto yy82;
yy191:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych == '.') goto yy332;
		goto yy82;
	} else {
		if (yych <= 'V') goto yy333;
		if (yych == 'v') goto yy333;
		goto yy82;
	}
yy192:
	yych = *++cur;
	if (yych == 'L') goto yy334;
	if (yych == 'l') goto yy334;
	goto yy82;
yy193:
	yych = *++cur;
	if (yych == '.') goto yy335;
	goto yy82;
yy194:
	yych = *++cur;
	if (yych == '.') goto yy336;
	goto yy82;
yy195:
	yych = *++cur;
	if (yych == '.') goto yy337;
	goto yy82;
yy196:
	yych = *++cur;
	if (yych == '.') goto yy338;
	goto yy82;
yy197:
	yych = *++cur;
	if (yych <= 'P') {
		if (yych == '.') goto yy339;
		goto yy82;
	} else {
		if (yych <= 'Q') goto yy340;
		if (yych == 'q') goto yy340;
		goto yy82;
	}
yy198:
	yych = *++cur;
	if (yych == 'T') goto yy341;
	if (yych == 't') goto yy341;
	goto yy82;
yy199:
	yych = *++cur;
	if (yych == '.') goto yy342;
	goto yy82;
yy200:
	yych = *++cur;
	if (yych == 'U') goto yy343;
	if (yych == 'u') goto yy343;
	goto yy82;
yy201:
	yych = *++cur;
	if (yych == 'R') goto yy344;
	if (yych == 'r') goto yy344;
	goto yy82;
yy202:
	yych = *++cur;
	if (yybm[0+yych] & 16) {
		goto yy202;
	}
	cur = ctxmar;
#line 597 "tokenizer.re"
	{
                if (last_token == yytokentype::TK_NEWLINE) {
                    uint64_t u;
                    if (lex_int(tok, cur, u, yylval.int_suffix.int_kind)) {
                            yylval.n = u;
                            if (enddo_label_stack[enddo_label_stack.size()-1] == u) {
                                while (enddo_label_stack[enddo_label_stack.size()-1] == u) {
                                    enddo_label_stack.pop_back();
                                    enddo_insert_count++;
                                }
                                enddo_newline_process = true;
                            } else {
                                enddo_newline_process = false;
                            }
                            RET(TK_LABEL)
                    } else {
                        token_loc(loc);
                        std::string t = token();
                        throw LFortran::parser_local::TokenizerError("Integer '" + t + "' too large",
                            loc);
                    }
                } else {
                    lex_int_large(al, tok, cur,
                        yylval.int_suffix.int_n,
                        yylval.int_suffix.int_kind);
                    RET(TK_INTEGER)
                }
            }
#line 2438 "tokenizer.cpp"
yy203:
	yych = *++cur;
yy204:
	if (yych <= '@') {
		if (yych == '.') goto yy345;
		goto yy59;
	} else {
		if (yych <= 'Z') goto yy203;
		if (yych <= '`') goto yy59;
		if (yych <= 'z') goto yy203;
		goto yy59;
	}
yy205:
	yych = *++cur;
	if (yych <= ',') {
		if (yych != '+') goto yy204;
	} else {
		if (yych <= '-') goto yy206;
		if (yych <= '/') goto yy204;
		if (yych <= '9') goto yy207;
		goto yy204;
	}
yy206:
	yych = *++cur;
	if (yych <= '/') goto yy59;
	if (yych >= ':') goto yy59;
yy207:
	yyaccept = 7;
	yych = *(mar = ++cur);
	if (yych <= '/') goto yy79;
	if (yych <= '9') goto yy207;
	if (yych == '_') goto yy188;
	goto yy79;
yy208:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yych <= '\r') {
		if (yych <= '\n') {
			if (yych == '\t') {
				ctxmar = cur;
				goto yy94;
			}
			goto yy21;
		} else {
			if (yych == '\f') goto yy21;
			ctxmar = cur;
			goto yy94;
		}
	} else {
		if (yych <= '-') {
			if (yych == ' ') {
				ctxmar = cur;
				goto yy94;
			}
			goto yy21;
		} else {
			if (yych <= '.') {
				ctxmar = cur;
				goto yy346;
			}
			if (yych <= '/') goto yy21;
			if (yych <= '9') goto yy208;
			goto yy21;
		}
	}
yy209:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yych <= '-') {
		if (yych <= '\v') {
			if (yych == '\t') {
				ctxmar = cur;
				goto yy94;
			}
			if (yych <= '\n') goto yy21;
			ctxmar = cur;
			goto yy94;
		} else {
			if (yych <= '\r') {
				if (yych <= '\f') goto yy21;
				ctxmar = cur;
				goto yy94;
			} else {
				if (yych == ' ') {
					ctxmar = cur;
					goto yy94;
				}
				goto yy21;
			}
		}
	} else {
		if (yych <= 'Z') {
			if (yych <= '/') {
				if (yych <= '.') {
					ctxmar = cur;
					goto yy346;
				}
				goto yy21;
			} else {
				if (yych <= '9') goto yy209;
				if (yych <= '@') goto yy21;
				goto yy209;
			}
		} else {
			if (yych <= '_') {
				if (yych <= '^') goto yy21;
				goto yy209;
			} else {
				if (yych <= '`') goto yy21;
				if (yych <= 'z') goto yy209;
				goto yy21;
			}
		}
	}
yy210:
	yych = *++cur;
	if (yych == 'T') goto yy347;
	if (yych == 't') goto yy347;
	goto yy37;
yy211:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'O') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy212;
			if (yych <= 'N') goto yy36;
			goto yy348;
		}
	} else {
		if (yych <= 'n') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 'o') goto yy348;
			if (yych <= 'z') goto yy36;
		}
	}
yy212:
#line 253 "tokenizer.re"
	{ KW(ALL) }
#line 2583 "tokenizer.cpp"
yy213:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'I') goto yy349;
		if (yych <= 'N') goto yy37;
		goto yy350;
	} else {
		if (yych <= 'i') {
			if (yych <= 'h') goto yy37;
			goto yy349;
		} else {
			if (yych == 'o') goto yy350;
			goto yy37;
		}
	}
yy214:
	yych = *++cur;
	if (yych == 'N') goto yy351;
	if (yych == 'n') goto yy351;
	goto yy37;
yy215:
	yych = *++cur;
	if (yybm[0+yych] & 32) {
		goto yy215;
	}
	if (yych == '"') goto yy352;
	goto yy59;
yy216:
	yych = *++cur;
	if (yych == '\'') goto yy353;
	if (yych <= '/') goto yy59;
	if (yych <= '1') goto yy216;
	goto yy59;
yy217:
	yych = *++cur;
	if (yych == 'K') goto yy354;
	if (yych == 'k') goto yy354;
	goto yy37;
yy218:
	yych = *++cur;
	if (yych == 'D') goto yy355;
	if (yych == 'd') goto yy355;
	goto yy37;
yy219:
	yych = *++cur;
	if (yych == 'C') goto yy356;
	if (yych == 'c') goto yy356;
	goto yy37;
yy220:
	yych = *++cur;
	if (yych == 'L') goto yy357;
	if (yych == 'l') goto yy357;
	goto yy37;
yy221:
	yych = *++cur;
	if (yych == 'E') goto yy358;
	if (yych == 'e') goto yy358;
	goto yy37;
yy222:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'N') goto yy359;
		if (yych <= 'Q') goto yy37;
		goto yy360;
	} else {
		if (yych <= 'n') {
			if (yych <= 'm') goto yy37;
			goto yy359;
		} else {
			if (yych == 'r') goto yy360;
			goto yy37;
		}
	}
yy223:
	yych = *++cur;
	if (yych == 'S') goto yy361;
	if (yych == 's') goto yy361;
	goto yy37;
yy224:
	yych = *++cur;
	if (yych == 'S') goto yy362;
	if (yych == 's') goto yy362;
	goto yy37;
yy225:
	yych = *++cur;
	if (yych == 'I') goto yy363;
	if (yych == 'i') goto yy363;
	goto yy37;
yy226:
	yych = *++cur;
	if (yych <= 'P') {
		if (yych == 'M') goto yy364;
		if (yych <= 'O') goto yy37;
		goto yy365;
	} else {
		if (yych <= 'm') {
			if (yych <= 'l') goto yy37;
			goto yy364;
		} else {
			if (yych == 'p') goto yy365;
			goto yy37;
		}
	}
yy227:
	yych = *++cur;
	if (yych <= 'T') {
		if (yych == 'C') goto yy366;
		if (yych <= 'S') goto yy37;
		goto yy367;
	} else {
		if (yych <= 'c') {
			if (yych <= 'b') goto yy37;
			goto yy366;
		} else {
			if (yych == 't') goto yy367;
			goto yy37;
		}
	}
yy228:
	yych = *++cur;
	if (yych == 'T') goto yy368;
	if (yych == 't') goto yy368;
	goto yy37;
yy229:
	yych = *++cur;
	if (yych == 'L') goto yy369;
	if (yych == 'l') goto yy369;
	goto yy37;
yy230:
	yych = *++cur;
	if (yych == 'A') goto yy370;
	if (yych == 'a') goto yy370;
	goto yy37;
yy231:
	yych = *++cur;
	if (yych == 'L') goto yy371;
	if (yych == 'l') goto yy371;
	goto yy37;
yy232:
	yych = *++cur;
	if (yych <= 'E') {
		if (yych == 'A') goto yy372;
		if (yych <= 'D') goto yy37;
		goto yy373;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy372;
		} else {
			if (yych == 'e') goto yy373;
			goto yy37;
		}
	}
yy233:
	yych = *++cur;
	if (yych == 'E') goto yy374;
	if (yych == 'e') goto yy374;
	goto yy37;
yy234:
	yych = *++cur;
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy59;
			goto yy234;
		} else {
			if (yych == '\v') goto yy234;
			goto yy59;
		}
	} else {
		if (yych <= ' ') {
			if (yych <= '\r') goto yy234;
			if (yych <= 0x1F) goto yy59;
			goto yy234;
		} else {
			if (yych <= '/') goto yy59;
			if (yych <= '9') goto yy375;
			goto yy59;
		}
	}
yy235:
	yych = *++cur;
	if (yych == 'B') goto yy377;
	if (yych == 'b') goto yy377;
	goto yy37;
yy236:
	yych = *++cur;
	if (yych == 'H') goto yy378;
	if (yych == 'h') goto yy378;
	goto yy37;
yy237:
	yych = *++cur;
	if (yych == 'M') goto yy379;
	if (yych == 'm') goto yy379;
	goto yy37;
yy238:
	yych = *++cur;
	if (yych == 'E') goto yy380;
	if (yych == 'e') goto yy380;
	goto yy37;
yy239:
	yyaccept = 10;
	yych = *(mar = ++cur);
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	switch (yych) {
		case '\t':
		case '\v':
		case '\r': goto yy382;
		case ' ': goto yy384;
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
		case '5':
		case '6':
		case '7':
		case '8':
		case '9':
		case 'G':
		case 'H':
		case 'J':
		case 'K':
		case 'L':
		case 'N':
		case 'O':
		case 'Q':
		case 'R':
		case 'U':
		case 'V':
		case 'X':
		case 'Y':
		case 'Z':
		case 'g':
		case 'h':
		case 'j':
		case 'k':
		case 'l':
		case 'n':
		case 'o':
		case 'q':
		case 'r':
		case 'u':
		case 'v':
		case 'x':
		case 'y':
		case 'z': goto yy36;
		case 'A':
		case 'a': goto yy385;
		case 'B':
		case 'b': goto yy386;
		case 'C':
		case 'c': goto yy387;
		case 'D':
		case 'd': goto yy388;
		case 'E':
		case 'e': goto yy389;
		case 'F':
		case 'f': goto yy390;
		case 'I':
		case 'i': goto yy391;
		case 'M':
		case 'm': goto yy392;
		case 'P':
		case 'p': goto yy393;
		case 'S':
		case 's': goto yy394;
		case 'T':
		case 't': goto yy395;
		case 'W':
		case 'w': goto yy396;
		default: goto yy240;
	}
yy240:
#line 301 "tokenizer.re"
	{ KW(END) }
#line 2861 "tokenizer.cpp"
yy241:
	yych = *++cur;
	if (yych == 'R') goto yy397;
	if (yych == 'r') goto yy397;
	goto yy37;
yy242:
	yych = *++cur;
	if (yych == 'M') goto yy398;
	if (yych == 'm') goto yy398;
	goto yy37;
yy243:
	yych = *++cur;
	if (yych == 'I') goto yy400;
	if (yych == 'i') goto yy400;
	goto yy37;
yy244:
	yych = *++cur;
	if (yych <= 'O') {
		if (yych == 'M') goto yy401;
		if (yych <= 'N') goto yy37;
		goto yy402;
	} else {
		if (yych <= 'm') {
			if (yych <= 'l') goto yy37;
			goto yy401;
		} else {
			if (yych == 'o') goto yy402;
			goto yy37;
		}
	}
yy245:
	yych = *++cur;
	if (yych == 'N') goto yy403;
	if (yych == 'n') goto yy403;
	goto yy37;
yy246:
	yych = *++cur;
	if (yych == 'T') goto yy404;
	if (yych == 't') goto yy404;
	goto yy37;
yy247:
	yych = *++cur;
	if (yych == 'E') goto yy405;
	if (yych == 'e') goto yy405;
	goto yy37;
yy248:
	yych = *++cur;
	if (yych == 'E') goto yy406;
	if (yych == 'e') goto yy406;
	goto yy37;
yy249:
	yych = *++cur;
	if (yych == 'A') goto yy407;
	if (yych == 'a') goto yy407;
	goto yy37;
yy250:
	yych = *++cur;
	if (yych == 'S') goto yy408;
	if (yych == 's') goto yy408;
	goto yy37;
yy251:
	yych = *++cur;
	if (yych <= 'M') {
		if (yych == 'A') goto yy409;
		if (yych <= 'L') goto yy37;
		goto yy410;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy409;
		} else {
			if (yych == 'm') goto yy410;
			goto yy37;
		}
	}
yy252:
	yych = *++cur;
	if (yych == 'C') goto yy412;
	if (yych == 'c') goto yy412;
	goto yy37;
yy253:
	yych = *++cur;
	if (yych == 'E') goto yy413;
	if (yych == 'e') goto yy413;
	goto yy37;
yy254:
	yych = *++cur;
	if (yych == 'O') goto yy414;
	if (yych == 'o') goto yy414;
	goto yy37;
yy255:
	yych = *++cur;
	if (yych == 'G') goto yy415;
	if (yych == 'g') goto yy415;
	goto yy37;
yy256:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych <= 'N') {
			if (yych == 'L') goto yy416;
			goto yy37;
		} else {
			if (yych <= 'O') goto yy417;
			if (yych <= 'T') goto yy37;
			goto yy418;
		}
	} else {
		if (yych <= 'n') {
			if (yych == 'l') goto yy416;
			goto yy37;
		} else {
			if (yych <= 'o') goto yy417;
			if (yych == 'u') goto yy418;
			goto yy37;
		}
	}
yy257:
	yych = *++cur;
	if (yych <= '\r') {
		if (yych <= '\n') {
			if (yych == '\t') goto yy257;
			goto yy59;
		} else {
			if (yych == '\f') goto yy59;
			goto yy257;
		}
	} else {
		if (yych <= 'N') {
			if (yych == ' ') goto yy257;
			goto yy59;
		} else {
			if (yych <= 'O') goto yy419;
			if (yych == 'o') goto yy419;
			goto yy59;
		}
	}
yy258:
	yych = *++cur;
	if (yych == 'L') goto yy420;
	if (yych == 'l') goto yy420;
	goto yy37;
yy259:
	yych = *++cur;
	if (yych == 'U') goto yy421;
	if (yych == 'u') goto yy421;
	goto yy37;
yy260:
	yych = *++cur;
	if (yych == 'U') goto yy422;
	if (yych == 'u') goto yy422;
	goto yy37;
yy261:
	yych = *++cur;
	if (yych == 'T') goto yy423;
	if (yych == 't') goto yy423;
	goto yy37;
yy262:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'E') goto yy424;
		if (yych <= 'Q') goto yy37;
		goto yy425;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy424;
		} else {
			if (yych == 'r') goto yy425;
			goto yy37;
		}
	}
yy263:
	yych = *++cur;
	if (yych == 'D') goto yy426;
	if (yych == 'd') goto yy426;
	goto yy37;
yy264:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 427 "tokenizer.re"
	{ KW(LEN) }
#line 3046 "tokenizer.cpp"
yy265:
	yych = *++cur;
	if (yych == 'A') goto yy427;
	if (yych == 'a') goto yy427;
	goto yy37;
yy266:
	yych = *++cur;
	if (yych == 'I') goto yy428;
	if (yych == 'i') goto yy428;
	goto yy37;
yy267:
	yych = *++cur;
	if (yych == 'O') goto yy429;
	if (yych == 'o') goto yy429;
	goto yy37;
yy268:
	yych = *++cur;
	if (yych == 'U') goto yy430;
	if (yych == 'u') goto yy430;
	goto yy37;
yy269:
	yych = *++cur;
	if (yych == 'D') goto yy431;
	if (yych == 'd') goto yy431;
	goto yy37;
yy270:
	yych = *++cur;
	if (yych == 'E') goto yy432;
	if (yych == 'e') goto yy432;
	goto yy37;
yy271:
	yych = *++cur;
	if (yych == '_') goto yy434;
	goto yy37;
yy272:
	yych = *++cur;
	if (yych <= '^') {
		if (yych == 'E') goto yy435;
		goto yy37;
	} else {
		if (yych <= '_') goto yy436;
		if (yych == 'e') goto yy435;
		goto yy37;
	}
yy273:
	yych = *++cur;
	if (yych == 'A') goto yy437;
	if (yych == 'a') goto yy437;
	goto yy37;
yy274:
	yych = *++cur;
	if (yych == 'L') goto yy438;
	if (yych == 'l') goto yy438;
	goto yy37;
yy275:
	yych = *++cur;
	if (yybm[0+yych] & 64) {
		goto yy275;
	}
	if (yych == '"') goto yy439;
	goto yy59;
yy276:
	yych = *++cur;
	if (yych == '\'') goto yy440;
	if (yych <= '/') goto yy59;
	if (yych <= '7') goto yy276;
	goto yy59;
yy277:
	yych = *++cur;
	if (yych == 'Y') goto yy441;
	if (yych == 'y') goto yy441;
	goto yy37;
yy278:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'N') goto yy442;
		if (yych <= 'Q') goto yy37;
		goto yy443;
	} else {
		if (yych <= 'n') {
			if (yych <= 'm') goto yy37;
			goto yy442;
		} else {
			if (yych == 'r') goto yy443;
			goto yy37;
		}
	}
yy279:
	yych = *++cur;
	if (yych == 'I') goto yy444;
	if (yych == 'i') goto yy444;
	goto yy37;
yy280:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 447 "tokenizer.re"
	{ KW(OUT) }
#line 3147 "tokenizer.cpp"
yy281:
	yych = *++cur;
	if (yych == 'A') goto yy445;
	if (yych == 'a') goto yy445;
	goto yy37;
yy282:
	yych = *++cur;
	if (yych == 'S') goto yy446;
	if (yych == 's') goto yy446;
	goto yy37;
yy283:
	yych = *++cur;
	if (yych == 'N') goto yy447;
	if (yych == 'n') goto yy447;
	goto yy37;
yy284:
	yych = *++cur;
	if (yych == 'T') goto yy448;
	if (yych == 't') goto yy448;
	goto yy37;
yy285:
	yych = *++cur;
	if (yych == 'C') goto yy449;
	if (yych == 'c') goto yy449;
	goto yy37;
yy286:
	yych = *++cur;
	if (yych <= 'V') {
		if (yych == 'N') goto yy450;
		if (yych <= 'U') goto yy37;
		goto yy451;
	} else {
		if (yych <= 'n') {
			if (yych <= 'm') goto yy37;
			goto yy450;
		} else {
			if (yych == 'v') goto yy451;
			goto yy37;
		}
	}
yy287:
	yych = *++cur;
	if (yych <= 'T') {
		if (yych <= 'F') {
			if (yych == 'C') goto yy452;
			goto yy37;
		} else {
			if (yych <= 'G') goto yy453;
			if (yych <= 'S') goto yy37;
			goto yy454;
		}
	} else {
		if (yych <= 'f') {
			if (yych == 'c') goto yy452;
			goto yy37;
		} else {
			if (yych <= 'g') goto yy453;
			if (yych == 't') goto yy454;
			goto yy37;
		}
	}
yy288:
	yych = *++cur;
	if (yych == 'L') goto yy455;
	if (yych == 'l') goto yy455;
	goto yy37;
yy289:
	yych = *++cur;
	if (yych == 'E') goto yy456;
	if (yych == 'e') goto yy456;
	goto yy37;
yy290:
	yych = *++cur;
	if (yych == 'E') goto yy457;
	if (yych == 'e') goto yy457;
	goto yy37;
yy291:
	yych = *++cur;
	if (yych == 'K') goto yy458;
	if (yych == 'k') goto yy458;
	goto yy37;
yy292:
	yych = *++cur;
	if (yych <= 'L') {
		if (yych == 'D') goto yy459;
		if (yych <= 'K') goto yy37;
		goto yy460;
	} else {
		if (yych <= 'd') {
			if (yych <= 'c') goto yy37;
			goto yy459;
		} else {
			if (yych == 'l') goto yy460;
			goto yy37;
		}
	}
yy293:
	yych = *++cur;
	if (yych == 'U') goto yy461;
	if (yych == 'u') goto yy461;
	goto yy37;
yy294:
	yych = *++cur;
	if (yych == 'U') goto yy462;
	if (yych == 'u') goto yy462;
	goto yy37;
yy295:
	yych = *++cur;
	if (yych == 'U') goto yy463;
	if (yych == 'u') goto yy463;
	goto yy37;
yy296:
	yych = *++cur;
	if (yych == 'U') goto yy464;
	if (yych == 'u') goto yy464;
	goto yy37;
yy297:
	yych = *++cur;
	if (yych == 'U') goto yy465;
	if (yych == 'u') goto yy465;
	goto yy37;
yy298:
	yych = *++cur;
	if (yych == 'I') goto yy466;
	if (yych == 'i') goto yy466;
	goto yy37;
yy299:
	yych = *++cur;
	if (yych == 'E') goto yy467;
	if (yych == 'e') goto yy467;
	goto yy37;
yy300:
	yych = *++cur;
	if (yych == 'E') goto yy468;
	if (yych == 'e') goto yy468;
	goto yy37;
yy301:
	yych = *++cur;
	if (yych == 'U') goto yy469;
	if (yych == 'u') goto yy469;
	goto yy37;
yy302:
	yych = *++cur;
	if (yych == 'R') goto yy470;
	if (yych == 'r') goto yy470;
	goto yy37;
yy303:
	yych = *++cur;
	if (yych == 'R') goto yy471;
	if (yych == 'r') goto yy471;
	goto yy37;
yy304:
	yych = *++cur;
	if (yych == 'T') goto yy472;
	if (yych == 't') goto yy472;
	goto yy37;
yy305:
	yych = *++cur;
	if (yych == 'P') goto yy473;
	if (yych == 'p') goto yy473;
	goto yy37;
yy306:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'M') goto yy474;
		if (yych <= 'Q') goto yy37;
		goto yy475;
	} else {
		if (yych <= 'm') {
			if (yych <= 'l') goto yy37;
			goto yy474;
		} else {
			if (yych == 'r') goto yy475;
			goto yy37;
		}
	}
yy307:
	yych = *++cur;
	if (yych == 'C') goto yy476;
	if (yych == 'c') goto yy476;
	goto yy37;
yy308:
	yych = *++cur;
	if (yych == 'G') goto yy478;
	if (yych == 'g') goto yy478;
	goto yy37;
yy309:
	yych = *++cur;
	if (yych == 'M') goto yy479;
	if (yych == 'm') goto yy479;
	goto yy37;
yy310:
	yych = *++cur;
	if (yych == 'P') goto yy480;
	if (yych == 'p') goto yy480;
	goto yy37;
yy311:
	yych = *++cur;
	if (yych == 'N') goto yy481;
	if (yych == 'n') goto yy481;
	goto yy37;
yy312:
	yych = *++cur;
	if (yych == 'E') goto yy482;
	if (yych == 'e') goto yy482;
	goto yy37;
yy313:
	yych = *++cur;
	if (yych == 'O') goto yy483;
	if (yych == 'o') goto yy483;
	goto yy37;
yy314:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 496 "tokenizer.re"
	{ KW(USE) }
#line 3367 "tokenizer.cpp"
yy315:
	yych = *++cur;
	if (yych == 'U') goto yy484;
	if (yych == 'u') goto yy484;
	goto yy37;
yy316:
	yych = *++cur;
	if (yych == 'A') goto yy485;
	if (yych == 'a') goto yy485;
	goto yy37;
yy317:
	yych = *++cur;
	if (yych == 'T') goto yy486;
	if (yych == 't') goto yy486;
	goto yy37;
yy318:
	yych = *++cur;
	if (yych == 'R') goto yy487;
	if (yych == 'r') goto yy487;
	goto yy37;
yy319:
	yych = *++cur;
	if (yych == 'L') goto yy488;
	if (yych == 'l') goto yy488;
	goto yy37;
yy320:
	yych = *++cur;
	if (yych == 'T') goto yy489;
	if (yych == 't') goto yy489;
	goto yy37;
yy321:
	yych = *++cur;
yy322:
	if (yybm[0+yych] & 128) {
		goto yy321;
	}
	if (yych == '"') goto yy490;
	goto yy59;
yy323:
	yych = *++cur;
yy324:
	if (yych <= '9') {
		if (yych == '\'') goto yy491;
		if (yych <= '/') goto yy59;
		goto yy323;
	} else {
		if (yych <= 'F') {
			if (yych <= '@') goto yy59;
			goto yy323;
		} else {
			if (yych <= '`') goto yy59;
			if (yych <= 'f') goto yy323;
			goto yy59;
		}
	}
yy325:
	++cur;
	cur = ctxmar;
#line 524 "tokenizer.re"
	{ RET(TK_LPAREN) }
#line 3428 "tokenizer.cpp"
yy326:
	yych = *++cur;
yy327:
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy59;
			goto yy326;
		} else {
			if (yych == '\v') goto yy326;
			goto yy59;
		}
	} else {
		if (yych <= ' ') {
			if (yych <= '\r') goto yy326;
			if (yych <= 0x1F) goto yy59;
			goto yy326;
		} else {
			if (yych == ')') goto yy492;
			goto yy59;
		}
	}
yy328:
	++cur;
	cur -= 3;
#line 527 "tokenizer.re"
	{ RET(TK_LPAREN) }
#line 3455 "tokenizer.cpp"
yy329:
	yych = *++cur;
	if (yych <= '/') goto yy79;
	if (yych <= '9') goto yy329;
	goto yy79;
yy330:
	yych = *++cur;
	if (yych <= 'Z') {
		if (yych <= '/') goto yy79;
		if (yych <= '9') goto yy330;
		if (yych <= '@') goto yy79;
		goto yy330;
	} else {
		if (yych <= '_') {
			if (yych <= '^') goto yy79;
			goto yy330;
		} else {
			if (yych <= '`') goto yy79;
			if (yych <= 'z') goto yy330;
			goto yy79;
		}
	}
yy331:
	yych = *++cur;
	if (yych == '.') goto yy493;
	goto yy82;
yy332:
	++cur;
#line 552 "tokenizer.re"
	{ WARN_REL(EQ) RET(TK_EQ) }
#line 3486 "tokenizer.cpp"
yy333:
	yych = *++cur;
	if (yych == '.') goto yy494;
	goto yy82;
yy334:
	yych = *++cur;
	if (yych == 'S') goto yy495;
	if (yych == 's') goto yy495;
	goto yy82;
yy335:
	++cur;
#line 567 "tokenizer.re"
	{ WARN_REL(GE) RET(TK_GE) }
#line 3500 "tokenizer.cpp"
yy336:
	++cur;
#line 564 "tokenizer.re"
	{ WARN_REL(GT) RET(TK_GT) }
#line 3505 "tokenizer.cpp"
yy337:
	++cur;
#line 561 "tokenizer.re"
	{ WARN_REL(LE) RET(TK_LE) }
#line 3510 "tokenizer.cpp"
yy338:
	++cur;
#line 558 "tokenizer.re"
	{ WARN_REL(LT) RET(TK_LT) }
#line 3515 "tokenizer.cpp"
yy339:
	++cur;
#line 555 "tokenizer.re"
	{ WARN_REL(NE) RET(TK_NE) }
#line 3520 "tokenizer.cpp"
yy340:
	yych = *++cur;
	if (yych == 'V') goto yy496;
	if (yych == 'v') goto yy496;
	goto yy82;
yy341:
	yych = *++cur;
	if (yych == '.') goto yy497;
	goto yy82;
yy342:
	++cur;
#line 573 "tokenizer.re"
	{ RET(TK_OR) }
#line 3534 "tokenizer.cpp"
yy343:
	yych = *++cur;
	if (yych == 'E') goto yy498;
	if (yych == 'e') goto yy498;
	goto yy82;
yy344:
	yych = *++cur;
	if (yych == '.') goto yy499;
	goto yy82;
yy345:
	++cur;
	cur = ctxmar;
#line 588 "tokenizer.re"
	{
                lex_int_large(al, tok, cur,
                    yylval.int_suffix.int_n,
                    yylval.int_suffix.int_kind);
                RET(TK_INTEGER)
            }
#line 3554 "tokenizer.cpp"
yy346:
	yych = *++cur;
	if (yych == '.') goto yy59;
	goto yy204;
yy347:
	yych = *++cur;
	if (yych == 'R') goto yy500;
	if (yych == 'r') goto yy500;
	goto yy37;
yy348:
	yych = *++cur;
	if (yych == 'C') goto yy501;
	if (yych == 'c') goto yy501;
	goto yy37;
yy349:
	yych = *++cur;
	if (yych == 'G') goto yy502;
	if (yych == 'g') goto yy502;
	goto yy37;
yy350:
	yych = *++cur;
	if (yych == 'C') goto yy503;
	if (yych == 'c') goto yy503;
	goto yy37;
yy351:
	yych = *++cur;
	if (yych == 'C') goto yy504;
	if (yych == 'c') goto yy504;
	goto yy37;
yy352:
	++cur;
#line 632 "tokenizer.re"
	{ token(yylval.string); RET(TK_BOZ_CONSTANT) }
#line 3588 "tokenizer.cpp"
yy353:
	++cur;
#line 633 "tokenizer.re"
	{ token(yylval.string); RET(TK_BOZ_CONSTANT) }
#line 3593 "tokenizer.cpp"
yy354:
	yych = *++cur;
	if (yych == 'S') goto yy505;
	if (yych == 's') goto yy505;
	goto yy37;
yy355:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 261 "tokenizer.re"
	{ KW(BIND) }
#line 3607 "tokenizer.cpp"
yy356:
	yych = *++cur;
	if (yych == 'K') goto yy506;
	if (yych == 'k') goto yy506;
	goto yy37;
yy357:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 263 "tokenizer.re"
	{ KW(CALL) }
#line 3621 "tokenizer.cpp"
yy358:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 264 "tokenizer.re"
	{ KW(CASE) }
#line 3630 "tokenizer.cpp"
yy359:
	yych = *++cur;
	if (yych == 'G') goto yy507;
	if (yych == 'g') goto yy507;
	goto yy37;
yy360:
	yych = *++cur;
	if (yych == 'A') goto yy508;
	if (yych == 'a') goto yy508;
	goto yy37;
yy361:
	yych = *++cur;
	if (yych == 'S') goto yy509;
	if (yych == 's') goto yy509;
	goto yy37;
yy362:
	yych = *++cur;
	if (yych == 'E') goto yy510;
	if (yych == 'e') goto yy510;
	goto yy37;
yy363:
	yych = *++cur;
	if (yych == 'M') goto yy511;
	if (yych == 'm') goto yy511;
	goto yy37;
yy364:
	yych = *++cur;
	if (yych == 'O') goto yy512;
	if (yych == 'o') goto yy512;
	goto yy37;
yy365:
	yych = *++cur;
	if (yych == 'L') goto yy513;
	if (yych == 'l') goto yy513;
	goto yy37;
yy366:
	yych = *++cur;
	if (yych == 'U') goto yy514;
	if (yych == 'u') goto yy514;
	goto yy37;
yy367:
	yych = *++cur;
	if (yych <= 'I') {
		if (yych == 'A') goto yy515;
		if (yych <= 'H') goto yy37;
		goto yy516;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy515;
		} else {
			if (yych == 'i') goto yy516;
			goto yy37;
		}
	}
yy368:
	yych = *++cur;
	if (yych == 'I') goto yy517;
	if (yych == 'i') goto yy517;
	goto yy37;
yy369:
	yych = *++cur;
	if (yych == 'E') goto yy518;
	if (yych == 'e') goto yy518;
	goto yy37;
yy370:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 279 "tokenizer.re"
	{ KW(DATA) }
#line 3704 "tokenizer.cpp"
yy371:
	yych = *++cur;
	if (yych == 'L') goto yy519;
	if (yych == 'l') goto yy519;
	goto yy37;
yy372:
	yych = *++cur;
	if (yych == 'U') goto yy520;
	if (yych == 'u') goto yy520;
	goto yy37;
yy373:
	yych = *++cur;
	if (yych == 'R') goto yy521;
	if (yych == 'r') goto yy521;
	goto yy37;
yy374:
	yych = *++cur;
	if (yych == 'N') goto yy522;
	if (yych == 'n') goto yy522;
	goto yy37;
yy375:
	yych = *++cur;
	if (yych <= '/') goto yy376;
	if (yych <= '9') goto yy375;
yy376:
	cur = ctxmar;
#line 284 "tokenizer.re"
	{
                // This is a label do statement, we have to match the
                // corresponding continue base "end do".
                uint64_t n = parse_int(cur);
                enddo_label_stack.push_back(n);
                KW(DO);
            }
#line 3739 "tokenizer.cpp"
yy377:
	yych = *++cur;
	if (yych == 'L') goto yy523;
	if (yych == 'l') goto yy523;
	goto yy37;
yy378:
	yych = *++cur;
	if (yych == 'I') goto yy524;
	if (yych == 'i') goto yy524;
	goto yy37;
yy379:
	yych = *++cur;
	if (yych == 'E') goto yy525;
	if (yych == 'e') goto yy525;
	goto yy37;
yy380:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'W') {
		if (yych <= '@') {
			if (yych <= '/') goto yy381;
			if (yych <= '9') goto yy36;
		} else {
			if (yych == 'I') goto yy526;
			if (yych <= 'V') goto yy36;
			goto yy527;
		}
	} else {
		if (yych <= 'i') {
			if (yych <= 'Z') goto yy36;
			if (yych <= '`') goto yy381;
			if (yych <= 'h') goto yy36;
			goto yy526;
		} else {
			if (yych == 'w') goto yy527;
			if (yych <= 'z') goto yy36;
		}
	}
yy381:
#line 297 "tokenizer.re"
	{ KW(ELSE) }
#line 3783 "tokenizer.cpp"
yy382:
	yych = *++cur;
yy383:
	switch (yych) {
		case '\t':
		case '\v':
		case '\r':
		case ' ': goto yy382;
		case 'A':
		case 'a': goto yy528;
		case 'B':
		case 'b': goto yy529;
		case 'C':
		case 'c': goto yy530;
		case 'D':
		case 'd': goto yy531;
		case 'E':
		case 'e': goto yy532;
		case 'F':
		case 'f': goto yy533;
		case 'I':
		case 'i': goto yy534;
		case 'M':
		case 'm': goto yy535;
		case 'P':
		case 'p': goto yy536;
		case 'S':
		case 's': goto yy537;
		case 'T':
		case 't': goto yy538;
		case 'W':
		case 'w': goto yy539;
		default: goto yy59;
	}
yy384:
	yych = *++cur;
	if (yych == 'F') goto yy540;
	if (yych == 'f') goto yy540;
	goto yy383;
yy385:
	yych = *++cur;
	if (yych == 'S') goto yy541;
	if (yych == 's') goto yy541;
	goto yy37;
yy386:
	yych = *++cur;
	if (yych == 'L') goto yy542;
	if (yych == 'l') goto yy542;
	goto yy37;
yy387:
	yych = *++cur;
	if (yych == 'R') goto yy543;
	if (yych == 'r') goto yy543;
	goto yy37;
yy388:
	yych = *++cur;
	if (yych == 'O') goto yy544;
	if (yych == 'o') goto yy544;
	goto yy37;
yy389:
	yych = *++cur;
	if (yych == 'N') goto yy545;
	if (yych == 'n') goto yy545;
	goto yy37;
yy390:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych <= 'N') {
			if (yych == 'I') goto yy546;
			goto yy37;
		} else {
			if (yych <= 'O') goto yy547;
			if (yych <= 'T') goto yy37;
			goto yy548;
		}
	} else {
		if (yych <= 'n') {
			if (yych == 'i') goto yy546;
			goto yy37;
		} else {
			if (yych <= 'o') goto yy547;
			if (yych == 'u') goto yy548;
			goto yy37;
		}
	}
yy391:
	yych = *++cur;
	if (yych <= 'N') {
		if (yych == 'F') goto yy549;
		if (yych <= 'M') goto yy37;
		goto yy550;
	} else {
		if (yych <= 'f') {
			if (yych <= 'e') goto yy37;
			goto yy549;
		} else {
			if (yych == 'n') goto yy550;
			goto yy37;
		}
	}
yy392:
	yych = *++cur;
	if (yych == 'O') goto yy551;
	if (yych == 'o') goto yy551;
	goto yy37;
yy393:
	yych = *++cur;
	if (yych == 'R') goto yy552;
	if (yych == 'r') goto yy552;
	goto yy37;
yy394:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych == 'E') goto yy553;
		if (yych <= 'T') goto yy37;
		goto yy554;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy553;
		} else {
			if (yych == 'u') goto yy554;
			goto yy37;
		}
	}
yy395:
	yych = *++cur;
	if (yych <= 'Y') {
		if (yych == 'E') goto yy555;
		if (yych <= 'X') goto yy37;
		goto yy556;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy37;
			goto yy555;
		} else {
			if (yych == 'y') goto yy556;
			goto yy37;
		}
	}
yy396:
	yych = *++cur;
	if (yych == 'H') goto yy557;
	if (yych == 'h') goto yy557;
	goto yy37;
yy397:
	yych = *++cur;
	if (yych == 'Y') goto yy558;
	if (yych == 'y') goto yy558;
	goto yy37;
yy398:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'E') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy399;
			if (yych <= 'D') goto yy36;
			goto yy559;
		}
	} else {
		if (yych <= 'd') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 'e') goto yy559;
			if (yych <= 'z') goto yy36;
		}
	}
yy399:
#line 378 "tokenizer.re"
	{ KW(ENUM) }
#line 3959 "tokenizer.cpp"
yy400:
	yych = *++cur;
	if (yych == 'V') goto yy560;
	if (yych == 'v') goto yy560;
	goto yy37;
yy401:
	yych = *++cur;
	if (yych == 'S') goto yy561;
	if (yych == 's') goto yy561;
	goto yy37;
yy402:
	yych = *++cur;
	if (yych == 'R') goto yy562;
	if (yych == 'r') goto yy562;
	goto yy37;
yy403:
	yych = *++cur;
	if (yych == 'T') goto yy563;
	if (yych == 't') goto yy563;
	goto yy37;
yy404:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 384 "tokenizer.re"
	{ KW(EXIT) }
#line 3988 "tokenizer.cpp"
yy405:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'N') goto yy564;
		if (yych <= 'Q') goto yy37;
		goto yy565;
	} else {
		if (yych <= 'n') {
			if (yych <= 'm') goto yy37;
			goto yy564;
		} else {
			if (yych == 'r') goto yy565;
			goto yy37;
		}
	}
yy406:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 387 "tokenizer.re"
	{ KW(FILE) }
#line 4012 "tokenizer.cpp"
yy407:
	yych = *++cur;
	if (yych == 'L') goto yy566;
	if (yych == 'l') goto yy566;
	goto yy37;
yy408:
	yych = *++cur;
	if (yych == 'H') goto yy567;
	if (yych == 'h') goto yy567;
	goto yy37;
yy409:
	yych = *++cur;
	if (yych == 'L') goto yy568;
	if (yych == 'l') goto yy568;
	goto yy37;
yy410:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'T') {
		if (yych <= '@') {
			if (yych <= '/') goto yy411;
			if (yych <= '9') goto yy36;
		} else {
			if (yych <= 'A') goto yy569;
			if (yych <= 'S') goto yy36;
			goto yy570;
		}
	} else {
		if (yych <= 'a') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy569;
		} else {
			if (yych == 't') goto yy570;
			if (yych <= 'z') goto yy36;
		}
	}
yy411:
#line 404 "tokenizer.re"
	{ KW(FORM) }
#line 4054 "tokenizer.cpp"
yy412:
	yych = *++cur;
	if (yych == 'T') goto yy571;
	if (yych == 't') goto yy571;
	goto yy37;
yy413:
	yych = *++cur;
	if (yych == 'R') goto yy572;
	if (yych == 'r') goto yy572;
	goto yy37;
yy414:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 409 "tokenizer.re"
	{ KW(GOTO) }
#line 4073 "tokenizer.cpp"
yy415:
	yych = *++cur;
	if (yych == 'E') goto yy573;
	if (yych == 'e') goto yy573;
	goto yy37;
yy416:
	yych = *++cur;
	if (yych == 'I') goto yy574;
	if (yych == 'i') goto yy574;
	goto yy37;
yy417:
	yych = *++cur;
	if (yych == 'R') goto yy575;
	if (yych == 'r') goto yy575;
	goto yy37;
yy418:
	yych = *++cur;
	if (yych == 'R') goto yy576;
	if (yych == 'r') goto yy576;
	goto yy37;
yy419:
	yych = *++cur;
	if (yych == 'U') goto yy577;
	if (yych == 'u') goto yy577;
	goto yy59;
yy420:
	yych = *++cur;
	if (yych == 'U') goto yy578;
	if (yych == 'u') goto yy578;
	goto yy37;
yy421:
	yych = *++cur;
	if (yych == 'T') goto yy579;
	if (yych == 't') goto yy579;
	goto yy37;
yy422:
	yych = *++cur;
	if (yych == 'I') goto yy580;
	if (yych == 'i') goto yy580;
	goto yy37;
yy423:
	yych = *++cur;
	if (yych == 'A') goto yy581;
	if (yych == 'a') goto yy581;
	goto yy37;
yy424:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych <= 'M') {
			if (yych == 'G') goto yy582;
			goto yy37;
		} else {
			if (yych <= 'N') goto yy583;
			if (yych <= 'Q') goto yy37;
			goto yy584;
		}
	} else {
		if (yych <= 'm') {
			if (yych == 'g') goto yy582;
			goto yy37;
		} else {
			if (yych <= 'n') goto yy583;
			if (yych == 'r') goto yy584;
			goto yy37;
		}
	}
yy425:
	yych = *++cur;
	if (yych == 'I') goto yy585;
	if (yych == 'i') goto yy585;
	goto yy37;
yy426:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 426 "tokenizer.re"
	{ KW(KIND) }
#line 4153 "tokenizer.cpp"
yy427:
	yych = *++cur;
	if (yych == 'L') goto yy586;
	if (yych == 'l') goto yy586;
	goto yy37;
yy428:
	yych = *++cur;
	if (yych == 'C') goto yy587;
	if (yych == 'c') goto yy587;
	goto yy37;
yy429:
	yych = *++cur;
	if (yych == 'R') goto yy588;
	if (yych == 'r') goto yy588;
	goto yy37;
yy430:
	yych = *++cur;
	if (yych == 'L') goto yy589;
	if (yych == 'l') goto yy589;
	goto yy37;
yy431:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 433 "tokenizer.re"
	{ KW(MOLD) }
#line 4182 "tokenizer.cpp"
yy432:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'L') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy433;
			if (yych <= 'K') goto yy36;
			goto yy590;
		}
	} else {
		if (yych <= 'k') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 'l') goto yy590;
			if (yych <= 'z') goto yy36;
		}
	}
yy433:
#line 434 "tokenizer.re"
	{ KW(NAME) }
#line 4208 "tokenizer.cpp"
yy434:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych <= '\'') {
		if (yych == '"') goto yy61;
		if (yych <= '&') goto yy37;
		goto yy71;
	} else {
		if (yych <= 'I') {
			if (yych <= 'H') goto yy37;
			goto yy591;
		} else {
			if (yych == 'i') goto yy591;
			goto yy37;
		}
	}
yy435:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 441 "tokenizer.re"
	{ KW(NONE) }
#line 4233 "tokenizer.cpp"
yy436:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych <= 'O') {
		if (yych <= '\'') {
			if (yych == '"') goto yy61;
			if (yych <= '&') goto yy37;
			goto yy71;
		} else {
			if (yych == 'I') goto yy592;
			if (yych <= 'N') goto yy37;
			goto yy593;
		}
	} else {
		if (yych <= 'i') {
			if (yych == 'R') goto yy594;
			if (yych <= 'h') goto yy37;
			goto yy592;
		} else {
			if (yych <= 'o') {
				if (yych <= 'n') goto yy37;
				goto yy593;
			} else {
				if (yych == 'r') goto yy594;
				goto yy37;
			}
		}
	}
yy437:
	yych = *++cur;
	if (yych == 'S') goto yy595;
	if (yych == 's') goto yy595;
	goto yy37;
yy438:
	yych = *++cur;
	if (yych == 'I') goto yy596;
	if (yych == 'i') goto yy596;
	goto yy37;
yy439:
	++cur;
#line 634 "tokenizer.re"
	{ token(yylval.string); RET(TK_BOZ_CONSTANT) }
#line 4276 "tokenizer.cpp"
yy440:
	++cur;
#line 635 "tokenizer.re"
	{ token(yylval.string); RET(TK_BOZ_CONSTANT) }
#line 4281 "tokenizer.cpp"
yy441:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 443 "tokenizer.re"
	{ KW(ONLY) }
#line 4290 "tokenizer.cpp"
yy442:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 444 "tokenizer.re"
	{ KW(OPEN) }
#line 4299 "tokenizer.cpp"
yy443:
	yych = *++cur;
	if (yych == 'A') goto yy597;
	if (yych == 'a') goto yy597;
	goto yy37;
yy444:
	yych = *++cur;
	if (yych == 'O') goto yy598;
	if (yych == 'o') goto yy598;
	goto yy37;
yy445:
	yych = *++cur;
	if (yych == 'M') goto yy599;
	if (yych == 'm') goto yy599;
	goto yy37;
yy446:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 449 "tokenizer.re"
	{ KW(PASS) }
#line 4323 "tokenizer.cpp"
yy447:
	yych = *++cur;
	if (yych == 'T') goto yy600;
	if (yych == 't') goto yy600;
	goto yy37;
yy448:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 451 "tokenizer.re"
	{ KW(POST) }
#line 4337 "tokenizer.cpp"
yy449:
	yych = *++cur;
	if (yych == 'I') goto yy601;
	if (yych == 'i') goto yy601;
	goto yy37;
yy450:
	yych = *++cur;
	if (yych == 'T') goto yy602;
	if (yych == 't') goto yy602;
	goto yy37;
yy451:
	yych = *++cur;
	if (yych == 'A') goto yy603;
	if (yych == 'a') goto yy603;
	goto yy37;
yy452:
	yych = *++cur;
	if (yych == 'E') goto yy604;
	if (yych == 'e') goto yy604;
	goto yy37;
yy453:
	yych = *++cur;
	if (yych == 'R') goto yy605;
	if (yych == 'r') goto yy605;
	goto yy37;
yy454:
	yych = *++cur;
	if (yych == 'E') goto yy606;
	if (yych == 'e') goto yy606;
	goto yy37;
yy455:
	yych = *++cur;
	if (yych == 'I') goto yy607;
	if (yych == 'i') goto yy607;
	goto yy37;
yy456:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 459 "tokenizer.re"
	{ KW(PURE) }
#line 4381 "tokenizer.cpp"
yy457:
	yych = *++cur;
	if (yych == 'T') goto yy608;
	if (yych == 't') goto yy608;
	goto yy37;
yy458:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 461 "tokenizer.re"
	{ KW(RANK) }
#line 4395 "tokenizer.cpp"
yy459:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 462 "tokenizer.re"
	{ KW(READ) }
#line 4404 "tokenizer.cpp"
yy460:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 463 "tokenizer.re"
	{KW(REAL) }
#line 4413 "tokenizer.cpp"
yy461:
	yych = *++cur;
	if (yych == 'R') goto yy609;
	if (yych == 'r') goto yy609;
	goto yy37;
yy462:
	yych = *++cur;
	if (yych == 'C') goto yy610;
	if (yych == 'c') goto yy610;
	goto yy37;
yy463:
	yych = *++cur;
	if (yych == 'I') goto yy611;
	if (yych == 'i') goto yy611;
	goto yy37;
yy464:
	yych = *++cur;
	if (yych == 'L') goto yy612;
	if (yych == 'l') goto yy612;
	goto yy37;
yy465:
	yych = *++cur;
	if (yych == 'R') goto yy613;
	if (yych == 'r') goto yy613;
	goto yy37;
yy466:
	yych = *++cur;
	if (yych == 'N') goto yy614;
	if (yych == 'n') goto yy614;
	goto yy37;
yy467:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 471 "tokenizer.re"
	{ KW(SAVE) }
#line 4452 "tokenizer.cpp"
yy468:
	yych = *++cur;
	if (yych == 'C') goto yy615;
	if (yych == 'c') goto yy615;
	goto yy37;
yy469:
	yych = *++cur;
	if (yych == 'E') goto yy616;
	if (yych == 'e') goto yy616;
	goto yy37;
yy470:
	yych = *++cur;
	if (yych == 'E') goto yy617;
	if (yych == 'e') goto yy617;
	goto yy37;
yy471:
	yych = *++cur;
	if (yych == 'C') goto yy618;
	if (yych == 'c') goto yy618;
	goto yy37;
yy472:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 479 "tokenizer.re"
	{ KW(STAT) }
#line 4481 "tokenizer.cpp"
yy473:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 480 "tokenizer.re"
	{ KW(STOP) }
#line 4490 "tokenizer.cpp"
yy474:
	yych = *++cur;
	if (yych == 'O') goto yy619;
	if (yych == 'o') goto yy619;
	goto yy37;
yy475:
	yych = *++cur;
	if (yych == 'O') goto yy620;
	if (yych == 'o') goto yy620;
	goto yy37;
yy476:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'T') {
		if (yych <= 'H') {
			if (yych <= '9') {
				if (yych >= '0') goto yy36;
			} else {
				if (yych <= '@') goto yy477;
				if (yych <= 'A') goto yy621;
				goto yy36;
			}
		} else {
			if (yych <= 'L') {
				if (yych <= 'I') goto yy622;
				goto yy36;
			} else {
				if (yych <= 'M') goto yy623;
				if (yych <= 'S') goto yy36;
				goto yy624;
			}
		}
	} else {
		if (yych <= 'i') {
			if (yych <= '`') {
				if (yych <= 'Z') goto yy36;
			} else {
				if (yych <= 'a') goto yy621;
				if (yych <= 'h') goto yy36;
				goto yy622;
			}
		} else {
			if (yych <= 's') {
				if (yych == 'm') goto yy623;
				goto yy36;
			} else {
				if (yych <= 't') goto yy624;
				if (yych <= 'z') goto yy36;
			}
		}
	}
yy477:
#line 483 "tokenizer.re"
	{ KW(SYNC) }
#line 4547 "tokenizer.cpp"
yy478:
	yych = *++cur;
	if (yych == 'E') goto yy625;
	if (yych == 'e') goto yy625;
	goto yy37;
yy479:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy626;
#line 489 "tokenizer.re"
	{ KW(TEAM) }
#line 4561 "tokenizer.cpp"
yy480:
	yych = *++cur;
	if (yych == 'L') goto yy627;
	if (yych == 'l') goto yy627;
	goto yy37;
yy481:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 492 "tokenizer.re"
	{ KW(THEN) }
#line 4575 "tokenizer.cpp"
yy482:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 494 "tokenizer.re"
	{ KW(TYPE) }
#line 4584 "tokenizer.cpp"
yy483:
	yych = *++cur;
	if (yych == 'R') goto yy628;
	if (yych == 'r') goto yy628;
	goto yy37;
yy484:
	yych = *++cur;
	if (yych == 'E') goto yy629;
	if (yych == 'e') goto yy629;
	goto yy37;
yy485:
	yych = *++cur;
	if (yych == 'T') goto yy630;
	if (yych == 't') goto yy630;
	goto yy37;
yy486:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 499 "tokenizer.re"
	{ KW(WAIT) }
#line 4608 "tokenizer.cpp"
yy487:
	yych = *++cur;
	if (yych == 'E') goto yy631;
	if (yych == 'e') goto yy631;
	goto yy37;
yy488:
	yych = *++cur;
	if (yych == 'E') goto yy632;
	if (yych == 'e') goto yy632;
	goto yy37;
yy489:
	yych = *++cur;
	if (yych == 'E') goto yy633;
	if (yych == 'e') goto yy633;
	goto yy37;
yy490:
	++cur;
#line 636 "tokenizer.re"
	{ token(yylval.string); RET(TK_BOZ_CONSTANT) }
#line 4628 "tokenizer.cpp"
yy491:
	++cur;
#line 637 "tokenizer.re"
	{ token(yylval.string); RET(TK_BOZ_CONSTANT) }
#line 4633 "tokenizer.cpp"
yy492:
	++cur;
	cur = ctxmar;
#line 526 "tokenizer.re"
	{ RET(TK_LPAREN) }
#line 4639 "tokenizer.cpp"
yy493:
	++cur;
#line 572 "tokenizer.re"
	{ RET(TK_AND) }
#line 4644 "tokenizer.cpp"
yy494:
	++cur;
#line 575 "tokenizer.re"
	{ RET(TK_EQV) }
#line 4649 "tokenizer.cpp"
yy495:
	yych = *++cur;
	if (yych == 'E') goto yy634;
	if (yych == 'e') goto yy634;
	goto yy82;
yy496:
	yych = *++cur;
	if (yych == '.') goto yy635;
	goto yy82;
yy497:
	++cur;
#line 571 "tokenizer.re"
	{ RET(TK_NOT) }
#line 4663 "tokenizer.cpp"
yy498:
	yych = *++cur;
	if (yych == '.') goto yy636;
	goto yy82;
yy499:
	++cur;
#line 574 "tokenizer.re"
	{ RET(TK_XOR) }
#line 4672 "tokenizer.cpp"
yy500:
	yych = *++cur;
	if (yych == 'A') goto yy638;
	if (yych == 'a') goto yy638;
	goto yy37;
yy501:
	yych = *++cur;
	if (yych == 'A') goto yy639;
	if (yych == 'a') goto yy639;
	goto yy37;
yy502:
	yych = *++cur;
	if (yych == 'N') goto yy640;
	if (yych == 'n') goto yy640;
	goto yy37;
yy503:
	yych = *++cur;
	if (yych == 'I') goto yy642;
	if (yych == 'i') goto yy642;
	goto yy37;
yy504:
	yych = *++cur;
	if (yych == 'H') goto yy643;
	if (yych == 'h') goto yy643;
	goto yy37;
yy505:
	yych = *++cur;
	if (yych == 'P') goto yy644;
	if (yych == 'p') goto yy644;
	goto yy37;
yy506:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 262 "tokenizer.re"
	{ KW(BLOCK) }
#line 4711 "tokenizer.cpp"
yy507:
	yych = *++cur;
	if (yych == 'E') goto yy645;
	if (yych == 'e') goto yy645;
	goto yy37;
yy508:
	yych = *++cur;
	if (yych == 'C') goto yy647;
	if (yych == 'c') goto yy647;
	goto yy37;
yy509:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 268 "tokenizer.re"
	{ KW(CLASS) }
#line 4730 "tokenizer.cpp"
yy510:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 269 "tokenizer.re"
	{ KW(CLOSE) }
#line 4739 "tokenizer.cpp"
yy511:
	yych = *++cur;
	if (yych == 'E') goto yy648;
	if (yych == 'e') goto yy648;
	goto yy37;
yy512:
	yych = *++cur;
	if (yych == 'N') goto yy649;
	if (yych == 'n') goto yy649;
	goto yy37;
yy513:
	yych = *++cur;
	if (yych == 'E') goto yy650;
	if (yych == 'e') goto yy650;
	goto yy37;
yy514:
	yych = *++cur;
	if (yych == 'R') goto yy651;
	if (yych == 'r') goto yy651;
	goto yy37;
yy515:
	yych = *++cur;
	if (yych == 'I') goto yy652;
	if (yych == 'i') goto yy652;
	goto yy37;
yy516:
	yych = *++cur;
	if (yych <= 'N') {
		if (yych == 'G') goto yy653;
		if (yych <= 'M') goto yy37;
		goto yy654;
	} else {
		if (yych <= 'g') {
			if (yych <= 'f') goto yy37;
			goto yy653;
		} else {
			if (yych == 'n') goto yy654;
			goto yy37;
		}
	}
yy517:
	yych = *++cur;
	if (yych == 'C') goto yy655;
	if (yych == 'c') goto yy655;
	goto yy37;
yy518:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 278 "tokenizer.re"
	{ KW(CYCLE) }
#line 4793 "tokenizer.cpp"
yy519:
	yych = *++cur;
	if (yych == 'O') goto yy656;
	if (yych == 'o') goto yy656;
	goto yy37;
yy520:
	yych = *++cur;
	if (yych == 'L') goto yy657;
	if (yych == 'l') goto yy657;
	goto yy37;
yy521:
	yych = *++cur;
	if (yych == 'R') goto yy658;
	if (yych == 'r') goto yy658;
	goto yy37;
yy522:
	yych = *++cur;
	if (yych == 'S') goto yy659;
	if (yych == 's') goto yy659;
	goto yy37;
yy523:
	yych = *++cur;
	if (yych == 'E') goto yy660;
	if (yych == 'e') goto yy660;
	goto yy37;
yy524:
	yych = *++cur;
	if (yych == 'L') goto yy662;
	if (yych == 'l') goto yy662;
	goto yy37;
yy525:
	yych = *++cur;
	if (yych == 'N') goto yy663;
	if (yych == 'n') goto yy663;
	goto yy37;
yy526:
	yych = *++cur;
	if (yych == 'F') goto yy664;
	if (yych == 'f') goto yy664;
	goto yy37;
yy527:
	yych = *++cur;
	if (yych == 'H') goto yy665;
	if (yych == 'h') goto yy665;
	goto yy37;
yy528:
	yych = *++cur;
	if (yych == 'S') goto yy666;
	if (yych == 's') goto yy666;
	goto yy59;
yy529:
	yych = *++cur;
	if (yych == 'L') goto yy667;
	if (yych == 'l') goto yy667;
	goto yy59;
yy530:
	yych = *++cur;
	if (yych == 'R') goto yy668;
	if (yych == 'r') goto yy668;
	goto yy59;
yy531:
	yych = *++cur;
	if (yych == 'O') goto yy669;
	if (yych == 'o') goto yy669;
	goto yy59;
yy532:
	yych = *++cur;
	if (yych == 'N') goto yy670;
	if (yych == 'n') goto yy670;
	goto yy59;
yy533:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych == 'O') goto yy671;
		if (yych <= 'T') goto yy59;
		goto yy672;
	} else {
		if (yych <= 'o') {
			if (yych <= 'n') goto yy59;
			goto yy671;
		} else {
			if (yych == 'u') goto yy672;
			goto yy59;
		}
	}
yy534:
	yych = *++cur;
	if (yych <= 'N') {
		if (yych == 'F') goto yy673;
		if (yych <= 'M') goto yy59;
		goto yy674;
	} else {
		if (yych <= 'f') {
			if (yych <= 'e') goto yy59;
			goto yy673;
		} else {
			if (yych == 'n') goto yy674;
			goto yy59;
		}
	}
yy535:
	yych = *++cur;
	if (yych == 'O') goto yy675;
	if (yych == 'o') goto yy675;
	goto yy59;
yy536:
	yych = *++cur;
	if (yych == 'R') goto yy676;
	if (yych == 'r') goto yy676;
	goto yy59;
yy537:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych == 'E') goto yy677;
		if (yych <= 'T') goto yy59;
		goto yy678;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy59;
			goto yy677;
		} else {
			if (yych == 'u') goto yy678;
			goto yy59;
		}
	}
yy538:
	yych = *++cur;
	if (yych <= 'Y') {
		if (yych == 'E') goto yy679;
		if (yych <= 'X') goto yy59;
		goto yy680;
	} else {
		if (yych <= 'e') {
			if (yych <= 'd') goto yy59;
			goto yy679;
		} else {
			if (yych == 'y') goto yy680;
			goto yy59;
		}
	}
yy539:
	yych = *++cur;
	if (yych == 'H') goto yy681;
	if (yych == 'h') goto yy681;
	goto yy59;
yy540:
	yych = *++cur;
	if (yych <= 'U') {
		if (yych <= 'N') {
			if (yych == 'I') goto yy682;
			goto yy59;
		} else {
			if (yych <= 'O') goto yy671;
			if (yych <= 'T') goto yy59;
			goto yy672;
		}
	} else {
		if (yych <= 'n') {
			if (yych == 'i') goto yy682;
			goto yy59;
		} else {
			if (yych <= 'o') goto yy671;
			if (yych == 'u') goto yy672;
			goto yy59;
		}
	}
yy541:
	yych = *++cur;
	if (yych == 'S') goto yy683;
	if (yych == 's') goto yy683;
	goto yy37;
yy542:
	yych = *++cur;
	if (yych == 'O') goto yy684;
	if (yych == 'o') goto yy684;
	goto yy37;
yy543:
	yych = *++cur;
	if (yych == 'I') goto yy685;
	if (yych == 'i') goto yy685;
	goto yy37;
yy544:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 363 "tokenizer.re"
	{
                if (enddo_newline_process) {
                    KW(CONTINUE)
                } else {
                    KW(ENDDO)
                }
            }
#line 4989 "tokenizer.cpp"
yy545:
	yych = *++cur;
	if (yych == 'U') goto yy686;
	if (yych == 'u') goto yy686;
	goto yy37;
yy546:
	yych = *++cur;
	if (yych == 'L') goto yy687;
	if (yych == 'l') goto yy687;
	goto yy37;
yy547:
	yych = *++cur;
	if (yych == 'R') goto yy688;
	if (yych == 'r') goto yy688;
	goto yy37;
yy548:
	yych = *++cur;
	if (yych == 'N') goto yy689;
	if (yych == 'n') goto yy689;
	goto yy37;
yy549:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 348 "tokenizer.re"
	{ KW(ENDIF) }
#line 5018 "tokenizer.cpp"
yy550:
	yych = *++cur;
	if (yych == 'T') goto yy690;
	if (yych == 't') goto yy690;
	goto yy37;
yy551:
	yych = *++cur;
	if (yych == 'D') goto yy691;
	if (yych == 'd') goto yy691;
	goto yy37;
yy552:
	yych = *++cur;
	if (yych == 'O') goto yy692;
	if (yych == 'o') goto yy692;
	goto yy37;
yy553:
	yych = *++cur;
	if (yych == 'L') goto yy693;
	if (yych == 'l') goto yy693;
	goto yy37;
yy554:
	yych = *++cur;
	if (yych == 'B') goto yy694;
	if (yych == 'b') goto yy694;
	goto yy37;
yy555:
	yych = *++cur;
	if (yych == 'A') goto yy695;
	if (yych == 'a') goto yy695;
	goto yy37;
yy556:
	yych = *++cur;
	if (yych == 'P') goto yy696;
	if (yych == 'p') goto yy696;
	goto yy37;
yy557:
	yych = *++cur;
	if (yych == 'E') goto yy697;
	if (yych == 'e') goto yy697;
	goto yy37;
yy558:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 377 "tokenizer.re"
	{ KW(ENTRY) }
#line 5067 "tokenizer.cpp"
yy559:
	yych = *++cur;
	if (yych == 'R') goto yy698;
	if (yych == 'r') goto yy698;
	goto yy37;
yy560:
	yych = *++cur;
	if (yych == 'A') goto yy699;
	if (yych == 'a') goto yy699;
	goto yy37;
yy561:
	yych = *++cur;
	if (yych == 'G') goto yy700;
	if (yych == 'g') goto yy700;
	goto yy37;
yy562:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 382 "tokenizer.re"
	{ KW(ERROR) }
#line 5091 "tokenizer.cpp"
yy563:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 383 "tokenizer.re"
	{ KW(EVENT) }
#line 5100 "tokenizer.cpp"
yy564:
	yych = *++cur;
	if (yych == 'D') goto yy701;
	if (yych == 'd') goto yy701;
	goto yy37;
yy565:
	yych = *++cur;
	if (yych == 'N') goto yy702;
	if (yych == 'n') goto yy702;
	goto yy37;
yy566:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 388 "tokenizer.re"
	{ KW(FINAL) }
#line 5119 "tokenizer.cpp"
yy567:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 389 "tokenizer.re"
	{ KW(FLUSH) }
#line 5128 "tokenizer.cpp"
yy568:
	yych = *++cur;
	if (yych == 'L') goto yy703;
	if (yych == 'l') goto yy703;
	goto yy37;
yy569:
	yych = *++cur;
	if (yych == 'T') goto yy704;
	if (yych == 't') goto yy704;
	goto yy37;
yy570:
	yych = *++cur;
	if (yych == 'E') goto yy706;
	if (yych == 'e') goto yy706;
	goto yy37;
yy571:
	yych = *++cur;
	if (yych == 'I') goto yy707;
	if (yych == 'i') goto yy707;
	goto yy37;
yy572:
	yych = *++cur;
	if (yych == 'I') goto yy708;
	if (yych == 'i') goto yy708;
	goto yy37;
yy573:
	yych = *++cur;
	if (yych == 'S') goto yy709;
	if (yych == 's') goto yy709;
	goto yy37;
yy574:
	yych = *++cur;
	if (yych == 'C') goto yy710;
	if (yych == 'c') goto yy710;
	goto yy37;
yy575:
	yych = *++cur;
	if (yych == 'T') goto yy711;
	if (yych == 't') goto yy711;
	goto yy37;
yy576:
	yych = *++cur;
	if (yych == 'E') goto yy712;
	if (yych == 'e') goto yy712;
	goto yy37;
yy577:
	yych = *++cur;
	if (yych == 'T') goto yy713;
	if (yych == 't') goto yy713;
	goto yy59;
yy578:
	yych = *++cur;
	if (yych == 'D') goto yy714;
	if (yych == 'd') goto yy714;
	goto yy37;
yy579:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 417 "tokenizer.re"
	{ KW(INOUT) }
#line 5192 "tokenizer.cpp"
yy580:
	yych = *++cur;
	if (yych == 'R') goto yy715;
	if (yych == 'r') goto yy715;
	goto yy37;
yy581:
	yych = *++cur;
	if (yych == 'N') goto yy716;
	if (yych == 'n') goto yy716;
	goto yy37;
yy582:
	yych = *++cur;
	if (yych == 'E') goto yy717;
	if (yych == 'e') goto yy717;
	goto yy37;
yy583:
	yych = *++cur;
	if (yych == 'T') goto yy718;
	if (yych == 't') goto yy718;
	goto yy37;
yy584:
	yych = *++cur;
	if (yych == 'F') goto yy719;
	if (yych == 'f') goto yy719;
	goto yy37;
yy585:
	yych = *++cur;
	if (yych == 'N') goto yy720;
	if (yych == 'n') goto yy720;
	goto yy37;
yy586:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy721;
#line 428 "tokenizer.re"
	{ KW(LOCAL) }
#line 5231 "tokenizer.cpp"
yy587:
	yych = *++cur;
	if (yych == 'A') goto yy722;
	if (yych == 'a') goto yy722;
	goto yy37;
yy588:
	yych = *++cur;
	if (yych == 'Y') goto yy723;
	if (yych == 'y') goto yy723;
	goto yy37;
yy589:
	yych = *++cur;
	if (yych == 'E') goto yy724;
	if (yych == 'e') goto yy724;
	goto yy37;
yy590:
	yych = *++cur;
	if (yych == 'I') goto yy725;
	if (yych == 'i') goto yy725;
	goto yy37;
yy591:
	yych = *++cur;
	if (yych == 'N') goto yy726;
	if (yych == 'n') goto yy726;
	goto yy37;
yy592:
	yych = *++cur;
	if (yych == 'N') goto yy727;
	if (yych == 'n') goto yy727;
	goto yy37;
yy593:
	yych = *++cur;
	if (yych == 'V') goto yy728;
	if (yych == 'v') goto yy728;
	goto yy37;
yy594:
	yych = *++cur;
	if (yych == 'E') goto yy729;
	if (yych == 'e') goto yy729;
	goto yy37;
yy595:
	yych = *++cur;
	if (yych == 'S') goto yy730;
	if (yych == 's') goto yy730;
	goto yy37;
yy596:
	yych = *++cur;
	if (yych == 'F') goto yy731;
	if (yych == 'f') goto yy731;
	goto yy37;
yy597:
	yych = *++cur;
	if (yych == 'T') goto yy732;
	if (yych == 't') goto yy732;
	goto yy37;
yy598:
	yych = *++cur;
	if (yych == 'N') goto yy733;
	if (yych == 'n') goto yy733;
	goto yy37;
yy599:
	yych = *++cur;
	if (yych == 'E') goto yy734;
	if (yych == 'e') goto yy734;
	goto yy37;
yy600:
	yych = *++cur;
	if (yych == 'E') goto yy735;
	if (yych == 'e') goto yy735;
	goto yy37;
yy601:
	yych = *++cur;
	if (yych == 'S') goto yy736;
	if (yych == 's') goto yy736;
	goto yy37;
yy602:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 453 "tokenizer.re"
	{ KW(PRINT) }
#line 5315 "tokenizer.cpp"
yy603:
	yych = *++cur;
	if (yych == 'T') goto yy737;
	if (yych == 't') goto yy737;
	goto yy37;
yy604:
	yych = *++cur;
	if (yych == 'D') goto yy738;
	if (yych == 'd') goto yy738;
	goto yy37;
yy605:
	yych = *++cur;
	if (yych == 'A') goto yy739;
	if (yych == 'a') goto yy739;
	goto yy37;
yy606:
	yych = *++cur;
	if (yych == 'C') goto yy740;
	if (yych == 'c') goto yy740;
	goto yy37;
yy607:
	yych = *++cur;
	if (yych == 'C') goto yy741;
	if (yych == 'c') goto yy741;
	goto yy37;
yy608:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 460 "tokenizer.re"
	{ KW(QUIET) }
#line 5349 "tokenizer.cpp"
yy609:
	yych = *++cur;
	if (yych == 'S') goto yy742;
	if (yych == 's') goto yy742;
	goto yy37;
yy610:
	yych = *++cur;
	if (yych == 'E') goto yy743;
	if (yych == 'e') goto yy743;
	goto yy37;
yy611:
	yych = *++cur;
	if (yych == 'R') goto yy744;
	if (yych == 'r') goto yy744;
	goto yy37;
yy612:
	yych = *++cur;
	if (yych == 'T') goto yy745;
	if (yych == 't') goto yy745;
	goto yy37;
yy613:
	yych = *++cur;
	if (yych == 'N') goto yy746;
	if (yych == 'n') goto yy746;
	goto yy37;
yy614:
	yych = *++cur;
	if (yych == 'D') goto yy747;
	if (yych == 'd') goto yy747;
	goto yy37;
yy615:
	yych = *++cur;
	if (yych == 'T') goto yy748;
	if (yych == 't') goto yy748;
	goto yy37;
yy616:
	yych = *++cur;
	if (yych == 'N') goto yy750;
	if (yych == 'n') goto yy750;
	goto yy37;
yy617:
	yych = *++cur;
	if (yych == 'D') goto yy751;
	if (yych == 'd') goto yy751;
	goto yy37;
yy618:
	yych = *++cur;
	if (yych == 'E') goto yy752;
	if (yych == 'e') goto yy752;
	goto yy37;
yy619:
	yych = *++cur;
	if (yych == 'D') goto yy753;
	if (yych == 'd') goto yy753;
	goto yy37;
yy620:
	yych = *++cur;
	if (yych == 'U') goto yy754;
	if (yych == 'u') goto yy754;
	goto yy37;
yy621:
	yych = *++cur;
	if (yych == 'L') goto yy755;
	if (yych == 'l') goto yy755;
	goto yy37;
yy622:
	yych = *++cur;
	if (yych == 'M') goto yy756;
	if (yych == 'm') goto yy756;
	goto yy37;
yy623:
	yych = *++cur;
	if (yych == 'E') goto yy757;
	if (yych == 'e') goto yy757;
	goto yy37;
yy624:
	yych = *++cur;
	if (yych == 'E') goto yy758;
	if (yych == 'e') goto yy758;
	goto yy37;
yy625:
	yych = *++cur;
	if (yych == 'T') goto yy759;
	if (yych == 't') goto yy759;
	goto yy37;
yy626:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych <= '\'') {
		if (yych == '"') goto yy61;
		if (yych <= '&') goto yy37;
		goto yy71;
	} else {
		if (yych <= 'N') {
			if (yych <= 'M') goto yy37;
			goto yy760;
		} else {
			if (yych == 'n') goto yy760;
			goto yy37;
		}
	}
yy627:
	yych = *++cur;
	if (yych == 'A') goto yy761;
	if (yych == 'a') goto yy761;
	goto yy37;
yy628:
	yych = *++cur;
	if (yych == 'M') goto yy762;
	if (yych == 'm') goto yy762;
	goto yy37;
yy629:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 497 "tokenizer.re"
	{ KW(VALUE) }
#line 5469 "tokenizer.cpp"
yy630:
	yych = *++cur;
	if (yych == 'I') goto yy763;
	if (yych == 'i') goto yy763;
	goto yy37;
yy631:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 500 "tokenizer.re"
	{ KW(WHERE) }
#line 5483 "tokenizer.cpp"
yy632:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 501 "tokenizer.re"
	{ KW(WHILE) }
#line 5492 "tokenizer.cpp"
yy633:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 502 "tokenizer.re"
	{ KW(WRITE) }
#line 5501 "tokenizer.cpp"
yy634:
	yych = *++cur;
	if (yych == '.') goto yy764;
	goto yy82;
yy635:
	++cur;
#line 576 "tokenizer.re"
	{ RET(TK_NEQV) }
#line 5510 "tokenizer.cpp"
yy636:
	yyaccept = 11;
	yych = *(mar = ++cur);
	if (yych == '_') goto yy766;
yy637:
#line 580 "tokenizer.re"
	{ RET(TK_TRUE) }
#line 5518 "tokenizer.cpp"
yy638:
	yych = *++cur;
	if (yych == 'C') goto yy767;
	if (yych == 'c') goto yy767;
	goto yy37;
yy639:
	yych = *++cur;
	if (yych == 'T') goto yy768;
	if (yych == 't') goto yy768;
	goto yy37;
yy640:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'M') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy641;
			if (yych <= 'L') goto yy36;
			goto yy769;
		}
	} else {
		if (yych <= 'l') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 'm') goto yy769;
			if (yych <= 'z') goto yy36;
		}
	}
yy641:
#line 256 "tokenizer.re"
	{ KW(ASSIGN) }
#line 5554 "tokenizer.cpp"
yy642:
	yych = *++cur;
	if (yych == 'A') goto yy770;
	if (yych == 'a') goto yy770;
	goto yy37;
yy643:
	yych = *++cur;
	if (yych == 'R') goto yy771;
	if (yych == 'r') goto yy771;
	goto yy37;
yy644:
	yych = *++cur;
	if (yych == 'A') goto yy772;
	if (yych == 'a') goto yy772;
	goto yy37;
yy645:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'T') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy646;
			if (yych <= 'S') goto yy36;
			goto yy773;
		}
	} else {
		if (yych <= 's') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 't') goto yy773;
			if (yych <= 'z') goto yy36;
		}
	}
yy646:
#line 265 "tokenizer.re"
	{ KW(CHANGE) }
#line 5595 "tokenizer.cpp"
yy647:
	yych = *++cur;
	if (yych == 'T') goto yy774;
	if (yych == 't') goto yy774;
	goto yy37;
yy648:
	yych = *++cur;
	if (yych == 'N') goto yy775;
	if (yych == 'n') goto yy775;
	goto yy37;
yy649:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 271 "tokenizer.re"
	{ KW(COMMON) }
#line 5614 "tokenizer.cpp"
yy650:
	yych = *++cur;
	if (yych == 'X') goto yy776;
	if (yych == 'x') goto yy776;
	goto yy37;
yy651:
	yych = *++cur;
	if (yych == 'R') goto yy777;
	if (yych == 'r') goto yy777;
	goto yy37;
yy652:
	yych = *++cur;
	if (yych == 'N') goto yy778;
	if (yych == 'n') goto yy778;
	goto yy37;
yy653:
	yych = *++cur;
	if (yych == 'U') goto yy779;
	if (yych == 'u') goto yy779;
	goto yy37;
yy654:
	yych = *++cur;
	if (yych == 'U') goto yy780;
	if (yych == 'u') goto yy780;
	goto yy37;
yy655:
	yych = *++cur;
	if (yych == 'A') goto yy781;
	if (yych == 'a') goto yy781;
	goto yy37;
yy656:
	yych = *++cur;
	if (yych == 'C') goto yy782;
	if (yych == 'c') goto yy782;
	goto yy37;
yy657:
	yych = *++cur;
	if (yych == 'T') goto yy783;
	if (yych == 't') goto yy783;
	goto yy37;
yy658:
	yych = *++cur;
	if (yych == 'E') goto yy784;
	if (yych == 'e') goto yy784;
	goto yy37;
yy659:
	yych = *++cur;
	if (yych == 'I') goto yy785;
	if (yych == 'i') goto yy785;
	goto yy37;
yy660:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'P') {
		if (yych <= '@') {
			if (yych <= '/') goto yy661;
			if (yych <= '9') goto yy36;
		} else {
			if (yych == 'C') goto yy786;
			if (yych <= 'O') goto yy36;
			goto yy787;
		}
	} else {
		if (yych <= 'c') {
			if (yych <= 'Z') goto yy36;
			if (yych <= '`') goto yy661;
			if (yych <= 'b') goto yy36;
			goto yy786;
		} else {
			if (yych == 'p') goto yy787;
			if (yych <= 'z') goto yy36;
		}
	}
yy661:
#line 293 "tokenizer.re"
	{ KW(DOUBLE) }
#line 5693 "tokenizer.cpp"
yy662:
	yych = *++cur;
	if (yych == 'E') goto yy788;
	if (yych == 'e') goto yy788;
	goto yy37;
yy663:
	yych = *++cur;
	if (yych == 'T') goto yy789;
	if (yych == 't') goto yy789;
	goto yy37;
yy664:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 298 "tokenizer.re"
	{ KW(ELSEIF) }
#line 5712 "tokenizer.cpp"
yy665:
	yych = *++cur;
	if (yych == 'E') goto yy790;
	if (yych == 'e') goto yy790;
	goto yy37;
yy666:
	yych = *++cur;
	if (yych == 'S') goto yy791;
	if (yych == 's') goto yy791;
	goto yy59;
yy667:
	yych = *++cur;
	if (yych == 'O') goto yy792;
	if (yych == 'o') goto yy792;
	goto yy59;
yy668:
	yych = *++cur;
	if (yych == 'I') goto yy793;
	if (yych == 'i') goto yy793;
	goto yy59;
yy669:
	++cur;
#line 356 "tokenizer.re"
	{
                if (enddo_newline_process) {
                    KW(CONTINUE)
                } else {
                    KW(END_DO)
                }
            }
#line 5743 "tokenizer.cpp"
yy670:
	yych = *++cur;
	if (yych == 'U') goto yy794;
	if (yych == 'u') goto yy794;
	goto yy59;
yy671:
	yych = *++cur;
	if (yych == 'R') goto yy795;
	if (yych == 'r') goto yy795;
	goto yy59;
yy672:
	yych = *++cur;
	if (yych == 'N') goto yy796;
	if (yych == 'n') goto yy796;
	goto yy59;
yy673:
	++cur;
#line 347 "tokenizer.re"
	{ KW(END_IF) }
#line 5763 "tokenizer.cpp"
yy674:
	yych = *++cur;
	if (yych == 'T') goto yy797;
	if (yych == 't') goto yy797;
	goto yy59;
yy675:
	yych = *++cur;
	if (yych == 'D') goto yy798;
	if (yych == 'd') goto yy798;
	goto yy59;
yy676:
	yych = *++cur;
	if (yych == 'O') goto yy799;
	if (yych == 'o') goto yy799;
	goto yy59;
yy677:
	yych = *++cur;
	if (yych == 'L') goto yy800;
	if (yych == 'l') goto yy800;
	goto yy59;
yy678:
	yych = *++cur;
	if (yych == 'B') goto yy801;
	if (yych == 'b') goto yy801;
	goto yy59;
yy679:
	yych = *++cur;
	if (yych == 'A') goto yy802;
	if (yych == 'a') goto yy802;
	goto yy59;
yy680:
	yych = *++cur;
	if (yych == 'P') goto yy803;
	if (yych == 'p') goto yy803;
	goto yy59;
yy681:
	yych = *++cur;
	if (yych == 'E') goto yy804;
	if (yych == 'e') goto yy804;
	goto yy59;
yy682:
	yych = *++cur;
	if (yych == 'L') goto yy805;
	if (yych == 'l') goto yy805;
	goto yy59;
yy683:
	yych = *++cur;
	if (yych == 'O') goto yy806;
	if (yych == 'o') goto yy806;
	goto yy37;
yy684:
	yych = *++cur;
	if (yych == 'C') goto yy807;
	if (yych == 'c') goto yy807;
	goto yy37;
yy685:
	yych = *++cur;
	if (yych == 'T') goto yy808;
	if (yych == 't') goto yy808;
	goto yy37;
yy686:
	yych = *++cur;
	if (yych == 'M') goto yy809;
	if (yych == 'm') goto yy809;
	goto yy37;
yy687:
	yych = *++cur;
	if (yych == 'E') goto yy810;
	if (yych == 'e') goto yy810;
	goto yy37;
yy688:
	yych = *++cur;
	if (yych == 'A') goto yy811;
	if (yych == 'a') goto yy811;
	goto yy37;
yy689:
	yych = *++cur;
	if (yych == 'C') goto yy812;
	if (yych == 'c') goto yy812;
	goto yy37;
yy690:
	yych = *++cur;
	if (yych == 'E') goto yy813;
	if (yych == 'e') goto yy813;
	goto yy37;
yy691:
	yych = *++cur;
	if (yych == 'U') goto yy814;
	if (yych == 'u') goto yy814;
	goto yy37;
yy692:
	yych = *++cur;
	if (yych <= 'G') {
		if (yych == 'C') goto yy815;
		if (yych <= 'F') goto yy37;
		goto yy816;
	} else {
		if (yych <= 'c') {
			if (yych <= 'b') goto yy37;
			goto yy815;
		} else {
			if (yych == 'g') goto yy816;
			goto yy37;
		}
	}
yy693:
	yych = *++cur;
	if (yych == 'E') goto yy817;
	if (yych == 'e') goto yy817;
	goto yy37;
yy694:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'M') goto yy818;
		if (yych <= 'Q') goto yy37;
		goto yy819;
	} else {
		if (yych <= 'm') {
			if (yych <= 'l') goto yy37;
			goto yy818;
		} else {
			if (yych == 'r') goto yy819;
			goto yy37;
		}
	}
yy695:
	yych = *++cur;
	if (yych == 'M') goto yy820;
	if (yych == 'm') goto yy820;
	goto yy37;
yy696:
	yych = *++cur;
	if (yych == 'E') goto yy821;
	if (yych == 'e') goto yy821;
	goto yy37;
yy697:
	yych = *++cur;
	if (yych == 'R') goto yy822;
	if (yych == 'r') goto yy822;
	goto yy37;
yy698:
	yych = *++cur;
	if (yych == 'A') goto yy823;
	if (yych == 'a') goto yy823;
	goto yy37;
yy699:
	yych = *++cur;
	if (yych == 'L') goto yy824;
	if (yych == 'l') goto yy824;
	goto yy37;
yy700:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 381 "tokenizer.re"
	{ KW(ERRMSG) }
#line 5922 "tokenizer.cpp"
yy701:
	yych = *++cur;
	if (yych == 'S') goto yy825;
	if (yych == 's') goto yy825;
	goto yy37;
yy702:
	yych = *++cur;
	if (yych == 'A') goto yy826;
	if (yych == 'a') goto yy826;
	goto yy37;
yy703:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 390 "tokenizer.re"
	{ KW(FORALL) }
#line 5941 "tokenizer.cpp"
yy704:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'T') {
		if (yych <= '9') {
			if (yych >= '0') goto yy36;
		} else {
			if (yych <= '@') goto yy705;
			if (yych <= 'S') goto yy36;
			goto yy827;
		}
	} else {
		if (yych <= 's') {
			if (yych <= 'Z') goto yy36;
			if (yych >= 'a') goto yy36;
		} else {
			if (yych <= 't') goto yy827;
			if (yych <= 'z') goto yy36;
		}
	}
yy705:
#line 391 "tokenizer.re"
	{
                if (last_token == yytokentype::TK_LABEL) {
                    unsigned char *start;
                    lex_format(cur, loc, start);
                    yylval.string.p = (char*) start;
                    yylval.string.n = cur-start-1;
                    RET(TK_FORMAT)
                } else {
                    token(yylval.string);
                    RET(TK_NAME)
                }
            }
#line 5978 "tokenizer.cpp"
yy706:
	yych = *++cur;
	if (yych == 'A') goto yy828;
	if (yych == 'a') goto yy828;
	goto yy37;
yy707:
	yych = *++cur;
	if (yych == 'O') goto yy829;
	if (yych == 'o') goto yy829;
	goto yy37;
yy708:
	yych = *++cur;
	if (yych == 'C') goto yy830;
	if (yych == 'c') goto yy830;
	goto yy37;
yy709:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 411 "tokenizer.re"
	{ KW(IMAGES) }
#line 6002 "tokenizer.cpp"
yy710:
	yych = *++cur;
	if (yych == 'I') goto yy831;
	if (yych == 'i') goto yy831;
	goto yy37;
yy711:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 413 "tokenizer.re"
	{ KW(IMPORT) }
#line 6016 "tokenizer.cpp"
yy712:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 414 "tokenizer.re"
	{ KW(IMPURE) }
#line 6025 "tokenizer.cpp"
yy713:
	++cur;
#line 418 "tokenizer.re"
	{ KW(IN_OUT) }
#line 6030 "tokenizer.cpp"
yy714:
	yych = *++cur;
	if (yych == 'E') goto yy832;
	if (yych == 'e') goto yy832;
	goto yy37;
yy715:
	yych = *++cur;
	if (yych == 'E') goto yy833;
	if (yych == 'e') goto yy833;
	goto yy37;
yy716:
	yych = *++cur;
	if (yych == 'T') goto yy834;
	if (yych == 't') goto yy834;
	goto yy37;
yy717:
	yych = *++cur;
	if (yych == 'R') goto yy835;
	if (yych == 'r') goto yy835;
	goto yy37;
yy718:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 422 "tokenizer.re"
	{ KW(INTENT) }
#line 6059 "tokenizer.cpp"
yy719:
	yych = *++cur;
	if (yych == 'A') goto yy836;
	if (yych == 'a') goto yy836;
	goto yy37;
yy720:
	yych = *++cur;
	if (yych == 'S') goto yy837;
	if (yych == 's') goto yy837;
	goto yy37;
yy721:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych <= '\'') {
		if (yych == '"') goto yy61;
		if (yych <= '&') goto yy37;
		goto yy71;
	} else {
		if (yych <= 'I') {
			if (yych <= 'H') goto yy37;
			goto yy838;
		} else {
			if (yych == 'i') goto yy838;
			goto yy37;
		}
	}
yy722:
	yych = *++cur;
	if (yych == 'L') goto yy839;
	if (yych == 'l') goto yy839;
	goto yy37;
yy723:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 431 "tokenizer.re"
	{ KW(MEMORY) }
#line 6099 "tokenizer.cpp"
yy724:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 432 "tokenizer.re"
	{ KW(MODULE) }
#line 6108 "tokenizer.cpp"
yy725:
	yych = *++cur;
	if (yych == 'S') goto yy840;
	if (yych == 's') goto yy840;
	goto yy37;
yy726:
	yych = *++cur;
	if (yych == 'D') goto yy841;
	if (yych == 'd') goto yy841;
	goto yy37;
yy727:
	yych = *++cur;
	if (yych == 'T') goto yy842;
	if (yych == 't') goto yy842;
	goto yy37;
yy728:
	yych = *++cur;
	if (yych == 'E') goto yy843;
	if (yych == 'e') goto yy843;
	goto yy37;
yy729:
	yych = *++cur;
	if (yych == 'C') goto yy844;
	if (yych == 'c') goto yy844;
	goto yy37;
yy730:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 437 "tokenizer.re"
	{ KW(NOPASS) }
#line 6142 "tokenizer.cpp"
yy731:
	yych = *++cur;
	if (yych == 'Y') goto yy845;
	if (yych == 'y') goto yy845;
	goto yy37;
yy732:
	yych = *++cur;
	if (yych == 'O') goto yy846;
	if (yych == 'o') goto yy846;
	goto yy37;
yy733:
	yych = *++cur;
	if (yych == 'A') goto yy847;
	if (yych == 'a') goto yy847;
	goto yy37;
yy734:
	yych = *++cur;
	if (yych == 'T') goto yy848;
	if (yych == 't') goto yy848;
	goto yy37;
yy735:
	yych = *++cur;
	if (yych == 'R') goto yy849;
	if (yych == 'r') goto yy849;
	goto yy37;
yy736:
	yych = *++cur;
	if (yych == 'I') goto yy850;
	if (yych == 'i') goto yy850;
	goto yy37;
yy737:
	yych = *++cur;
	if (yych == 'E') goto yy851;
	if (yych == 'e') goto yy851;
	goto yy37;
yy738:
	yych = *++cur;
	if (yych == 'U') goto yy852;
	if (yych == 'u') goto yy852;
	goto yy37;
yy739:
	yych = *++cur;
	if (yych == 'M') goto yy853;
	if (yych == 'm') goto yy853;
	goto yy37;
yy740:
	yych = *++cur;
	if (yych == 'T') goto yy854;
	if (yych == 't') goto yy854;
	goto yy37;
yy741:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 458 "tokenizer.re"
	{ KW(PUBLIC) }
#line 6201 "tokenizer.cpp"
yy742:
	yych = *++cur;
	if (yych == 'I') goto yy855;
	if (yych == 'i') goto yy855;
	goto yy37;
yy743:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 465 "tokenizer.re"
	{ KW(REDUCE) }
#line 6215 "tokenizer.cpp"
yy744:
	yych = *++cur;
	if (yych == 'E') goto yy856;
	if (yych == 'e') goto yy856;
	goto yy37;
yy745:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 468 "tokenizer.re"
	{ KW(RESULT) }
#line 6229 "tokenizer.cpp"
yy746:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 469 "tokenizer.re"
	{ KW(RETURN) }
#line 6238 "tokenizer.cpp"
yy747:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 470 "tokenizer.re"
	{ KW(REWIND) }
#line 6247 "tokenizer.cpp"
yy748:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= 'T') {
		if (yych <= 'B') {
			if (yych <= '/') goto yy749;
			if (yych <= '9') goto yy36;
			if (yych >= 'A') goto yy36;
		} else {
			if (yych <= 'Q') {
				if (yych <= 'C') goto yy857;
				goto yy36;
			} else {
				if (yych <= 'R') goto yy858;
				if (yych <= 'S') goto yy36;
				goto yy859;
			}
		}
	} else {
		if (yych <= 'q') {
			if (yych <= '`') {
				if (yych <= 'Z') goto yy36;
			} else {
				if (yych == 'c') goto yy857;
				goto yy36;
			}
		} else {
			if (yych <= 's') {
				if (yych <= 'r') goto yy858;
				goto yy36;
			} else {
				if (yych <= 't') goto yy859;
				if (yych <= 'z') goto yy36;
			}
		}
	}
yy749:
#line 472 "tokenizer.re"
	{ KW(SELECT) }
#line 6289 "tokenizer.cpp"
yy750:
	yych = *++cur;
	if (yych == 'C') goto yy860;
	if (yych == 'c') goto yy860;
	goto yy37;
yy751:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 477 "tokenizer.re"
	{ KW(SHARED) }
#line 6303 "tokenizer.cpp"
yy752:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 478 "tokenizer.re"
	{ KW(SOURCE) }
#line 6312 "tokenizer.cpp"
yy753:
	yych = *++cur;
	if (yych == 'U') goto yy861;
	if (yych == 'u') goto yy861;
	goto yy37;
yy754:
	yych = *++cur;
	if (yych == 'T') goto yy862;
	if (yych == 't') goto yy862;
	goto yy37;
yy755:
	yych = *++cur;
	if (yych == 'L') goto yy863;
	if (yych == 'l') goto yy863;
	goto yy37;
yy756:
	yych = *++cur;
	if (yych == 'A') goto yy864;
	if (yych == 'a') goto yy864;
	goto yy37;
yy757:
	yych = *++cur;
	if (yych == 'M') goto yy865;
	if (yych == 'm') goto yy865;
	goto yy37;
yy758:
	yych = *++cur;
	if (yych == 'A') goto yy866;
	if (yych == 'a') goto yy866;
	goto yy37;
yy759:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 488 "tokenizer.re"
	{ KW(TARGET) }
#line 6351 "tokenizer.cpp"
yy760:
	yych = *++cur;
	if (yych == 'U') goto yy867;
	if (yych == 'u') goto yy867;
	goto yy37;
yy761:
	yych = *++cur;
	if (yych == 'T') goto yy868;
	if (yych == 't') goto yy868;
	goto yy37;
yy762:
	yych = *++cur;
	if (yych == 'A') goto yy869;
	if (yych == 'a') goto yy869;
	goto yy37;
yy763:
	yych = *++cur;
	if (yych == 'L') goto yy870;
	if (yych == 'l') goto yy870;
	goto yy37;
yy764:
	yyaccept = 12;
	yych = *(mar = ++cur);
	if (yych == '_') goto yy871;
yy765:
#line 581 "tokenizer.re"
	{ RET(TK_FALSE) }
#line 6379 "tokenizer.cpp"
yy766:
	yych = *++cur;
	if (yych <= 'Z') {
		if (yych <= '/') goto yy59;
		if (yych <= '9') goto yy872;
		if (yych <= '@') goto yy59;
		goto yy873;
	} else {
		if (yych <= '_') {
			if (yych <= '^') goto yy59;
			goto yy873;
		} else {
			if (yych <= '`') goto yy59;
			if (yych <= 'z') goto yy873;
			goto yy59;
		}
	}
yy767:
	yych = *++cur;
	if (yych == 'T') goto yy874;
	if (yych == 't') goto yy874;
	goto yy37;
yy768:
	yych = *++cur;
	if (yych <= 'E') {
		if (yych == 'A') goto yy875;
		if (yych <= 'D') goto yy37;
		goto yy876;
	} else {
		if (yych <= 'a') {
			if (yych <= '`') goto yy37;
			goto yy875;
		} else {
			if (yych == 'e') goto yy876;
			goto yy37;
		}
	}
yy769:
	yych = *++cur;
	if (yych == 'E') goto yy877;
	if (yych == 'e') goto yy877;
	goto yy37;
yy770:
	yych = *++cur;
	if (yych == 'T') goto yy878;
	if (yych == 't') goto yy878;
	goto yy37;
yy771:
	yych = *++cur;
	if (yych == 'O') goto yy879;
	if (yych == 'o') goto yy879;
	goto yy37;
yy772:
	yych = *++cur;
	if (yych == 'C') goto yy880;
	if (yych == 'c') goto yy880;
	goto yy37;
yy773:
	yych = *++cur;
	if (yych == 'E') goto yy881;
	if (yych == 'e') goto yy881;
	goto yy37;
yy774:
	yych = *++cur;
	if (yych == 'E') goto yy882;
	if (yych == 'e') goto yy882;
	goto yy37;
yy775:
	yych = *++cur;
	if (yych == 'S') goto yy883;
	if (yych == 's') goto yy883;
	goto yy37;
yy776:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 272 "tokenizer.re"
	{ KW(COMPLEX) }
#line 6460 "tokenizer.cpp"
yy777:
	yych = *++cur;
	if (yych == 'E') goto yy884;
	if (yych == 'e') goto yy884;
	goto yy37;
yy778:
	yych = *++cur;
	if (yych == 'S') goto yy885;
	if (yych == 's') goto yy885;
	goto yy37;
yy779:
	yych = *++cur;
	if (yych == 'O') goto yy886;
	if (yych == 'o') goto yy886;
	goto yy37;
yy780:
	yych = *++cur;
	if (yych == 'E') goto yy887;
	if (yych == 'e') goto yy887;
	goto yy37;
yy781:
	yych = *++cur;
	if (yych == 'L') goto yy888;
	if (yych == 'l') goto yy888;
	goto yy37;
yy782:
	yych = *++cur;
	if (yych == 'A') goto yy889;
	if (yych == 'a') goto yy889;
	goto yy37;
yy783:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 281 "tokenizer.re"
	{ KW(DEFAULT) }
#line 6499 "tokenizer.cpp"
yy784:
	yych = *++cur;
	if (yych == 'D') goto yy890;
	if (yych == 'd') goto yy890;
	goto yy37;
yy785:
	yych = *++cur;
	if (yych == 'O') goto yy891;
	if (yych == 'o') goto yy891;
	goto yy37;
yy786:
	yych = *++cur;
	if (yych == 'O') goto yy892;
	if (yych == 'o') goto yy892;
	goto yy37;
yy787:
	yych = *++cur;
	if (yych == 'R') goto yy893;
	if (yych == 'r') goto yy893;
	goto yy37;
yy788:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 292 "tokenizer.re"
	{ KW(DOWHILE) }
#line 6528 "tokenizer.cpp"
yy789:
	yych = *++cur;
	if (yych == 'A') goto yy894;
	if (yych == 'a') goto yy894;
	goto yy37;
yy790:
	yych = *++cur;
	if (yych == 'R') goto yy895;
	if (yych == 'r') goto yy895;
	goto yy37;
yy791:
	yych = *++cur;
	if (yych == 'O') goto yy896;
	if (yych == 'o') goto yy896;
	goto yy59;
yy792:
	yych = *++cur;
	if (yych == 'C') goto yy897;
	if (yych == 'c') goto yy897;
	goto yy59;
yy793:
	yych = *++cur;
	if (yych == 'T') goto yy898;
	if (yych == 't') goto yy898;
	goto yy59;
yy794:
	yych = *++cur;
	if (yych == 'M') goto yy899;
	if (yych == 'm') goto yy899;
	goto yy59;
yy795:
	yych = *++cur;
	if (yych == 'A') goto yy900;
	if (yych == 'a') goto yy900;
	goto yy59;
yy796:
	yych = *++cur;
	if (yych == 'C') goto yy901;
	if (yych == 'c') goto yy901;
	goto yy59;
yy797:
	yych = *++cur;
	if (yych == 'E') goto yy902;
	if (yych == 'e') goto yy902;
	goto yy59;
yy798:
	yych = *++cur;
	if (yych == 'U') goto yy903;
	if (yych == 'u') goto yy903;
	goto yy59;
yy799:
	yych = *++cur;
	if (yych <= 'G') {
		if (yych == 'C') goto yy904;
		if (yych <= 'F') goto yy59;
		goto yy905;
	} else {
		if (yych <= 'c') {
			if (yych <= 'b') goto yy59;
			goto yy904;
		} else {
			if (yych == 'g') goto yy905;
			goto yy59;
		}
	}
yy800:
	yych = *++cur;
	if (yych == 'E') goto yy906;
	if (yych == 'e') goto yy906;
	goto yy59;
yy801:
	yych = *++cur;
	if (yych <= 'R') {
		if (yych == 'M') goto yy907;
		if (yych <= 'Q') goto yy59;
		goto yy908;
	} else {
		if (yych <= 'm') {
			if (yych <= 'l') goto yy59;
			goto yy907;
		} else {
			if (yych == 'r') goto yy908;
			goto yy59;
		}
	}
yy802:
	yych = *++cur;
	if (yych == 'M') goto yy909;
	if (yych == 'm') goto yy909;
	goto yy59;
yy803:
	yych = *++cur;
	if (yych == 'E') goto yy910;
	if (yych == 'e') goto yy910;
	goto yy59;
yy804:
	yych = *++cur;
	if (yych == 'R') goto yy911;
	if (yych == 'r') goto yy911;
	goto yy59;
yy805:
	yych = *++cur;
	if (yych == 'E') goto yy912;
	if (yych == 'e') goto yy912;
	goto yy59;
yy806:
	yych = *++cur;
	if (yych == 'C') goto yy913;
	if (yych == 'c') goto yy913;
	goto yy37;
yy807:
	yych = *++cur;
	if (yych == 'K') goto yy914;
	if (yych == 'k') goto yy914;
	goto yy37;
yy808:
	yych = *++cur;
	if (yych == 'I') goto yy916;
	if (yych == 'i') goto yy916;
	goto yy37;
yy809:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 330 "tokenizer.re"
	{ KW(ENDENUM) }
#line 6657 "tokenizer.cpp"
yy810:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 375 "tokenizer.re"
	{ KW(ENDFILE) }
#line 6666 "tokenizer.cpp"
yy811:
	yych = *++cur;
	if (yych == 'L') goto yy917;
	if (yych == 'l') goto yy917;
	goto yy37;
yy812:
	yych = *++cur;
	if (yych == 'T') goto yy918;
	if (yych == 't') goto yy918;
	goto yy37;
yy813:
	yych = *++cur;
	if (yych == 'R') goto yy919;
	if (yych == 'r') goto yy919;
	goto yy37;
yy814:
	yych = *++cur;
	if (yych == 'L') goto yy920;
	if (yych == 'l') goto yy920;
	goto yy37;
yy815:
	yych = *++cur;
	if (yych == 'E') goto yy921;
	if (yych == 'e') goto yy921;
	goto yy37;
yy816:
	yych = *++cur;
	if (yych == 'R') goto yy922;
	if (yych == 'r') goto yy922;
	goto yy37;
yy817:
	yych = *++cur;
	if (yych == 'C') goto yy923;
	if (yych == 'c') goto yy923;
	goto yy37;
yy818:
	yych = *++cur;
	if (yych == 'O') goto yy924;
	if (yych == 'o') goto yy924;
	goto yy37;
yy819:
	yych = *++cur;
	if (yych == 'O') goto yy925;
	if (yych == 'o') goto yy925;
	goto yy37;
yy820:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 342 "tokenizer.re"
	{ KW(ENDTEAM) }
#line 6720 "tokenizer.cpp"
yy821:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 354 "tokenizer.re"
	{ KW(ENDTYPE) }
#line 6729 "tokenizer.cpp"
yy822:
	yych = *++cur;
	if (yych == 'E') goto yy926;
	if (yych == 'e') goto yy926;
	goto yy37;
yy823:
	yych = *++cur;
	if (yych == 'T') goto yy927;
	if (yych == 't') goto yy927;
	goto yy37;
yy824:
	yych = *++cur;
	if (yych == 'E') goto yy928;
	if (yych == 'e') goto yy928;
	goto yy37;
yy825:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 385 "tokenizer.re"
	{ KW(EXTENDS) }
#line 6753 "tokenizer.cpp"
yy826:
	yych = *++cur;
	if (yych == 'L') goto yy929;
	if (yych == 'l') goto yy929;
	goto yy37;
yy827:
	yych = *++cur;
	if (yych == 'E') goto yy930;
	if (yych == 'e') goto yy930;
	goto yy37;
yy828:
	yych = *++cur;
	if (yych == 'M') goto yy931;
	if (yych == 'm') goto yy931;
	goto yy37;
yy829:
	yych = *++cur;
	if (yych == 'N') goto yy932;
	if (yych == 'n') goto yy932;
	goto yy37;
yy830:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 407 "tokenizer.re"
	{ KW(GENERIC) }
#line 6782 "tokenizer.cpp"
yy831:
	yych = *++cur;
	if (yych == 'T') goto yy933;
	if (yych == 't') goto yy933;
	goto yy37;
yy832:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 416 "tokenizer.re"
	{ KW(INCLUDE) }
#line 6796 "tokenizer.cpp"
yy833:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 419 "tokenizer.re"
	{ KW(INQUIRE) }
#line 6805 "tokenizer.cpp"
yy834:
	yych = *++cur;
	if (yych == 'I') goto yy934;
	if (yych == 'i') goto yy934;
	goto yy37;
yy835:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 421 "tokenizer.re"
	{ KW(INTEGER) }
#line 6819 "tokenizer.cpp"
yy836:
	yych = *++cur;
	if (yych == 'C') goto yy935;
	if (yych == 'c') goto yy935;
	goto yy37;
yy837:
	yych = *++cur;
	if (yych == 'I') goto yy936;
	if (yych == 'i') goto yy936;
	goto yy37;
yy838:
	yych = *++cur;
	if (yych == 'N') goto yy937;
	if (yych == 'n') goto yy937;
	goto yy37;
yy839:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 430 "tokenizer.re"
	{ KW(LOGICAL) }
#line 6843 "tokenizer.cpp"
yy840:
	yych = *++cur;
	if (yych == 'T') goto yy938;
	if (yych == 't') goto yy938;
	goto yy37;
yy841:
	yych = *++cur;
	if (yych == 'E') goto yy939;
	if (yych == 'e') goto yy939;
	goto yy37;
yy842:
	yych = *++cur;
	if (yych == 'R') goto yy940;
	if (yych == 'r') goto yy940;
	goto yy37;
yy843:
	yych = *++cur;
	if (yych == 'R') goto yy941;
	if (yych == 'r') goto yy941;
	goto yy37;
yy844:
	yych = *++cur;
	if (yych == 'U') goto yy942;
	if (yych == 'u') goto yy942;
	goto yy37;
yy845:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 442 "tokenizer.re"
	{ KW(NULLIFY) }
#line 6877 "tokenizer.cpp"
yy846:
	yych = *++cur;
	if (yych == 'R') goto yy943;
	if (yych == 'r') goto yy943;
	goto yy37;
yy847:
	yych = *++cur;
	if (yych == 'L') goto yy944;
	if (yych == 'l') goto yy944;
	goto yy37;
yy848:
	yych = *++cur;
	if (yych == 'E') goto yy945;
	if (yych == 'e') goto yy945;
	goto yy37;
yy849:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 450 "tokenizer.re"
	{ KW(POINTER) }
#line 6901 "tokenizer.cpp"
yy850:
	yych = *++cur;
	if (yych == 'O') goto yy946;
	if (yych == 'o') goto yy946;
	goto yy37;
yy851:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 454 "tokenizer.re"
	{ KW(PRIVATE) }
#line 6915 "tokenizer.cpp"
yy852:
	yych = *++cur;
	if (yych == 'R') goto yy947;
	if (yych == 'r') goto yy947;
	goto yy37;
yy853:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 456 "tokenizer.re"
	{ KW(PROGRAM) }
#line 6929 "tokenizer.cpp"
yy854:
	yych = *++cur;
	if (yych == 'E') goto yy948;
	if (yych == 'e') goto yy948;
	goto yy37;
yy855:
	yych = *++cur;
	if (yych == 'V') goto yy949;
	if (yych == 'v') goto yy949;
	goto yy37;
yy856:
	yych = *++cur;
	if (yych <= 'S') {
		if (yych == 'M') goto yy950;
		if (yych <= 'R') goto yy37;
		goto yy951;
	} else {
		if (yych <= 'm') {
			if (yych <= 'l') goto yy37;
			goto yy950;
		} else {
			if (yych == 's') goto yy951;
			goto yy37;
		}
	}
yy857:
	yych = *++cur;
	if (yych == 'A') goto yy952;
	if (yych == 'a') goto yy952;
	goto yy37;
yy858:
	yych = *++cur;
	if (yych == 'A') goto yy953;
	if (yych == 'a') goto yy953;
	goto yy37;
yy859:
	yych = *++cur;
	if (yych == 'Y') goto yy954;
	if (yych == 'y') goto yy954;
	goto yy37;
yy860:
	yych = *++cur;
	if (yych == 'E') goto yy955;
	if (yych == 'e') goto yy955;
	goto yy37;
yy861:
	yych = *++cur;
	if (yych == 'L') goto yy956;
	if (yych == 'l') goto yy956;
	goto yy37;
yy862:
	yych = *++cur;
	if (yych == 'I') goto yy957;
	if (yych == 'i') goto yy957;
	goto yy37;
yy863:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 484 "tokenizer.re"
	{ KW(SYNC_ALL) }
#line 6993 "tokenizer.cpp"
yy864:
	yych = *++cur;
	if (yych == 'G') goto yy958;
	if (yych == 'g') goto yy958;
	goto yy37;
yy865:
	yych = *++cur;
	if (yych == 'O') goto yy959;
	if (yych == 'o') goto yy959;
	goto yy37;
yy866:
	yych = *++cur;
	if (yych == 'M') goto yy960;
	if (yych == 'm') goto yy960;
	goto yy37;
yy867:
	yych = *++cur;
	if (yych == 'M') goto yy961;
	if (yych == 'm') goto yy961;
	goto yy37;
yy868:
	yych = *++cur;
	if (yych == 'E') goto yy962;
	if (yych == 'e') goto yy962;
	goto yy37;
yy869:
	yych = *++cur;
	if (yych == 'T') goto yy963;
	if (yych == 't') goto yy963;
	goto yy37;
yy870:
	yych = *++cur;
	if (yych == 'E') goto yy964;
	if (yych == 'e') goto yy964;
	goto yy37;
yy871:
	yych = *++cur;
	if (yych <= 'Z') {
		if (yych <= '/') goto yy59;
		if (yych <= '9') goto yy965;
		if (yych <= '@') goto yy59;
		goto yy966;
	} else {
		if (yych <= '_') {
			if (yych <= '^') goto yy59;
			goto yy966;
		} else {
			if (yych <= '`') goto yy59;
			if (yych <= 'z') goto yy966;
			goto yy59;
		}
	}
yy872:
	yych = *++cur;
	if (yych <= '/') goto yy637;
	if (yych <= '9') goto yy872;
	goto yy637;
yy873:
	yych = *++cur;
	if (yych <= 'Z') {
		if (yych <= '/') goto yy637;
		if (yych <= '9') goto yy873;
		if (yych <= '@') goto yy637;
		goto yy873;
	} else {
		if (yych <= '_') {
			if (yych <= '^') goto yy637;
			goto yy873;
		} else {
			if (yych <= '`') goto yy637;
			if (yych <= 'z') goto yy873;
			goto yy637;
		}
	}
yy874:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 252 "tokenizer.re"
	{ KW(ABSTRACT) }
#line 7076 "tokenizer.cpp"
yy875:
	yych = *++cur;
	if (yych == 'B') goto yy967;
	if (yych == 'b') goto yy967;
	goto yy37;
yy876:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 255 "tokenizer.re"
	{ KW(ALLOCATE) }
#line 7090 "tokenizer.cpp"
yy877:
	yych = *++cur;
	if (yych == 'N') goto yy968;
	if (yych == 'n') goto yy968;
	goto yy37;
yy878:
	yych = *++cur;
	if (yych == 'E') goto yy969;
	if (yych == 'e') goto yy969;
	goto yy37;
yy879:
	yych = *++cur;
	if (yych == 'N') goto yy970;
	if (yych == 'n') goto yy970;
	goto yy37;
yy880:
	yych = *++cur;
	if (yych == 'E') goto yy971;
	if (yych == 'e') goto yy971;
	goto yy37;
yy881:
	yych = *++cur;
	if (yych == 'A') goto yy972;
	if (yych == 'a') goto yy972;
	goto yy37;
yy882:
	yych = *++cur;
	if (yych == 'R') goto yy973;
	if (yych == 'r') goto yy973;
	goto yy37;
yy883:
	yych = *++cur;
	if (yych == 'I') goto yy974;
	if (yych == 'i') goto yy974;
	goto yy37;
yy884:
	yych = *++cur;
	if (yych == 'N') goto yy975;
	if (yych == 'n') goto yy975;
	goto yy37;
yy885:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 274 "tokenizer.re"
	{ KW(CONTAINS) }
#line 7139 "tokenizer.cpp"
yy886:
	yych = *++cur;
	if (yych == 'U') goto yy976;
	if (yych == 'u') goto yy976;
	goto yy37;
yy887:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 276 "tokenizer.re"
	{ KW(CONTINUE) }
#line 7153 "tokenizer.cpp"
yy888:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 277 "tokenizer.re"
	{ KW(CRITICAL) }
#line 7162 "tokenizer.cpp"
yy889:
	yych = *++cur;
	if (yych == 'T') goto yy977;
	if (yych == 't') goto yy977;
	goto yy37;
yy890:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 282 "tokenizer.re"
	{ KW(DEFERRED) }
#line 7176 "tokenizer.cpp"
yy891:
	yych = *++cur;
	if (yych == 'N') goto yy978;
	if (yych == 'n') goto yy978;
	goto yy37;
yy892:
	yych = *++cur;
	if (yych == 'M') goto yy979;
	if (yych == 'm') goto yy979;
	goto yy37;
yy893:
	yych = *++cur;
	if (yych == 'E') goto yy980;
	if (yych == 'e') goto yy980;
	goto yy37;
yy894:
	yych = *++cur;
	if (yych == 'L') goto yy981;
	if (yych == 'l') goto yy981;
	goto yy37;
yy895:
	yych = *++cur;
	if (yych == 'E') goto yy982;
	if (yych == 'e') goto yy982;
	goto yy37;
yy896:
	yych = *++cur;
	if (yych == 'C') goto yy983;
	if (yych == 'c') goto yy983;
	goto yy59;
yy897:
	yych = *++cur;
	if (yych == 'K') goto yy984;
	if (yych == 'k') goto yy984;
	goto yy59;
yy898:
	yych = *++cur;
	if (yych == 'I') goto yy986;
	if (yych == 'i') goto yy986;
	goto yy59;
yy899:
	++cur;
#line 329 "tokenizer.re"
	{ KW(END_ENUM) }
#line 7221 "tokenizer.cpp"
yy900:
	yych = *++cur;
	if (yych == 'L') goto yy987;
	if (yych == 'l') goto yy987;
	goto yy59;
yy901:
	yych = *++cur;
	if (yych == 'T') goto yy988;
	if (yych == 't') goto yy988;
	goto yy59;
yy902:
	yych = *++cur;
	if (yych == 'R') goto yy989;
	if (yych == 'r') goto yy989;
	goto yy59;
yy903:
	yych = *++cur;
	if (yych == 'L') goto yy990;
	if (yych == 'l') goto yy990;
	goto yy59;
yy904:
	yych = *++cur;
	if (yych == 'E') goto yy991;
	if (yych == 'e') goto yy991;
	goto yy59;
yy905:
	yych = *++cur;
	if (yych == 'R') goto yy992;
	if (yych == 'r') goto yy992;
	goto yy59;
yy906:
	yych = *++cur;
	if (yych == 'C') goto yy993;
	if (yych == 'c') goto yy993;
	goto yy59;
yy907:
	yych = *++cur;
	if (yych == 'O') goto yy994;
	if (yych == 'o') goto yy994;
	goto yy59;
yy908:
	yych = *++cur;
	if (yych == 'O') goto yy995;
	if (yych == 'o') goto yy995;
	goto yy59;
yy909:
	++cur;
#line 341 "tokenizer.re"
	{ KW(END_TEAM) }
#line 7271 "tokenizer.cpp"
yy910:
	++cur;
#line 353 "tokenizer.re"
	{ KW(END_TYPE) }
#line 7276 "tokenizer.cpp"
yy911:
	yych = *++cur;
	if (yych == 'E') goto yy996;
	if (yych == 'e') goto yy996;
	goto yy59;
yy912:
	++cur;
#line 374 "tokenizer.re"
	{ KW(END_FILE) }
#line 7286 "tokenizer.cpp"
yy913:
	yych = *++cur;
	if (yych == 'I') goto yy997;
	if (yych == 'i') goto yy997;
	goto yy37;
yy914:
	yyaccept = 13;
	yych = *(mar = ++cur);
	if (yybm[0+yych] & 8) {
		goto yy106;
	}
	if (yych <= '/') {
		if (yych <= '\v') {
			if (yych == '\t') goto yy998;
			if (yych >= '\v') goto yy998;
		} else {
			if (yych <= '\r') {
				if (yych >= '\r') goto yy998;
			} else {
				if (yych == ' ') goto yy998;
			}
		}
	} else {
		if (yych <= 'Z') {
			if (yych <= '@') {
				if (yych <= '9') goto yy36;
			} else {
				if (yych == 'D') goto yy999;
				goto yy36;
			}
		} else {
			if (yych <= 'c') {
				if (yych >= 'a') goto yy36;
			} else {
				if (yych <= 'd') goto yy999;
				if (yych <= 'z') goto yy36;
			}
		}
	}
yy915:
#line 313 "tokenizer.re"
	{ KW(ENDBLOCK) }
#line 7329 "tokenizer.cpp"
yy916:
	yych = *++cur;
	if (yych == 'C') goto yy1000;
	if (yych == 'c') goto yy1000;
	goto yy37;
yy917:
	yych = *++cur;
	if (yych == 'L') goto yy1001;
	if (yych == 'l') goto yy1001;
	goto yy37;
yy918:
	yych = *++cur;
	if (yych == 'I') goto yy1002;
	if (yych == 'i') goto yy1002;
	goto yy37;
yy919:
	yych = *++cur;
	if (yych == 'F') goto yy1003;
	if (yych == 'f') goto yy1003;
	goto yy37;
yy920:
	yych = *++cur;
	if (yych == 'E') goto yy1004;
	if (yych == 'e') goto yy1004;
	goto yy37;
yy921:
	yych = *++cur;
	if (yych == 'D') goto yy1005;
	if (yych == 'd') goto yy1005;
	goto yy37;
yy922:
	yych = *++cur;
	if (yych == 'A') goto yy1006;
	if (yych == 'a') goto yy1006;
	goto yy37;
yy923:
	yych = *++cur;
	if (yych == 'T') goto yy1007;
	if (yych == 't') goto yy1007;
	goto yy37;
yy924:
	yych = *++cur;
	if (yych == 'D') goto yy1008;
	if (yych == 'd') goto yy1008;
	goto yy37;
yy925:
	yych = *++cur;
	if (yych == 'U') goto yy1009;
	if (yych == 'u') goto yy1009;
	goto yy37;
yy926:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 372 "tokenizer.re"
	{ KW(ENDWHERE) }
#line 7388 "tokenizer.cpp"
yy927:
	yych = *++cur;
	if (yych == 'O') goto yy1010;
	if (yych == 'o') goto yy1010;
	goto yy37;
yy928:
	yych = *++cur;
	if (yych == 'N') goto yy1011;
	if (yych == 'n') goto yy1011;
	goto yy37;
yy929:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 386 "tokenizer.re"
	{ KW(EXTERNAL) }
#line 7407 "tokenizer.cpp"
yy930:
	yych = *++cur;
	if (yych == 'D') goto yy1012;
	if (yych == 'd') goto yy1012;
	goto yy37;
yy931:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 405 "tokenizer.re"
	{ KW(FORM_TEAM) }
#line 7421 "tokenizer.cpp"
yy932:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 406 "tokenizer.re"
	{ KW(FUNCTION) }
#line 7430 "tokenizer.cpp"
yy933:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 412 "tokenizer.re"
	{ KW(IMPLICIT) }
#line 7439 "tokenizer.cpp"
yy934:
	yych = *++cur;
	if (yych == 'A') goto yy1013;
	if (yych == 'a') goto yy1013;
	goto yy37;
yy935:
	yych = *++cur;
	if (yych == 'E') goto yy1014;
	if (yych == 'e') goto yy1014;
	goto yy37;
yy936:
	yych = *++cur;
	if (yych == 'C') goto yy1015;
	if (yych == 'c') goto yy1015;
	goto yy37;
yy937:
	yych = *++cur;
	if (yych == 'I') goto yy1016;
	if (yych == 'i') goto yy1016;
	goto yy37;
yy938:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 435 "tokenizer.re"
	{ KW(NAMELIST) }
#line 7468 "tokenizer.cpp"
yy939:
	yych = *++cur;
	if (yych == 'X') goto yy1017;
	if (yych == 'x') goto yy1017;
	goto yy37;
yy940:
	yych = *++cur;
	if (yych == 'I') goto yy1018;
	if (yych == 'i') goto yy1018;
	goto yy37;
yy941:
	yych = *++cur;
	if (yych == 'R') goto yy1019;
	if (yych == 'r') goto yy1019;
	goto yy37;
yy942:
	yych = *++cur;
	if (yych == 'R') goto yy1020;
	if (yych == 'r') goto yy1020;
	goto yy37;
yy943:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 445 "tokenizer.re"
	{ KW(OPERATOR) }
#line 7497 "tokenizer.cpp"
yy944:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 446 "tokenizer.re"
	{ KW(OPTIONAL) }
#line 7506 "tokenizer.cpp"
yy945:
	yych = *++cur;
	if (yych == 'R') goto yy1021;
	if (yych == 'r') goto yy1021;
	goto yy37;
yy946:
	yych = *++cur;
	if (yych == 'N') goto yy1022;
	if (yych == 'n') goto yy1022;
	goto yy37;
yy947:
	yych = *++cur;
	if (yych == 'E') goto yy1023;
	if (yych == 'e') goto yy1023;
	goto yy37;
yy948:
	yych = *++cur;
	if (yych == 'D') goto yy1024;
	if (yych == 'd') goto yy1024;
	goto yy37;
yy949:
	yych = *++cur;
	if (yych == 'E') goto yy1025;
	if (yych == 'e') goto yy1025;
	goto yy37;
yy950:
	yych = *++cur;
	if (yych == 'E') goto yy1026;
	if (yych == 'e') goto yy1026;
	goto yy37;
yy951:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 467 "tokenizer.re"
	{ KW(REQUIRES) }
#line 7545 "tokenizer.cpp"
yy952:
	yych = *++cur;
	if (yych == 'S') goto yy1027;
	if (yych == 's') goto yy1027;
	goto yy37;
yy953:
	yych = *++cur;
	if (yych == 'N') goto yy1028;
	if (yych == 'n') goto yy1028;
	goto yy37;
yy954:
	yych = *++cur;
	if (yych == 'P') goto yy1029;
	if (yych == 'p') goto yy1029;
	goto yy37;
yy955:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 476 "tokenizer.re"
	{ KW(SEQUENCE) }
#line 7569 "tokenizer.cpp"
yy956:
	yych = *++cur;
	if (yych == 'E') goto yy1030;
	if (yych == 'e') goto yy1030;
	goto yy37;
yy957:
	yych = *++cur;
	if (yych == 'N') goto yy1031;
	if (yych == 'n') goto yy1031;
	goto yy37;
yy958:
	yych = *++cur;
	if (yych == 'E') goto yy1032;
	if (yych == 'e') goto yy1032;
	goto yy37;
yy959:
	yych = *++cur;
	if (yych == 'R') goto yy1033;
	if (yych == 'r') goto yy1033;
	goto yy37;
yy960:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 487 "tokenizer.re"
	{ KW(SYNC_TEAM) }
#line 7598 "tokenizer.cpp"
yy961:
	yych = *++cur;
	if (yych == 'B') goto yy1034;
	if (yych == 'b') goto yy1034;
	goto yy37;
yy962:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 491 "tokenizer.re"
	{ KW(TEMPLATE) }
#line 7612 "tokenizer.cpp"
yy963:
	yych = *++cur;
	if (yych == 'T') goto yy1035;
	if (yych == 't') goto yy1035;
	goto yy37;
yy964:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 498 "tokenizer.re"
	{ KW(VOLATILE) }
#line 7626 "tokenizer.cpp"
yy965:
	yych = *++cur;
	if (yych <= '/') goto yy765;
	if (yych <= '9') goto yy965;
	goto yy765;
yy966:
	yych = *++cur;
	if (yych <= 'Z') {
		if (yych <= '/') goto yy765;
		if (yych <= '9') goto yy966;
		if (yych <= '@') goto yy765;
		goto yy966;
	} else {
		if (yych <= '_') {
			if (yych <= '^') goto yy765;
			goto yy966;
		} else {
			if (yych <= '`') goto yy765;
			if (yych <= 'z') goto yy966;
			goto yy765;
		}
	}
yy967:
	yych = *++cur;
	if (yych == 'L') goto yy1036;
	if (yych == 'l') goto yy1036;
	goto yy37;
yy968:
	yych = *++cur;
	if (yych == 'T') goto yy1037;
	if (yych == 't') goto yy1037;
	goto yy37;
yy969:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 258 "tokenizer.re"
	{ KW(ASSOCIATE) }
#line 7667 "tokenizer.cpp"
yy970:
	yych = *++cur;
	if (yych == 'O') goto yy1038;
	if (yych == 'o') goto yy1038;
	goto yy37;
yy971:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 260 "tokenizer.re"
	{ KW(BACKSPACE) }
#line 7681 "tokenizer.cpp"
yy972:
	yych = *++cur;
	if (yych == 'M') goto yy1039;
	if (yych == 'm') goto yy1039;
	goto yy37;
yy973:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 267 "tokenizer.re"
	{ KW(CHARACTER) }
#line 7695 "tokenizer.cpp"
yy974:
	yych = *++cur;
	if (yych == 'O') goto yy1040;
	if (yych == 'o') goto yy1040;
	goto yy37;
yy975:
	yych = *++cur;
	if (yych == 'T') goto yy1041;
	if (yych == 't') goto yy1041;
	goto yy37;
yy976:
	yych = *++cur;
	if (yych == 'S') goto yy1042;
	if (yych == 's') goto yy1042;
	goto yy37;
yy977:
	yych = *++cur;
	if (yych == 'E') goto yy1043;
	if (yych == 'e') goto yy1043;
	goto yy37;
yy978:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 283 "tokenizer.re"
	{ KW(DIMENSION) }
#line 7724 "tokenizer.cpp"
yy979:
	yych = *++cur;
	if (yych == 'P') goto yy1044;
	if (yych == 'p') goto yy1044;
	goto yy37;
yy980:
	yych = *++cur;
	if (yych == 'C') goto yy1045;
	if (yych == 'c') goto yy1045;
	goto yy37;
yy981:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 296 "tokenizer.re"
	{ KW(ELEMENTAL) }
#line 7743 "tokenizer.cpp"
yy982:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 299 "tokenizer.re"
	{ KW(ELSEWHERE) }
#line 7752 "tokenizer.cpp"
yy983:
	yych = *++cur;
	if (yych == 'I') goto yy1046;
	if (yych == 'i') goto yy1046;
	goto yy59;
yy984:
	yyaccept = 14;
	yych = *(mar = ++cur);
	if (yych <= '\r') {
		if (yych <= '\n') {
			if (yych == '\t') goto yy1047;
		} else {
			if (yych != '\f') goto yy1047;
		}
	} else {
		if (yych <= 'C') {
			if (yych == ' ') goto yy1047;
		} else {
			if (yych <= 'D') goto yy1048;
			if (yych == 'd') goto yy1048;
		}
	}
yy985:
#line 312 "tokenizer.re"
	{ KW(END_BLOCK) }
#line 7778 "tokenizer.cpp"
yy986:
	yych = *++cur;
	if (yych == 'C') goto yy1049;
	if (yych == 'c') goto yy1049;
	goto yy59;
yy987:
	yych = *++cur;
	if (yych == 'L') goto yy1050;
	if (yych == 'l') goto yy1050;
	goto yy59;
yy988:
	yych = *++cur;
	if (yych == 'I') goto yy1051;
	if (yych == 'i') goto yy1051;
	goto yy59;
yy989:
	yych = *++cur;
	if (yych == 'F') goto yy1052;
	if (yych == 'f') goto yy1052;
	goto yy59;
yy990:
	yych = *++cur;
	if (yych == 'E') goto yy1053;
	if (yych == 'e') goto yy1053;
	goto yy59;
yy991:
	yych = *++cur;
	if (yych == 'D') goto yy1054;
	if (yych == 'd') goto yy1054;
	goto yy59;
yy992:
	yych = *++cur;
	if (yych == 'A') goto yy1055;
	if (yych == 'a') goto yy1055;
	goto yy59;
yy993:
	yych = *++cur;
	if (yych == 'T') goto yy1056;
	if (yych == 't') goto yy1056;
	goto yy59;
yy994:
	yych = *++cur;
	if (yych == 'D') goto yy1057;
	if (yych == 'd') goto yy1057;
	goto yy59;
yy995:
	yych = *++cur;
	if (yych == 'U') goto yy1058;
	if (yych == 'u') goto yy1058;
	goto yy59;
yy996:
	++cur;
#line 371 "tokenizer.re"
	{ KW(END_WHERE) }
#line 7833 "tokenizer.cpp"
yy997:
	yych = *++cur;
	if (yych == 'A') goto yy1059;
	if (yych == 'a') goto yy1059;
	goto yy37;
yy998:
	yych = *++cur;
	if (yych <= '\r') {
		if (yych <= '\n') {
			if (yych == '\t') goto yy998;
			goto yy59;
		} else {
			if (yych == '\f') goto yy59;
			goto yy998;
		}
	} else {
		if (yych <= 'C') {
			if (yych == ' ') goto yy998;
			goto yy59;
		} else {
			if (yych <= 'D') goto yy1060;
			if (yych == 'd') goto yy1060;
			goto yy59;
		}
	}
yy999:
	yych = *++cur;
	if (yych == 'A') goto yy1061;
	if (yych == 'a') goto yy1061;
	goto yy37;
yy1000:
	yych = *++cur;
	if (yych == 'A') goto yy1062;
	if (yych == 'a') goto yy1062;
	goto yy37;
yy1001:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 345 "tokenizer.re"
	{ KW(ENDFORALL) }
#line 7877 "tokenizer.cpp"
yy1002:
	yych = *++cur;
	if (yych == 'O') goto yy1063;
	if (yych == 'o') goto yy1063;
	goto yy37;
yy1003:
	yych = *++cur;
	if (yych == 'A') goto yy1064;
	if (yych == 'a') goto yy1064;
	goto yy37;
yy1004:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 307 "tokenizer.re"
	{ KW(ENDMODULE) }
#line 7896 "tokenizer.cpp"
yy1005:
	yych = *++cur;
	if (yych == 'U') goto yy1065;
	if (yych == 'u') goto yy1065;
	goto yy37;
yy1006:
	yych = *++cur;
	if (yych == 'M') goto yy1066;
	if (yych == 'm') goto yy1066;
	goto yy37;
yy1007:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 333 "tokenizer.re"
	{ KW(ENDSELECT) }
#line 7915 "tokenizer.cpp"
yy1008:
	yych = *++cur;
	if (yych == 'U') goto yy1067;
	if (yych == 'u') goto yy1067;
	goto yy37;
yy1009:
	yych = *++cur;
	if (yych == 'T') goto yy1068;
	if (yych == 't') goto yy1068;
	goto yy37;
yy1010:
	yych = *++cur;
	if (yych == 'R') goto yy1069;
	if (yych == 'r') goto yy1069;
	goto yy37;
yy1011:
	yych = *++cur;
	if (yych == 'C') goto yy1070;
	if (yych == 'c') goto yy1070;
	goto yy37;
yy1012:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 403 "tokenizer.re"
	{ KW(FORMATTED) }
#line 7944 "tokenizer.cpp"
yy1013:
	yych = *++cur;
	if (yych == 'T') goto yy1071;
	if (yych == 't') goto yy1071;
	goto yy37;
yy1014:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 423 "tokenizer.re"
	{ KW(INTERFACE) }
#line 7958 "tokenizer.cpp"
yy1015:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 424 "tokenizer.re"
	{ KW(INTRINSIC) }
#line 7967 "tokenizer.cpp"
yy1016:
	yych = *++cur;
	if (yych == 'T') goto yy1072;
	if (yych == 't') goto yy1072;
	goto yy37;
yy1017:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 436 "tokenizer.re"
	{ KW(NEW_INDEX) }
#line 7981 "tokenizer.cpp"
yy1018:
	yych = *++cur;
	if (yych == 'N') goto yy1073;
	if (yych == 'n') goto yy1073;
	goto yy37;
yy1019:
	yych = *++cur;
	if (yych == 'I') goto yy1074;
	if (yych == 'i') goto yy1074;
	goto yy37;
yy1020:
	yych = *++cur;
	if (yych == 'S') goto yy1075;
	if (yych == 's') goto yy1075;
	goto yy37;
yy1021:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 448 "tokenizer.re"
	{ KW(PARAMETER) }
#line 8005 "tokenizer.cpp"
yy1022:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 452 "tokenizer.re"
	{ KW(PRECISION) }
#line 8014 "tokenizer.cpp"
yy1023:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 455 "tokenizer.re"
	{ KW(PROCEDURE) }
#line 8023 "tokenizer.cpp"
yy1024:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 457 "tokenizer.re"
	{ KW(PROTECTED) }
#line 8032 "tokenizer.cpp"
yy1025:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 464 "tokenizer.re"
	{ KW(RECURSIVE) }
#line 8041 "tokenizer.cpp"
yy1026:
	yych = *++cur;
	if (yych == 'N') goto yy1076;
	if (yych == 'n') goto yy1076;
	goto yy37;
yy1027:
	yych = *++cur;
	if (yych == 'E') goto yy1077;
	if (yych == 'e') goto yy1077;
	goto yy37;
yy1028:
	yych = *++cur;
	if (yych == 'K') goto yy1078;
	if (yych == 'k') goto yy1078;
	goto yy37;
yy1029:
	yych = *++cur;
	if (yych == 'E') goto yy1079;
	if (yych == 'e') goto yy1079;
	goto yy37;
yy1030:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 481 "tokenizer.re"
	{ KW(SUBMODULE) }
#line 8070 "tokenizer.cpp"
yy1031:
	yych = *++cur;
	if (yych == 'E') goto yy1080;
	if (yych == 'e') goto yy1080;
	goto yy37;
yy1032:
	yych = *++cur;
	if (yych == 'S') goto yy1081;
	if (yych == 's') goto yy1081;
	goto yy37;
yy1033:
	yych = *++cur;
	if (yych == 'Y') goto yy1082;
	if (yych == 'y') goto yy1082;
	goto yy37;
yy1034:
	yych = *++cur;
	if (yych == 'E') goto yy1083;
	if (yych == 'e') goto yy1083;
	goto yy37;
yy1035:
	yych = *++cur;
	if (yych == 'E') goto yy1084;
	if (yych == 'e') goto yy1084;
	goto yy37;
yy1036:
	yych = *++cur;
	if (yych == 'E') goto yy1085;
	if (yych == 'e') goto yy1085;
	goto yy37;
yy1037:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 257 "tokenizer.re"
	{ KW(ASSIGNMENT) }
#line 8109 "tokenizer.cpp"
yy1038:
	yych = *++cur;
	if (yych == 'U') goto yy1086;
	if (yych == 'u') goto yy1086;
	goto yy37;
yy1039:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 266 "tokenizer.re"
	{ KW(CHANGE_TEAM) }
#line 8123 "tokenizer.cpp"
yy1040:
	yych = *++cur;
	if (yych == 'N') goto yy1087;
	if (yych == 'n') goto yy1087;
	goto yy37;
yy1041:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 273 "tokenizer.re"
	{ KW(CONCURRENT) }
#line 8137 "tokenizer.cpp"
yy1042:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 275 "tokenizer.re"
	{ KW(CONTIGUOUS) }
#line 8146 "tokenizer.cpp"
yy1043:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 280 "tokenizer.re"
	{ KW(DEALLOCATE) }
#line 8155 "tokenizer.cpp"
yy1044:
	yych = *++cur;
	if (yych == 'L') goto yy1088;
	if (yych == 'l') goto yy1088;
	goto yy37;
yy1045:
	yych = *++cur;
	if (yych == 'I') goto yy1089;
	if (yych == 'i') goto yy1089;
	goto yy37;
yy1046:
	yych = *++cur;
	if (yych == 'A') goto yy1090;
	if (yych == 'a') goto yy1090;
	goto yy59;
yy1047:
	yych = *++cur;
	if (yych <= '\r') {
		if (yych <= '\n') {
			if (yych == '\t') goto yy1047;
			goto yy59;
		} else {
			if (yych == '\f') goto yy59;
			goto yy1047;
		}
	} else {
		if (yych <= 'C') {
			if (yych == ' ') goto yy1047;
			goto yy59;
		} else {
			if (yych <= 'D') goto yy1091;
			if (yych == 'd') goto yy1091;
			goto yy59;
		}
	}
yy1048:
	yych = *++cur;
	if (yych == 'A') goto yy1092;
	if (yych == 'a') goto yy1092;
	goto yy59;
yy1049:
	yych = *++cur;
	if (yych == 'A') goto yy1093;
	if (yych == 'a') goto yy1093;
	goto yy59;
yy1050:
	++cur;
#line 344 "tokenizer.re"
	{ KW(END_FORALL) }
#line 8205 "tokenizer.cpp"
yy1051:
	yych = *++cur;
	if (yych == 'O') goto yy1094;
	if (yych == 'o') goto yy1094;
	goto yy59;
yy1052:
	yych = *++cur;
	if (yych == 'A') goto yy1095;
	if (yych == 'a') goto yy1095;
	goto yy59;
yy1053:
	++cur;
#line 306 "tokenizer.re"
	{ KW(END_MODULE) }
#line 8220 "tokenizer.cpp"
yy1054:
	yych = *++cur;
	if (yych == 'U') goto yy1096;
	if (yych == 'u') goto yy1096;
	goto yy59;
yy1055:
	yych = *++cur;
	if (yych == 'M') goto yy1097;
	if (yych == 'm') goto yy1097;
	goto yy59;
yy1056:
	++cur;
#line 332 "tokenizer.re"
	{ KW(END_SELECT) }
#line 8235 "tokenizer.cpp"
yy1057:
	yych = *++cur;
	if (yych == 'U') goto yy1098;
	if (yych == 'u') goto yy1098;
	goto yy59;
yy1058:
	yych = *++cur;
	if (yych == 'T') goto yy1099;
	if (yych == 't') goto yy1099;
	goto yy59;
yy1059:
	yych = *++cur;
	if (yych == 'T') goto yy1100;
	if (yych == 't') goto yy1100;
	goto yy37;
yy1060:
	yych = *++cur;
	if (yych == 'A') goto yy1101;
	if (yych == 'a') goto yy1101;
	goto yy59;
yy1061:
	yych = *++cur;
	if (yych == 'T') goto yy1102;
	if (yych == 't') goto yy1102;
	goto yy37;
yy1062:
	yych = *++cur;
	if (yych == 'L') goto yy1103;
	if (yych == 'l') goto yy1103;
	goto yy37;
yy1063:
	yych = *++cur;
	if (yych == 'N') goto yy1104;
	if (yych == 'n') goto yy1104;
	goto yy37;
yy1064:
	yych = *++cur;
	if (yych == 'C') goto yy1105;
	if (yych == 'c') goto yy1105;
	goto yy37;
yy1065:
	yych = *++cur;
	if (yych == 'R') goto yy1106;
	if (yych == 'r') goto yy1106;
	goto yy37;
yy1066:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 304 "tokenizer.re"
	{ KW(ENDPROGRAM) }
#line 8289 "tokenizer.cpp"
yy1067:
	yych = *++cur;
	if (yych == 'L') goto yy1107;
	if (yych == 'l') goto yy1107;
	goto yy37;
yy1068:
	yych = *++cur;
	if (yych == 'I') goto yy1108;
	if (yych == 'i') goto yy1108;
	goto yy37;
yy1069:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 379 "tokenizer.re"
	{ KW(ENUMERATOR) }
#line 8308 "tokenizer.cpp"
yy1070:
	yych = *++cur;
	if (yych == 'E') goto yy1109;
	if (yych == 'e') goto yy1109;
	goto yy37;
yy1071:
	yych = *++cur;
	if (yych == 'E') goto yy1110;
	if (yych == 'e') goto yy1110;
	goto yy37;
yy1072:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 429 "tokenizer.re"
	{ KW(LOCAL_INIT) }
#line 8327 "tokenizer.cpp"
yy1073:
	yych = *++cur;
	if (yych == 'S') goto yy1111;
	if (yych == 's') goto yy1111;
	goto yy37;
yy1074:
	yych = *++cur;
	if (yych == 'D') goto yy1112;
	if (yych == 'd') goto yy1112;
	goto yy37;
yy1075:
	yych = *++cur;
	if (yych == 'I') goto yy1113;
	if (yych == 'i') goto yy1113;
	goto yy37;
yy1076:
	yych = *++cur;
	if (yych == 'T') goto yy1114;
	if (yych == 't') goto yy1114;
	goto yy37;
yy1077:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 473 "tokenizer.re"
	{ KW(SELECT_CASE) }
#line 8356 "tokenizer.cpp"
yy1078:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 474 "tokenizer.re"
	{ KW(SELECT_RANK) }
#line 8365 "tokenizer.cpp"
yy1079:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 475 "tokenizer.re"
	{ KW(SELECT_TYPE) }
#line 8374 "tokenizer.cpp"
yy1080:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 482 "tokenizer.re"
	{ KW(SUBROUTINE) }
#line 8383 "tokenizer.cpp"
yy1081:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 485 "tokenizer.re"
	{ KW(SYNC_IMAGES) }
#line 8392 "tokenizer.cpp"
yy1082:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 486 "tokenizer.re"
	{ KW(SYNC_MEMORY) }
#line 8401 "tokenizer.cpp"
yy1083:
	yych = *++cur;
	if (yych == 'R') goto yy1115;
	if (yych == 'r') goto yy1115;
	goto yy37;
yy1084:
	yych = *++cur;
	if (yych == 'D') goto yy1116;
	if (yych == 'd') goto yy1116;
	goto yy37;
yy1085:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 254 "tokenizer.re"
	{ KW(ALLOCATABLE) }
#line 8420 "tokenizer.cpp"
yy1086:
	yych = *++cur;
	if (yych == 'S') goto yy1117;
	if (yych == 's') goto yy1117;
	goto yy37;
yy1087:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 270 "tokenizer.re"
	{ KW(CODIMENSION) }
#line 8434 "tokenizer.cpp"
yy1088:
	yych = *++cur;
	if (yych == 'E') goto yy1118;
	if (yych == 'e') goto yy1118;
	goto yy37;
yy1089:
	yych = *++cur;
	if (yych == 'S') goto yy1119;
	if (yych == 's') goto yy1119;
	goto yy37;
yy1090:
	yych = *++cur;
	if (yych == 'T') goto yy1120;
	if (yych == 't') goto yy1120;
	goto yy59;
yy1091:
	yych = *++cur;
	if (yych == 'A') goto yy1121;
	if (yych == 'a') goto yy1121;
	goto yy59;
yy1092:
	yych = *++cur;
	if (yych == 'T') goto yy1122;
	if (yych == 't') goto yy1122;
	goto yy59;
yy1093:
	yych = *++cur;
	if (yych == 'L') goto yy1123;
	if (yych == 'l') goto yy1123;
	goto yy59;
yy1094:
	yych = *++cur;
	if (yych == 'N') goto yy1124;
	if (yych == 'n') goto yy1124;
	goto yy59;
yy1095:
	yych = *++cur;
	if (yych == 'C') goto yy1125;
	if (yych == 'c') goto yy1125;
	goto yy59;
yy1096:
	yych = *++cur;
	if (yych == 'R') goto yy1126;
	if (yych == 'r') goto yy1126;
	goto yy59;
yy1097:
	++cur;
#line 303 "tokenizer.re"
	{ KW(END_PROGRAM) }
#line 8484 "tokenizer.cpp"
yy1098:
	yych = *++cur;
	if (yych == 'L') goto yy1127;
	if (yych == 'l') goto yy1127;
	goto yy59;
yy1099:
	yych = *++cur;
	if (yych == 'I') goto yy1128;
	if (yych == 'i') goto yy1128;
	goto yy59;
yy1100:
	yych = *++cur;
	if (yych == 'E') goto yy1129;
	if (yych == 'e') goto yy1129;
	goto yy37;
yy1101:
	yych = *++cur;
	if (yych == 'T') goto yy1130;
	if (yych == 't') goto yy1130;
	goto yy59;
yy1102:
	yych = *++cur;
	if (yych == 'A') goto yy1131;
	if (yych == 'a') goto yy1131;
	goto yy37;
yy1103:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 339 "tokenizer.re"
	{ KW(ENDCRITICAL) }
#line 8518 "tokenizer.cpp"
yy1104:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 324 "tokenizer.re"
	{ KW(ENDFUNCTION) }
#line 8527 "tokenizer.cpp"
yy1105:
	yych = *++cur;
	if (yych == 'E') goto yy1132;
	if (yych == 'e') goto yy1132;
	goto yy37;
yy1106:
	yych = *++cur;
	if (yych == 'E') goto yy1133;
	if (yych == 'e') goto yy1133;
	goto yy37;
yy1107:
	yych = *++cur;
	if (yych == 'E') goto yy1134;
	if (yych == 'e') goto yy1134;
	goto yy37;
yy1108:
	yych = *++cur;
	if (yych == 'N') goto yy1135;
	if (yych == 'n') goto yy1135;
	goto yy37;
yy1109:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 380 "tokenizer.re"
	{ KW(EQUIVALENCE) }
#line 8556 "tokenizer.cpp"
yy1110:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 420 "tokenizer.re"
	{ KW(INSTANTIATE) }
#line 8565 "tokenizer.cpp"
yy1111:
	yych = *++cur;
	if (yych == 'I') goto yy1136;
	if (yych == 'i') goto yy1136;
	goto yy37;
yy1112:
	yych = *++cur;
	if (yych == 'A') goto yy1137;
	if (yych == 'a') goto yy1137;
	goto yy37;
yy1113:
	yych = *++cur;
	if (yych == 'V') goto yy1138;
	if (yych == 'v') goto yy1138;
	goto yy37;
yy1114:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 466 "tokenizer.re"
	{ KW(REQUIREMENT) }
#line 8589 "tokenizer.cpp"
yy1115:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 490 "tokenizer.re"
	{ KW(TEAM_NUMBER) }
#line 8598 "tokenizer.cpp"
yy1116:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 495 "tokenizer.re"
	{ KW(UNFORMATTED) }
#line 8607 "tokenizer.cpp"
yy1117:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 259 "tokenizer.re"
	{ KW(ASYNCHRONOUS) }
#line 8616 "tokenizer.cpp"
yy1118:
	yych = *++cur;
	if (yych == 'X') goto yy1139;
	if (yych == 'x') goto yy1139;
	goto yy37;
yy1119:
	yych = *++cur;
	if (yych == 'I') goto yy1140;
	if (yych == 'i') goto yy1140;
	goto yy37;
yy1120:
	yych = *++cur;
	if (yych == 'E') goto yy1141;
	if (yych == 'e') goto yy1141;
	goto yy59;
yy1121:
	yych = *++cur;
	if (yych == 'T') goto yy1142;
	if (yych == 't') goto yy1142;
	goto yy59;
yy1122:
	yych = *++cur;
	if (yych == 'A') goto yy1143;
	if (yych == 'a') goto yy1143;
	goto yy59;
yy1123:
	++cur;
#line 338 "tokenizer.re"
	{ KW(END_CRITICAL) }
#line 8646 "tokenizer.cpp"
yy1124:
	++cur;
#line 323 "tokenizer.re"
	{ KW(END_FUNCTION) }
#line 8651 "tokenizer.cpp"
yy1125:
	yych = *++cur;
	if (yych == 'E') goto yy1144;
	if (yych == 'e') goto yy1144;
	goto yy59;
yy1126:
	yych = *++cur;
	if (yych == 'E') goto yy1145;
	if (yych == 'e') goto yy1145;
	goto yy59;
yy1127:
	yych = *++cur;
	if (yych == 'E') goto yy1146;
	if (yych == 'e') goto yy1146;
	goto yy59;
yy1128:
	yych = *++cur;
	if (yych == 'N') goto yy1147;
	if (yych == 'n') goto yy1147;
	goto yy59;
yy1129:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 336 "tokenizer.re"
	{ KW(ENDASSOCIATE) }
#line 8680 "tokenizer.cpp"
yy1130:
	yych = *++cur;
	if (yych == 'A') goto yy1148;
	if (yych == 'a') goto yy1148;
	goto yy59;
yy1131:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 318 "tokenizer.re"
	{ KW(ENDBLOCKDATA) }
#line 8694 "tokenizer.cpp"
yy1132:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 351 "tokenizer.re"
	{ KW(ENDINTERFACE) }
#line 8703 "tokenizer.cpp"
yy1133:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 327 "tokenizer.re"
	{ KW(ENDPROCEDURE) }
#line 8712 "tokenizer.cpp"
yy1134:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 310 "tokenizer.re"
	{ KW(ENDSUBMODULE) }
#line 8721 "tokenizer.cpp"
yy1135:
	yych = *++cur;
	if (yych == 'E') goto yy1149;
	if (yych == 'e') goto yy1149;
	goto yy37;
yy1136:
	yych = *++cur;
	if (yych == 'C') goto yy1150;
	if (yych == 'c') goto yy1150;
	goto yy37;
yy1137:
	yych = *++cur;
	if (yych == 'B') goto yy1151;
	if (yych == 'b') goto yy1151;
	goto yy37;
yy1138:
	yych = *++cur;
	if (yych == 'E') goto yy1152;
	if (yych == 'e') goto yy1152;
	goto yy37;
yy1139:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 295 "tokenizer.re"
	{ KW(DOUBLE_COMPLEX) }
#line 8750 "tokenizer.cpp"
yy1140:
	yych = *++cur;
	if (yych == 'O') goto yy1153;
	if (yych == 'o') goto yy1153;
	goto yy37;
yy1141:
	++cur;
#line 335 "tokenizer.re"
	{ KW(END_ASSOCIATE) }
#line 8760 "tokenizer.cpp"
yy1142:
	yych = *++cur;
	if (yych == 'A') goto yy1154;
	if (yych == 'a') goto yy1154;
	goto yy59;
yy1143:
	++cur;
#line 317 "tokenizer.re"
	{ KW(END_BLOCK_DATA) }
#line 8770 "tokenizer.cpp"
yy1144:
	++cur;
#line 350 "tokenizer.re"
	{ KW(END_INTERFACE) }
#line 8775 "tokenizer.cpp"
yy1145:
	++cur;
#line 326 "tokenizer.re"
	{ KW(END_PROCEDURE) }
#line 8780 "tokenizer.cpp"
yy1146:
	++cur;
#line 309 "tokenizer.re"
	{ KW(END_SUBMODULE) }
#line 8785 "tokenizer.cpp"
yy1147:
	yych = *++cur;
	if (yych == 'E') goto yy1155;
	if (yych == 'e') goto yy1155;
	goto yy59;
yy1148:
	++cur;
#line 316 "tokenizer.re"
	{ KW(END_BLOCK_DATA) }
#line 8795 "tokenizer.cpp"
yy1149:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 321 "tokenizer.re"
	{ KW(ENDSUBROUTINE) }
#line 8804 "tokenizer.cpp"
yy1150:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 438 "tokenizer.re"
	{ KW(NON_INTRINSIC) }
#line 8813 "tokenizer.cpp"
yy1151:
	yych = *++cur;
	if (yych == 'L') goto yy1156;
	if (yych == 'l') goto yy1156;
	goto yy37;
yy1152:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 440 "tokenizer.re"
	{ KW(NON_RECURSIVE) }
#line 8827 "tokenizer.cpp"
yy1153:
	yych = *++cur;
	if (yych == 'N') goto yy1157;
	if (yych == 'n') goto yy1157;
	goto yy37;
yy1154:
	++cur;
#line 315 "tokenizer.re"
	{ KW(END_BLOCK_DATA) }
#line 8837 "tokenizer.cpp"
yy1155:
	++cur;
#line 320 "tokenizer.re"
	{ KW(END_SUBROUTINE) }
#line 8842 "tokenizer.cpp"
yy1156:
	yych = *++cur;
	if (yych == 'E') goto yy1158;
	if (yych == 'e') goto yy1158;
	goto yy37;
yy1157:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 294 "tokenizer.re"
	{ KW(DOUBLE_PRECISION) }
#line 8856 "tokenizer.cpp"
yy1158:
	yych = *++cur;
	if (yybm[256+yych] & 32) {
		goto yy36;
	}
	if (yych == '_') goto yy106;
#line 439 "tokenizer.re"
	{ KW(NON_OVERRIDABLE) }
#line 8865 "tokenizer.cpp"
}
#line 664 "tokenizer.re"

    }
}

std::string token(unsigned char *tok, unsigned char* cur)
{
    return std::string((char *)tok, cur - tok);
}

void token_loc(Location &loc)
{
    loc.first = 1;
    loc.last = 1;
}

void lex_format(unsigned char *&cur, Location &loc,
        unsigned char *&start) {
    int num_paren = 0;
    for (;;) {
        unsigned char *tok = cur;
        unsigned char *mar;
        
#line 8890 "tokenizer.cpp"
{
	unsigned char yych;
	unsigned int yyaccept = 0;
	static const unsigned char yybm[] = {
		  0, 208, 208, 208, 208, 208, 208, 208, 
		208, 244, 176, 244, 208, 244, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		244, 208, 192, 208, 208, 208, 208,  80, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		216, 216, 216, 216, 216, 216, 216, 216, 
		216, 216, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
		208, 208, 208, 208, 208, 208, 208, 208, 
	};
	yych = *cur;
	if (yybm[0+yych] & 4) {
		goto yy1163;
	}
	switch (yych) {
		case 0x00: goto yy1160;
		case '"': goto yy1164;
		case '&': goto yy1165;
		case '\'': goto yy1166;
		case '(': goto yy1167;
		case ')': goto yy1168;
		case '*': goto yy1169;
		case ',': goto yy1170;
		case '-': goto yy1171;
		case '/':
		case ':': goto yy1172;
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
		case '5':
		case '6':
		case '7':
		case '8':
		case '9': goto yy1174;
		case 'A':
		case 'a': goto yy1175;
		case 'B':
		case 'I':
		case 'O':
		case 'Z':
		case 'b':
		case 'i':
		case 'o':
		case 'z': goto yy1177;
		case 'D':
		case 'F':
		case 'd':
		case 'f': goto yy1178;
		case 'E':
		case 'e': goto yy1179;
		case 'G':
		case 'g': goto yy1180;
		case 'L':
		case 'l': goto yy1181;
		case 'P':
		case 'p': goto yy1182;
		case 'T':
		case 't': goto yy1183;
		case 'X':
		case 'x': goto yy1184;
		default: goto yy1161;
	}
yy1160:
	++cur;
#line 757 "tokenizer.re"
	{
                token_loc(loc);
                std::string t = token(tok, cur);
                throw LFortran::parser_local::TokenizerError(
                    "End of file not expected in `format` statement '" + t + "'", loc);
            }
#line 8991 "tokenizer.cpp"
yy1161:
	++cur;
yy1162:
#line 723 "tokenizer.re"
	{
                token_loc(loc);
                std::string t = token(tok, cur);
                throw LFortran::parser_local::TokenizerError("Token '" + t
                    + "' is not recognized in `format` statement", loc);
            }
#line 9002 "tokenizer.cpp"
yy1163:
	yych = *++cur;
	if (yybm[0+yych] & 4) {
		goto yy1163;
	}
#line 763 "tokenizer.re"
	{ continue; }
#line 9010 "tokenizer.cpp"
yy1164:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 0x00) goto yy1162;
	goto yy1186;
yy1165:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= '\f') {
		if (yych <= 0x08) goto yy1162;
		if (yych <= '\v') goto yy1191;
		goto yy1162;
	} else {
		if (yych <= '\r') goto yy1191;
		if (yych <= 0x1F) goto yy1162;
		if (yych <= '!') goto yy1191;
		goto yy1162;
	}
yy1166:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 0x00) goto yy1162;
	goto yy1196;
yy1167:
	++cur;
#line 729 "tokenizer.re"
	{
                if (num_paren == 0) {
                    num_paren++;
                    start = cur;
                    continue;
                } else {
                    cur--;
                    unsigned char *tmp;
                    lex_format(cur, loc, tmp);
                    continue;
                }
            }
#line 9049 "tokenizer.cpp"
yy1168:
	++cur;
#line 753 "tokenizer.re"
	{
                LCOMPILERS_ASSERT(num_paren == 1);
                return;
            }
#line 9057 "tokenizer.cpp"
yy1169:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy1162;
			goto yy1198;
		} else {
			if (yych == '\v') goto yy1198;
			goto yy1162;
		}
	} else {
		if (yych <= ' ') {
			if (yych <= '\r') goto yy1198;
			if (yych <= 0x1F) goto yy1162;
			goto yy1198;
		} else {
			if (yych == '(') goto yy1199;
			goto yy1162;
		}
	}
yy1170:
	++cur;
#line 764 "tokenizer.re"
	{ continue; }
#line 9083 "tokenizer.cpp"
yy1171:
	++cur;
#line 768 "tokenizer.re"
	{ continue; }
#line 9088 "tokenizer.cpp"
yy1172:
	++cur;
yy1173:
#line 770 "tokenizer.re"
	{ continue; }
#line 9094 "tokenizer.cpp"
yy1174:
	yyaccept = 0;
	yych = *(mar = ++cur);
	switch (yych) {
		case '\t':
		case '\v':
		case '\r':
		case ' ':
		case '(':
		case '/':
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
		case '5':
		case '6':
		case '7':
		case '8':
		case '9':
		case 'A':
		case 'B':
		case 'D':
		case 'E':
		case 'F':
		case 'G':
		case 'I':
		case 'L':
		case 'O':
		case 'P':
		case 'X':
		case 'Z':
		case 'a':
		case 'b':
		case 'd':
		case 'e':
		case 'f':
		case 'g':
		case 'i':
		case 'l':
		case 'o':
		case 'p':
		case 'x':
		case 'z': goto yy1203;
		default: goto yy1162;
	}
yy1175:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy1175;
	}
yy1176:
#line 769 "tokenizer.re"
	{ continue; }
#line 9149 "tokenizer.cpp"
yy1177:
	yych = *++cur;
	if (yych <= '/') goto yy1162;
	if (yych <= '9') goto yy1209;
	goto yy1162;
yy1178:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= '/') goto yy1162;
	if (yych <= '9') goto yy1210;
	goto yy1162;
yy1179:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 'W') {
		if (yych <= 'M') {
			if (yych <= '/') goto yy1162;
			if (yych <= '9') goto yy1211;
			goto yy1162;
		} else {
			if (yych <= 'N') goto yy1212;
			if (yych == 'S') goto yy1212;
			goto yy1162;
		}
	} else {
		if (yych <= 'r') {
			if (yych <= 'X') goto yy1212;
			if (yych == 'n') goto yy1212;
			goto yy1162;
		} else {
			if (yych <= 's') goto yy1212;
			if (yych == 'x') goto yy1212;
			goto yy1162;
		}
	}
yy1180:
	yych = *++cur;
	if (yych <= '/') goto yy1162;
	if (yych <= '9') goto yy1213;
	goto yy1162;
yy1181:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy1175;
	}
	goto yy1162;
yy1182:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yych <= 'D') goto yy1176;
	if (yych <= 'F') goto yy1205;
	if (yych <= 'd') goto yy1176;
	if (yych <= 'f') goto yy1205;
	goto yy1176;
yy1183:
	yyaccept = 0;
	yych = *(mar = ++cur);
	if (yych <= 'Q') {
		if (yych <= '9') {
			if (yych <= '/') goto yy1162;
			goto yy1214;
		} else {
			if (yych == 'L') goto yy1215;
			goto yy1162;
		}
	} else {
		if (yych <= 'l') {
			if (yych <= 'R') goto yy1215;
			if (yych <= 'k') goto yy1162;
			goto yy1215;
		} else {
			if (yych == 'r') goto yy1215;
			goto yy1162;
		}
	}
yy1184:
	++cur;
	goto yy1176;
yy1185:
	yych = *++cur;
yy1186:
	if (yybm[0+yych] & 16) {
		goto yy1185;
	}
	if (yych >= 0x01) goto yy1188;
yy1187:
	cur = mar;
	if (yyaccept <= 2) {
		if (yyaccept <= 1) {
			if (yyaccept == 0) {
				goto yy1162;
			} else {
				goto yy1176;
			}
		} else {
			goto yy1189;
		}
	} else {
		if (yyaccept == 3) {
			goto yy1193;
		} else {
			goto yy1197;
		}
	}
yy1188:
	yyaccept = 2;
	yych = *(mar = ++cur);
	if (yych == '"') goto yy1185;
yy1189:
#line 766 "tokenizer.re"
	{ continue; }
#line 9261 "tokenizer.cpp"
yy1190:
	yych = *++cur;
yy1191:
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy1187;
			goto yy1190;
		} else {
			if (yych <= '\n') goto yy1192;
			if (yych <= '\v') goto yy1190;
			goto yy1187;
		}
	} else {
		if (yych <= 0x1F) {
			if (yych <= '\r') goto yy1190;
			goto yy1187;
		} else {
			if (yych <= ' ') goto yy1190;
			if (yych <= '!') goto yy1194;
			goto yy1187;
		}
	}
yy1192:
	yyaccept = 3;
	yych = *(mar = ++cur);
	if (yybm[0+yych] & 32) {
		goto yy1192;
	}
	if (yych <= 0x1F) goto yy1193;
	if (yych <= '!') goto yy1194;
	if (yych == '&') goto yy1216;
yy1193:
#line 765 "tokenizer.re"
	{ continue; }
#line 9296 "tokenizer.cpp"
yy1194:
	yych = *++cur;
	if (yybm[0+yych] & 64) {
		goto yy1194;
	}
	if (yych <= 0x00) goto yy1187;
	goto yy1192;
yy1195:
	yych = *++cur;
yy1196:
	if (yybm[0+yych] & 128) {
		goto yy1195;
	}
	if (yych <= 0x00) goto yy1187;
	yyaccept = 4;
	yych = *(mar = ++cur);
	if (yych == '\'') goto yy1195;
yy1197:
#line 767 "tokenizer.re"
	{ continue; }
#line 9317 "tokenizer.cpp"
yy1198:
	yych = *++cur;
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy1187;
			goto yy1198;
		} else {
			if (yych == '\v') goto yy1198;
			goto yy1187;
		}
	} else {
		if (yych <= ' ') {
			if (yych <= '\r') goto yy1198;
			if (yych <= 0x1F) goto yy1187;
			goto yy1198;
		} else {
			if (yych != '(') goto yy1187;
		}
	}
yy1199:
	++cur;
#line 747 "tokenizer.re"
	{
                cur--;
                unsigned char *tmp;
                lex_format(cur, loc, tmp);
                continue;
            }
#line 9346 "tokenizer.cpp"
yy1200:
	yych = *++cur;
	if (yych <= '\f') {
		if (yych <= '\t') {
			if (yych <= 0x08) goto yy1187;
			goto yy1200;
		} else {
			if (yych == '\v') goto yy1200;
			goto yy1187;
		}
	} else {
		if (yych <= ' ') {
			if (yych <= '\r') goto yy1200;
			if (yych <= 0x1F) goto yy1187;
			goto yy1200;
		} else {
			if (yych != '(') goto yy1187;
		}
	}
yy1201:
	++cur;
#line 741 "tokenizer.re"
	{
                cur--;
                unsigned char *tmp;
                lex_format(cur, loc, tmp);
                continue;
            }
#line 9375 "tokenizer.cpp"
yy1202:
	yych = *++cur;
yy1203:
	switch (yych) {
		case '\t':
		case '\v':
		case '\r':
		case ' ': goto yy1200;
		case '(': goto yy1201;
		case '/': goto yy1172;
		case '0':
		case '1':
		case '2':
		case '3':
		case '4':
		case '5':
		case '6':
		case '7':
		case '8':
		case '9': goto yy1202;
		case 'A':
		case 'a': goto yy1175;
		case 'B':
		case 'I':
		case 'O':
		case 'Z':
		case 'b':
		case 'i':
		case 'o':
		case 'z': goto yy1204;
		case 'D':
		case 'F':
		case 'd':
		case 'f': goto yy1205;
		case 'E':
		case 'e': goto yy1206;
		case 'G':
		case 'g': goto yy1207;
		case 'L':
		case 'l': goto yy1208;
		case 'P':
		case 'p': goto yy1182;
		case 'X':
		case 'x': goto yy1184;
		default: goto yy1187;
	}
yy1204:
	yych = *++cur;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1209;
	goto yy1187;
yy1205:
	yych = *++cur;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1210;
	goto yy1187;
yy1206:
	yych = *++cur;
	if (yych <= 'W') {
		if (yych <= 'M') {
			if (yych <= '/') goto yy1187;
			if (yych <= '9') goto yy1211;
			goto yy1187;
		} else {
			if (yych <= 'N') goto yy1212;
			if (yych == 'S') goto yy1212;
			goto yy1187;
		}
	} else {
		if (yych <= 'r') {
			if (yych <= 'X') goto yy1212;
			if (yych == 'n') goto yy1212;
			goto yy1187;
		} else {
			if (yych <= 's') goto yy1212;
			if (yych == 'x') goto yy1212;
			goto yy1187;
		}
	}
yy1207:
	yych = *++cur;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1213;
	goto yy1187;
yy1208:
	yych = *++cur;
	if (yybm[0+yych] & 8) {
		goto yy1175;
	}
	goto yy1187;
yy1209:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yych == '.') goto yy1208;
	if (yych <= '/') goto yy1176;
	if (yych <= '9') goto yy1209;
	goto yy1176;
yy1210:
	yych = *++cur;
	if (yych == '.') goto yy1208;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1210;
	goto yy1187;
yy1211:
	yych = *++cur;
	if (yych == '.') goto yy1217;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1211;
	goto yy1187;
yy1212:
	yych = *++cur;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1211;
	goto yy1187;
yy1213:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yych == '.') goto yy1217;
	if (yych <= '/') goto yy1176;
	if (yych <= '9') goto yy1213;
	goto yy1176;
yy1214:
	yych = *++cur;
	if (yych <= '/') goto yy1173;
	if (yych <= '9') goto yy1214;
	goto yy1173;
yy1215:
	yych = *++cur;
	if (yych <= '/') goto yy1187;
	if (yych <= '9') goto yy1214;
	goto yy1187;
yy1216:
	++cur;
	goto yy1193;
yy1217:
	yych = *++cur;
	if (yych <= '/') goto yy1187;
	if (yych >= ':') goto yy1187;
yy1218:
	yyaccept = 1;
	yych = *(mar = ++cur);
	if (yych <= 'D') {
		if (yych <= '/') goto yy1176;
		if (yych <= '9') goto yy1218;
		goto yy1176;
	} else {
		if (yych <= 'E') goto yy1208;
		if (yych == 'e') goto yy1208;
		goto yy1176;
	}
}
#line 771 "tokenizer.re"

    }
}

} // namespace LCompilers::LFortran
